/*      */ package oracle.jdbc.driver;
/*      */ 
/*      */ import java.io.InputStream;
/*      */ import java.io.OutputStream;
/*      */ import java.io.Reader;
/*      */ import java.io.Writer;
/*      */ import java.security.AccessController;
/*      */ import java.security.PrivilegedAction;
/*      */ import java.sql.Connection;
/*      */ import java.sql.SQLException;
/*      */ import java.sql.SQLWarning;
/*      */ import java.util.Locale;
/*      */ import java.util.NoSuchElementException;
/*      */ import java.util.Properties;
/*      */ import java.util.StringTokenizer;
/*      */ import oracle.jdbc.OracleOCIFailover;
/*      */ import oracle.jdbc.internal.OracleConnection;
/*      */ import oracle.jdbc.oracore.OracleTypeADT;
/*      */ import oracle.jdbc.oracore.OracleTypeCLOB;
/*      */ import oracle.jdbc.pool.OracleOCIConnectionPool;
/*      */ import oracle.jdbc.pool.OraclePooledConnection;
/*      */ import oracle.sql.BFILE;
/*      */ import oracle.sql.BLOB;
/*      */ import oracle.sql.BfileDBAccess;
/*      */ import oracle.sql.BlobDBAccess;
/*      */ import oracle.sql.CLOB;
/*      */ import oracle.sql.ClobDBAccess;
/*      */ import oracle.sql.LobPlsqlUtil;
/*      */ import oracle.sql.SQLName;
/*      */ import oracle.sql.converter.CharacterSetMetaData;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public class T2CConnection
/*      */   extends PhysicalConnection
/*      */   implements BfileDBAccess, BlobDBAccess, ClobDBAccess
/*      */ {
/*   48 */   short[] queryMetaData1 = null;
/*   49 */   byte[] queryMetaData2 = null;
/*   50 */   int queryMetaData1Offset = 0;
/*   51 */   int queryMetaData2Offset = 0;
/*      */   private String password;
/*   53 */   int fatalErrorNumber = 0;
/*   54 */   String fatalErrorMessage = null;
/*      */   
/*      */   static final int QMD_dbtype = 0;
/*      */   
/*      */   static final int QMD_dbsize = 1;
/*      */   
/*      */   static final int QMD_nullok = 2;
/*      */   
/*      */   static final int QMD_precision = 3;
/*      */   
/*      */   static final int QMD_scale = 4;
/*      */   
/*      */   static final int QMD_formOfUse = 5;
/*      */   
/*      */   static final int QMD_columnNameLength = 6;
/*      */   
/*      */   static final int QMD_tdo0 = 7;
/*      */   
/*      */   static final int QMD_tdo1 = 8;
/*      */   
/*      */   static final int QMD_tdo2 = 9;
/*      */   
/*      */   static final int QMD_tdo3 = 10;
/*      */   
/*      */   static final int QMD_charLength = 11;
/*      */   
/*      */   static final int QMD_typeNameLength = 12;
/*      */   static final int T2C_LOCATOR_MAX_LEN = 16;
/*      */   static final int T2C_LINEARIZED_LOCATOR_MAX_LEN = 4000;
/*      */   static final int T2C_LINEARIZED_BFILE_LOCATOR_MAX_LEN = 530;
/*      */   static final int METADATA1_INDICES_PER_COLUMN = 13;
/*      */   protected static final int SIZEOF_QUERYMETADATA2 = 8;
/*   86 */   int queryMetaData1Size = 100;
/*   87 */   int queryMetaData2Size = 800;
/*      */   
/*      */   long m_nativeState;
/*      */   
/*      */   short m_clientCharacterSet;
/*      */   
/*      */   byte byteAlign;
/*      */   
/*      */   private static final int EOJ_SUCCESS = 0;
/*      */   
/*      */   private static final int EOJ_ERROR = -1;
/*      */   
/*      */   private static final int EOJ_WARNING = 1;
/*      */   
/*      */   private static final String OCILIBRARY = "ocijdbc10";
/*      */   
/*  103 */   private int logon_mode = 0;
/*      */   
/*      */   static final int LOGON_MODE_DEFAULT = 0;
/*      */   
/*      */   static final int LOGON_MODE_SYSDBA = 2;
/*      */   
/*      */   static final int LOGON_MODE_SYSOPER = 4;
/*      */   
/*      */   static final int LOGON_MODE_CONNECTION_POOL = 5;
/*      */   
/*      */   static final int LOGON_MODE_CONNPOOL_CONNECTION = 6;
/*      */   
/*      */   static final int LOGON_MODE_CONNPOOL_PROXY_CONNECTION = 7;
/*      */   
/*      */   static final int LOGON_MODE_CONNPOOL_ALIASED_CONNECTION = 8;
/*      */   static final int T2C_PROXYTYPE_NONE = 0;
/*      */   static final int T2C_PROXYTYPE_USER_NAME = 1;
/*      */   static final int T2C_PROXYTYPE_DISTINGUISHED_NAME = 2;
/*      */   static final int T2C_PROXYTYPE_CERTIFICATE = 3;
/*      */   private static boolean isLibraryLoaded;
/*  123 */   OracleOCIFailover appCallback = null;
/*  124 */   Object appCallbackObject = null;
/*      */   
/*      */   private Properties nativeInfo;
/*      */   
/*      */ 
/*      */   protected T2CConnection(String paramString1, String paramString2, String paramString3, String paramString4, Properties paramProperties, OracleDriverExtension paramOracleDriverExtension)
/*      */     throws SQLException
/*      */   {
/*  132 */     super(paramString1, paramString2, paramString3, paramString4, paramProperties, paramOracleDriverExtension);
/*      */     
/*  134 */     initialize();
/*      */   }
/*      */   
/*      */   final void initializePassword(String paramString) throws SQLException
/*      */   {
/*  139 */     this.password = paramString;
/*      */   }
/*      */   
/*      */   protected void initialize()
/*      */   {
/*  144 */     allocQueryMetaDataBuffers();
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void allocQueryMetaDataBuffers()
/*      */   {
/*  174 */     this.queryMetaData1Offset = 0;
/*  175 */     this.queryMetaData1 = new short[this.queryMetaData1Size * 13];
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*  180 */     this.queryMetaData2Offset = 0;
/*  181 */     this.queryMetaData2 = new byte[this.queryMetaData2Size];
/*      */     
/*  183 */     this.namedTypeAccessorByteLen = 0;
/*  184 */     this.refTypeAccessorByteLen = 0;
/*      */   }
/*      */   
/*      */   void reallocateQueryMetaData(int paramInt1, int paramInt2)
/*      */   {
/*  189 */     this.queryMetaData1 = null;
/*  190 */     this.queryMetaData2 = null;
/*      */     
/*  192 */     this.queryMetaData1Size = Math.max(paramInt1, this.queryMetaData1Size);
/*  193 */     this.queryMetaData2Size = Math.max(paramInt2, this.queryMetaData2Size);
/*      */     
/*  195 */     allocQueryMetaDataBuffers();
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void logon()
/*      */     throws SQLException
/*      */   {
/*  217 */     if (this.database == null) {
/*  218 */       DatabaseError.throwSqlException(64);
/*      */     }
/*  220 */     if (!isLibraryLoaded) {
/*  221 */       loadNativeLibrary(this.connectionProperties);
/*      */     }
/*      */     
/*      */ 
/*  225 */     if (this.connectionProperties.getProperty("is_connection_pooling") == "true")
/*      */     {
/*      */ 
/*  228 */       processOCIConnectionPooling();
/*      */ 
/*      */ 
/*      */     }
/*      */     else
/*      */     {
/*      */ 
/*  235 */       long l1 = 0L;
/*  236 */       long l2 = 0L;
/*  237 */       long l3 = 0L;
/*      */       String str1;
/*      */       String str2;
/*  240 */       if (((str1 = this.connectionProperties.getProperty("OCISvcCtxHandle")) != null) && ((str2 = this.connectionProperties.getProperty("OCIEnvHandle")) != null))
/*      */       {
/*      */ 
/*      */ 
/*      */ 
/*  245 */         l1 = Long.parseLong(str1);
/*  246 */         l2 = Long.parseLong(str2);
/*      */         String str3;
/*  248 */         if ((str3 = this.connectionProperties.getProperty("OCIErrHandle")) != null)
/*      */         {
/*  250 */           l3 = Long.parseLong(str3);
/*      */         }
/*      */         
/*      */ 
/*      */ 
/*  255 */         if ((str4 = this.connectionProperties.getProperty("JDBCDriverCharSetId")) != null)
/*      */         {
/*  257 */           this.m_clientCharacterSet = new Integer(str4).shortValue();
/*      */ 
/*      */         }
/*      */         else
/*      */         {
/*      */ 
/*  263 */           DatabaseError.throwSqlException(89);
/*      */         }
/*      */         
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  270 */         this.conversion = new DBConversion(this.m_clientCharacterSet, this.m_clientCharacterSet, this.m_clientCharacterSet);
/*      */         
/*      */ 
/*  273 */         localObject = new short[3];
/*      */         
/*  275 */         this.sqlWarning = checkError(t2cUseConnection(this.m_nativeState, l2, l1, l3, (short[])localObject), this.sqlWarning);
/*      */         
/*      */ 
/*      */ 
/*  279 */         this.conversion = new DBConversion(localObject[0], this.m_clientCharacterSet, localObject[1]);
/*  280 */         this.byteAlign = ((byte)(localObject[2] & 0xFF));
/*      */         
/*  282 */         return;
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*  287 */       String str4 = this.connectionProperties.getProperty("internal_logon");
/*      */       
/*      */ 
/*  290 */       if (str4 == null) {
/*  291 */         this.logon_mode = 0;
/*  292 */       } else if (str4.equalsIgnoreCase("SYSDBA")) {
/*  293 */         this.logon_mode = 2;
/*  294 */       } else if (str4.equalsIgnoreCase("SYSOPER")) {
/*  295 */         this.logon_mode = 4;
/*      */       }
/*  297 */       Object localObject = this.connectionProperties.getProperty("oracle.jdbc.ociNlsLangBackwardCompatible");
/*      */       
/*      */ 
/*  300 */       byte[] arrayOfByte1 = null;
/*  301 */       byte[] arrayOfByte2 = null;
/*  302 */       String str5 = null;
/*  303 */       byte[] arrayOfByte3 = new byte[0];
/*  304 */       if (this.connectionProperties != null)
/*      */       {
/*  306 */         str5 = (String)this.connectionProperties.get("OCINewPassword");
/*      */       }
/*      */       
/*      */ 
/*  310 */       if ((localObject != null) && (((String)localObject).equalsIgnoreCase("true")))
/*      */       {
/*      */ 
/*      */ 
/*  314 */         this.m_clientCharacterSet = getDriverCharSetIdFromNLS_LANG(this.connectionProperties);
/*      */ 
/*      */       }
/*      */       else
/*      */       {
/*  319 */         this.m_clientCharacterSet = getClientCharSetId();
/*      */       }
/*      */       
/*  322 */       if (str5 != null) {
/*  323 */         arrayOfByte3 = DBConversion.stringToAsciiBytes(str5);
/*      */       }
/*  325 */       arrayOfByte1 = this.user == null ? new byte[0] : DBConversion.stringToDriverCharBytes(this.user, this.m_clientCharacterSet);
/*      */       
/*      */ 
/*      */ 
/*  329 */       arrayOfByte2 = this.password == null ? new byte[0] : DBConversion.stringToAsciiBytes(this.password);
/*      */       
/*      */ 
/*  332 */       byte[] arrayOfByte4 = DBConversion.stringToAsciiBytes(this.database);
/*      */       
/*  334 */       short[] arrayOfShort = new short[3];
/*  335 */       byte[] arrayOfByte5 = CharacterSetMetaData.getNLSLanguage(Locale.getDefault()).getBytes();
/*      */       
/*  337 */       byte[] arrayOfByte6 = CharacterSetMetaData.getNLSTerritory(Locale.getDefault()).getBytes();
/*      */       
/*      */ 
/*      */ 
/*  341 */       this.conversion = new DBConversion(this.m_clientCharacterSet, this.m_clientCharacterSet, this.m_clientCharacterSet);
/*      */       
/*      */ 
/*  344 */       if (this.m_nativeState == 0L)
/*      */       {
/*  346 */         this.sqlWarning = checkError(t2cCreateState(arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length, arrayOfByte4, arrayOfByte4.length, this.m_clientCharacterSet, this.logon_mode, arrayOfShort, arrayOfByte5, arrayOfByte6), this.sqlWarning);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       }
/*      */       else
/*      */       {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  360 */         this.sqlWarning = checkError(t2cLogon(this.m_nativeState, arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length, arrayOfByte4, arrayOfByte4.length, this.logon_mode, arrayOfShort, arrayOfByte5, arrayOfByte6), this.sqlWarning);
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  371 */       this.conversion = new DBConversion(arrayOfShort[0], this.m_clientCharacterSet, arrayOfShort[1]);
/*  372 */       this.byteAlign = ((byte)(arrayOfShort[2] & 0xFF));
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void logoff()
/*      */     throws SQLException
/*      */   {
/*      */     try
/*      */     {
/*  389 */       if (this.m_nativeState != 0L)
/*      */       {
/*  391 */         checkError(t2cLogoff(this.m_nativeState));
/*      */       }
/*      */     }
/*      */     catch (NullPointerException localNullPointerException) {}
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void open(OracleStatement paramOracleStatement)
/*      */     throws SQLException
/*      */   {
/*  413 */     byte[] arrayOfByte = paramOracleStatement.sqlObject.getSql(paramOracleStatement.processEscapes, paramOracleStatement.convertNcharLiterals).getBytes();
/*      */     
/*      */ 
/*  416 */     checkError(t2cCreateStatement(this.m_nativeState, 0L, arrayOfByte, arrayOfByte.length, paramOracleStatement, false, paramOracleStatement.rowPrefetch));
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   void doCancel()
/*      */     throws SQLException
/*      */   {
/*  433 */     checkError(t2cCancel(this.m_nativeState));
/*      */   }
/*      */   
/*      */   native int t2cAbort(long paramLong);
/*      */   
/*      */   void doAbort() throws SQLException
/*      */   {
/*  440 */     checkError(t2cAbort(this.m_nativeState));
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void doSetAutoCommit(boolean paramBoolean)
/*      */     throws SQLException
/*      */   {
/*  457 */     checkError(t2cSetAutoCommit(this.m_nativeState, paramBoolean));
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void doCommit()
/*      */     throws SQLException
/*      */   {
/*  471 */     checkError(t2cCommit(this.m_nativeState));
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void doRollback()
/*      */     throws SQLException
/*      */   {
/*  485 */     checkError(t2cRollback(this.m_nativeState));
/*      */   }
/*      */   
/*      */   protected String doGetDatabaseProductVersion() throws SQLException
/*      */   {
/*  490 */     byte[] arrayOfByte = t2cGetProductionVersion(this.m_nativeState);
/*      */     
/*  492 */     return this.conversion.CharBytesToString(arrayOfByte, arrayOfByte.length);
/*      */   }
/*      */   
/*      */   protected short doGetVersionNumber() throws SQLException
/*      */   {
/*  497 */     short s = 0;
/*      */     
/*      */     try
/*      */     {
/*  501 */       String str1 = doGetDatabaseProductVersion();
/*      */       
/*  503 */       StringTokenizer localStringTokenizer = new StringTokenizer(str1.trim(), " .", false);
/*  504 */       String str2 = null;
/*  505 */       int i = 0;
/*  506 */       int j = 0;
/*      */       
/*  508 */       while (localStringTokenizer.hasMoreTokens())
/*      */       {
/*  510 */         str2 = localStringTokenizer.nextToken();
/*      */         
/*      */         try
/*      */         {
/*  514 */           j = Integer.decode(str2).shortValue();
/*  515 */           s = (short)(s * 10 + j);
/*  516 */           i++;
/*      */           
/*      */ 
/*  519 */           if (i == 4) {
/*      */             break;
/*      */           }
/*      */         }
/*      */         catch (NumberFormatException localNumberFormatException) {}
/*      */       }
/*      */     }
/*      */     catch (NoSuchElementException localNoSuchElementException) {}
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  536 */     if (s == -1) {
/*  537 */       s = 0;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*  542 */     return s;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public ClobDBAccess createClobDBAccess()
/*      */   {
/*  549 */     return this;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public BlobDBAccess createBlobDBAccess()
/*      */   {
/*  556 */     return this;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public BfileDBAccess createBfileDBAccess()
/*      */   {
/*  563 */     return this;
/*      */   }
/*      */   
/*      */ 
/*      */   public CLOB createClob(byte[] paramArrayOfByte)
/*      */     throws SQLException
/*      */   {
/*  570 */     return new CLOB(this, paramArrayOfByte);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public CLOB createClob(byte[] paramArrayOfByte, short paramShort)
/*      */     throws SQLException
/*      */   {
/*  579 */     return new CLOB(this, paramArrayOfByte, paramShort);
/*      */   }
/*      */   
/*      */ 
/*      */   public BLOB createBlob(byte[] paramArrayOfByte)
/*      */     throws SQLException
/*      */   {
/*  586 */     return new BLOB(this, paramArrayOfByte);
/*      */   }
/*      */   
/*      */ 
/*      */   public BFILE createBfile(byte[] paramArrayOfByte)
/*      */     throws SQLException
/*      */   {
/*  593 */     return new BFILE(this, paramArrayOfByte);
/*      */   }
/*      */   
/*      */   protected SQLWarning checkError(int paramInt) throws SQLException
/*      */   {
/*  598 */     return checkError(paramInt, null);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   protected SQLWarning checkError(int paramInt, SQLWarning paramSQLWarning)
/*      */     throws SQLException
/*      */   {
/*  606 */     switch (paramInt)
/*      */     {
/*      */     case 0: 
/*      */       break;
/*      */     
/*      */ 
/*      */     case -1: 
/*      */     case 1: 
/*  614 */       T2CError localT2CError = new T2CError();
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  620 */       int i = -1;
/*      */       
/*  622 */       if (this.m_nativeState != 0L)
/*      */       {
/*  624 */         i = t2cDescribeError(this.m_nativeState, localT2CError, localT2CError.m_errorMessage);
/*      */ 
/*      */       }
/*  627 */       else if (this.fatalErrorNumber != 0)
/*      */       {
/*  629 */         String str1 = DatabaseError.ErrorToSQLState(this.fatalErrorNumber);
/*      */         
/*  631 */         DatabaseError.throwSqlException(this.fatalErrorMessage, str1, localT2CError.m_errorNumber);
/*      */ 
/*      */       }
/*      */       else
/*      */       {
/*  636 */         DatabaseError.throwSqlException(8);
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*  641 */       switch (localT2CError.m_errorNumber)
/*      */       {
/*      */       case 28: 
/*      */       case 600: 
/*      */       case 1012: 
/*      */       case 1041: 
/*      */       case 3113: 
/*      */       case 3114: 
/*  649 */         internalClose();
/*      */       }
/*      */       
/*      */       
/*      */ 
/*  654 */       if (i == -1) {
/*  655 */         DatabaseError.throwSqlException(1, "Fetch error message failed!");
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*  660 */       int j = 0;
/*      */       
/*  662 */       while ((j < localT2CError.m_errorMessage.length) && (localT2CError.m_errorMessage[j] != 0)) {
/*  663 */         j++;
/*      */       }
/*  665 */       String str2 = this.conversion.CharBytesToString(localT2CError.m_errorMessage, j, true);
/*      */       
/*      */ 
/*  668 */       String str3 = DatabaseError.ErrorToSQLState(localT2CError.m_errorNumber);
/*      */       
/*  670 */       if (paramInt == -1)
/*      */       {
/*  672 */         DatabaseError.throwSqlException(str2, str3, localT2CError.m_errorNumber);
/*      */ 
/*      */       }
/*      */       else
/*      */       {
/*  677 */         paramSQLWarning = DatabaseError.addSqlWarning(paramSQLWarning, str2, str3, localT2CError.m_errorNumber);
/*      */       }
/*      */       
/*      */ 
/*  681 */       break;
/*      */     }
/*      */     
/*      */     
/*      */ 
/*      */ 
/*  687 */     return paramSQLWarning;
/*      */   }
/*      */   
/*      */   OracleStatement RefCursorBytesToStatement(byte[] paramArrayOfByte, OracleStatement paramOracleStatement)
/*      */     throws SQLException
/*      */   {
/*  693 */     T2CStatement localT2CStatement = new T2CStatement(this, 1, this.defaultRowPrefetch, -1, -1);
/*      */     
/*  695 */     localT2CStatement.needToParse = false;
/*  696 */     localT2CStatement.serverCursor = true;
/*  697 */     localT2CStatement.isOpen = true;
/*  698 */     localT2CStatement.processEscapes = false;
/*      */     
/*  700 */     localT2CStatement.prepareForNewResults(true, false);
/*  701 */     localT2CStatement.sqlObject.initialize("select unknown as ref cursor from whatever");
/*      */     
/*  703 */     localT2CStatement.sqlKind = 0;
/*      */     
/*  705 */     checkError(t2cCreateStatement(this.m_nativeState, paramOracleStatement.c_state, paramArrayOfByte, paramArrayOfByte.length, localT2CStatement, true, this.defaultRowPrefetch));
/*      */     
/*      */ 
/*      */ 
/*  709 */     return localT2CStatement;
/*      */   }
/*      */   
/*      */ 
/*      */   public void getForm(OracleTypeADT paramOracleTypeADT, OracleTypeCLOB paramOracleTypeCLOB, int paramInt)
/*      */     throws SQLException
/*      */   {
/*  716 */     int i = 0;
/*      */     
/*  718 */     if (paramOracleTypeCLOB != null)
/*      */     {
/*  720 */       String[] arrayOfString1 = new String[1];
/*  721 */       String[] arrayOfString2 = new String[1];
/*      */       
/*  723 */       SQLName.parse(paramOracleTypeADT.getFullName(), arrayOfString1, arrayOfString2, true);
/*      */       
/*  725 */       String str = "\"" + arrayOfString1[0] + "\".\"" + arrayOfString2[0] + "\"";
/*      */       
/*      */ 
/*  728 */       byte[] arrayOfByte = this.conversion.StringToCharBytes(str);
/*      */       
/*  730 */       int j = t2cGetFormOfUse(this.m_nativeState, paramOracleTypeCLOB, arrayOfByte, arrayOfByte.length, paramInt);
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  736 */       if (j < 0) {
/*  737 */         checkError(j);
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*  742 */       paramOracleTypeCLOB.setForm(j);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public long getTdoCState(String paramString1, String paramString2)
/*      */     throws SQLException
/*      */   {
/*  761 */     String str = "\"" + paramString1 + "\".\"" + paramString2 + "\"";
/*  762 */     byte[] arrayOfByte = this.conversion.StringToCharBytes(str);
/*  763 */     int[] arrayOfInt = new int[1];
/*  764 */     long l = t2cGetTDO(this.m_nativeState, arrayOfByte, arrayOfByte.length, arrayOfInt);
/*  765 */     if (l == 0L)
/*      */     {
/*      */ 
/*      */ 
/*  769 */       checkError(arrayOfInt[0]);
/*      */     }
/*      */     
/*      */ 
/*  773 */     return l;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   /**
/*      */    * @deprecated
/*      */    */
/*      */   public Properties getDBAccessProperties()
/*      */     throws SQLException
/*      */   {
/*  787 */     return getOCIHandles();
/*      */   }
/*      */   
/*      */   public synchronized Properties getOCIHandles() throws SQLException
/*      */   {
/*  792 */     if (this.nativeInfo == null)
/*      */     {
/*  794 */       long[] arrayOfLong = new long[3];
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  800 */       checkError(t2cGetHandles(this.m_nativeState, arrayOfLong));
/*      */       
/*      */ 
/*  803 */       this.nativeInfo = new Properties();
/*      */       
/*  805 */       this.nativeInfo.put("OCIEnvHandle", String.valueOf(arrayOfLong[0]));
/*  806 */       this.nativeInfo.put("OCISvcCtxHandle", String.valueOf(arrayOfLong[1]));
/*  807 */       this.nativeInfo.put("OCIErrHandle", String.valueOf(arrayOfLong[2]));
/*  808 */       this.nativeInfo.put("ClientCharSet", String.valueOf(this.m_clientCharacterSet));
/*      */     }
/*      */     
/*  811 */     return this.nativeInfo;
/*      */   }
/*      */   
/*      */   public Properties getServerSessionInfo() throws SQLException
/*      */   {
/*  816 */     if (this.lifecycle != 1) {
/*  817 */       DatabaseError.throwSqlException(8);
/*      */     }
/*  819 */     Properties localProperties = new Properties();
/*  820 */     checkError(t2cGetServerSessionInfo(this.m_nativeState, localProperties));
/*      */     
/*  822 */     return localProperties;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public Properties getConnectionPoolInfo()
/*      */     throws SQLException
/*      */   {
/*  830 */     if (this.lifecycle != 1)
/*  831 */       DatabaseError.throwSqlException(8);
/*  832 */     Properties localProperties = new Properties();
/*      */     
/*  834 */     checkError(t2cGetConnPoolInfo(this.m_nativeState, localProperties));
/*      */     
/*  836 */     return localProperties;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public void setConnectionPoolInfo(int paramInt1, int paramInt2, int paramInt3, int paramInt4, int paramInt5, int paramInt6)
/*      */     throws SQLException
/*      */   {
/*  844 */     checkError(t2cSetConnPoolInfo(this.m_nativeState, paramInt1, paramInt2, paramInt3, paramInt4, paramInt5, paramInt6));
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public void ociPasswordChange(String paramString1, String paramString2, String paramString3)
/*      */     throws SQLException
/*      */   {
/*  852 */     if (this.lifecycle != 1)
/*  853 */       DatabaseError.throwSqlException(8);
/*  854 */     byte[] arrayOfByte1 = paramString1 == null ? new byte[0] : DBConversion.stringToDriverCharBytes(paramString1, this.m_clientCharacterSet);
/*      */     
/*      */ 
/*      */ 
/*  858 */     byte[] arrayOfByte2 = paramString2 == null ? new byte[0] : DBConversion.stringToAsciiBytes(paramString2);
/*      */     
/*      */ 
/*  861 */     byte[] arrayOfByte3 = paramString3 == null ? new byte[0] : DBConversion.stringToAsciiBytes(paramString3);
/*      */     
/*      */ 
/*  864 */     this.sqlWarning = checkError(t2cPasswordChange(this.m_nativeState, arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length), this.sqlWarning);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   private void processOCIConnectionPooling()
/*      */     throws SQLException
/*      */   {
/*  873 */     if (this.lifecycle != 1)
/*  874 */       DatabaseError.throwSqlException(8);
/*  875 */     byte[] arrayOfByte1 = null;
/*      */     
/*  877 */     byte[] arrayOfByte2 = this.password == null ? new byte[0] : DBConversion.stringToAsciiBytes(this.password);
/*      */     
/*      */ 
/*  880 */     byte[] arrayOfByte3 = DBConversion.stringToAsciiBytes(this.database);
/*      */     
/*  882 */     byte[] arrayOfByte4 = CharacterSetMetaData.getNLSLanguage(Locale.getDefault()).getBytes();
/*      */     
/*  884 */     byte[] arrayOfByte5 = CharacterSetMetaData.getNLSTerritory(Locale.getDefault()).getBytes();
/*      */     
/*      */ 
/*      */ 
/*  888 */     String str1 = this.connectionProperties.getProperty("connection_pool");
/*      */     
/*      */ 
/*  891 */     short[] arrayOfShort = new short[3];
/*      */     Object localObject1;
/*  893 */     Object localObject2; if (str1 == "connection_pool")
/*      */     {
/*  895 */       localObject1 = this.connectionProperties.getProperty("oracle.jdbc.ociNlsLangBackwardCompatible");
/*      */       
/*      */ 
/*  898 */       if ((localObject1 != null) && (((String)localObject1).equalsIgnoreCase("true")))
/*      */       {
/*      */ 
/*      */ 
/*  902 */         this.m_clientCharacterSet = getDriverCharSetIdFromNLS_LANG(this.connectionProperties);
/*      */ 
/*      */       }
/*      */       else
/*      */       {
/*  907 */         this.m_clientCharacterSet = getClientCharSetId();
/*      */       }
/*      */       
/*  910 */       arrayOfByte1 = this.user == null ? new byte[0] : DBConversion.stringToDriverCharBytes(this.user, this.m_clientCharacterSet);
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  916 */       this.conversion = new DBConversion(this.m_clientCharacterSet, this.m_clientCharacterSet, this.m_clientCharacterSet);
/*      */       
/*      */ 
/*  919 */       this.logon_mode = 5;
/*      */       
/*  921 */       if (this.m_nativeState == 0L)
/*      */       {
/*  923 */         localObject2 = new int[6];
/*      */         
/*  925 */         OracleOCIConnectionPool.readPoolConfig(this.connectionProperties, (int[])localObject2);
/*      */         
/*  927 */         this.sqlWarning = checkError(t2cCreateConnPool(arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length, this.m_clientCharacterSet, this.logon_mode, localObject2[0], localObject2[1], localObject2[2], localObject2[3], localObject2[4], localObject2[5]), this.sqlWarning);
/*      */         
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  938 */         this.versionNumber = 10000;
/*      */ 
/*      */ 
/*      */       }
/*      */       else
/*      */       {
/*      */ 
/*  945 */         throw DatabaseError.newSqlException(0, "Internal Error: ");
/*      */ 
/*      */       }
/*      */       
/*      */ 
/*      */     }
/*  951 */     else if (str1 == "connpool_connection")
/*      */     {
/*  953 */       this.logon_mode = 6;
/*      */       
/*  955 */       localObject1 = (T2CConnection)this.connectionProperties.get("connpool_object");
/*      */       
/*      */ 
/*  958 */       this.m_clientCharacterSet = ((T2CConnection)localObject1).m_clientCharacterSet;
/*      */       
/*  960 */       arrayOfByte1 = this.user == null ? new byte[0] : DBConversion.stringToDriverCharBytes(this.user, this.m_clientCharacterSet);
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  966 */       this.conversion = new DBConversion(this.m_clientCharacterSet, this.m_clientCharacterSet, this.m_clientCharacterSet);
/*      */       
/*      */ 
/*  969 */       this.sqlWarning = checkError(t2cConnPoolLogon(((T2CConnection)localObject1).m_nativeState, arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length, this.logon_mode, 0, 0, null, null, 0, null, 0, null, 0, null, 0, null, 0, arrayOfShort, arrayOfByte4, arrayOfByte5), this.sqlWarning);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     }
/*  997 */     else if (str1 == "connpool_alias_connection")
/*      */     {
/*  999 */       this.logon_mode = 8;
/*      */       
/*      */ 
/* 1002 */       localObject1 = null;
/*      */       
/* 1004 */       localObject1 = (byte[])this.connectionProperties.get("connection_id");
/*      */       
/*      */ 
/* 1007 */       localObject2 = (T2CConnection)this.connectionProperties.get("connpool_object");
/*      */       
/*      */ 
/* 1010 */       this.m_clientCharacterSet = ((T2CConnection)localObject2).m_clientCharacterSet;
/*      */       
/* 1012 */       arrayOfByte1 = this.user == null ? new byte[0] : DBConversion.stringToDriverCharBytes(this.user, this.m_clientCharacterSet);
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1018 */       this.conversion = new DBConversion(this.m_clientCharacterSet, this.m_clientCharacterSet, this.m_clientCharacterSet);
/*      */       
/*      */ 
/* 1021 */       this.sqlWarning = checkError(t2cConnPoolLogon(((T2CConnection)localObject2).m_nativeState, arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length, this.logon_mode, 0, 0, null, null, 0, null, 0, null, 0, null, 0, (byte[])localObject1, localObject1 == null ? 0 : localObject1.length, arrayOfShort, arrayOfByte4, arrayOfByte5), this.sqlWarning);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     }
/* 1049 */     else if (str1 == "connpool_proxy_connection")
/*      */     {
/* 1051 */       this.logon_mode = 7;
/*      */       
/*      */ 
/* 1054 */       localObject1 = this.connectionProperties.getProperty("proxytype");
/*      */       
/*      */ 
/*      */ 
/* 1058 */       localObject2 = (Integer)this.connectionProperties.get("proxy_num_roles");
/*      */       
/* 1060 */       int i = ((Integer)localObject2).intValue();
/*      */       
/* 1062 */       String[] arrayOfString = null;
/*      */       
/* 1064 */       if (i > 0)
/*      */       {
/* 1066 */         arrayOfString = (String[])this.connectionProperties.get("proxy_roles");
/*      */       }
/*      */       
/*      */ 
/* 1070 */       byte[] arrayOfByte6 = null;
/* 1071 */       byte[] arrayOfByte7 = null;
/* 1072 */       byte[] arrayOfByte8 = null;
/* 1073 */       byte[] arrayOfByte9 = null;
/*      */       
/*      */ 
/* 1076 */       int j = 0;
/*      */       
/*      */       String str2;
/* 1079 */       if (localObject1 == "proxytype_user_name")
/*      */       {
/* 1081 */         j = 1;
/*      */         
/* 1083 */         str2 = this.connectionProperties.getProperty("proxy_user_name");
/*      */         
/*      */ 
/* 1086 */         if (str2 != null) {
/* 1087 */           arrayOfByte6 = str2.getBytes();
/*      */         }
/* 1089 */         str2 = this.connectionProperties.getProperty("proxy_password");
/*      */         
/*      */ 
/* 1092 */         if (str2 != null) {
/* 1093 */           arrayOfByte7 = str2.getBytes();
/*      */         }
/* 1095 */       } else if (localObject1 == "proxytype_distinguished_name")
/*      */       {
/*      */ 
/* 1098 */         j = 2;
/*      */         
/* 1100 */         str2 = this.connectionProperties.getProperty("proxy_distinguished_name");
/*      */         
/*      */ 
/* 1103 */         if (str2 != null) {
/* 1104 */           arrayOfByte8 = str2.getBytes();
/*      */         }
/* 1106 */       } else if (localObject1 == "proxytype_certificate")
/*      */       {
/* 1108 */         j = 3;
/*      */         
/* 1110 */         arrayOfByte9 = (byte[])this.connectionProperties.get("proxy_certificate");
/*      */ 
/*      */ 
/*      */       }
/*      */       else
/*      */       {
/*      */ 
/*      */ 
/* 1118 */         DatabaseError.throwSqlException(107);
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1125 */       T2CConnection localT2CConnection = (T2CConnection)this.connectionProperties.get("connpool_object");
/*      */       
/*      */ 
/* 1128 */       this.m_clientCharacterSet = localT2CConnection.m_clientCharacterSet;
/*      */       
/* 1130 */       arrayOfByte1 = this.user == null ? new byte[0] : DBConversion.stringToDriverCharBytes(this.user, this.m_clientCharacterSet);
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1136 */       this.conversion = new DBConversion(this.m_clientCharacterSet, this.m_clientCharacterSet, this.m_clientCharacterSet);
/*      */       
/*      */ 
/* 1139 */       this.sqlWarning = checkError(t2cConnPoolLogon(localT2CConnection.m_nativeState, arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length, this.logon_mode, j, i, arrayOfString, arrayOfByte6, arrayOfByte6 == null ? 0 : arrayOfByte6.length, arrayOfByte7, arrayOfByte7 == null ? 0 : arrayOfByte7.length, arrayOfByte8, arrayOfByte8 == null ? 0 : arrayOfByte8.length, arrayOfByte9, arrayOfByte9 == null ? 0 : arrayOfByte9.length, null, 0, arrayOfShort, arrayOfByte4, arrayOfByte5), this.sqlWarning);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     }
/*      */     else
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1163 */       DatabaseError.throwSqlException(23, "connection-pool-logon");
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1169 */     this.conversion = new DBConversion(arrayOfShort[0], this.m_clientCharacterSet, arrayOfShort[1]);
/* 1170 */     this.byteAlign = ((byte)(arrayOfShort[2] & 0xFF));
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public boolean isDescriptorSharable(OracleConnection paramOracleConnection)
/*      */     throws SQLException
/*      */   {
/* 1184 */     T2CConnection localT2CConnection = this;
/* 1185 */     PhysicalConnection localPhysicalConnection = (PhysicalConnection)paramOracleConnection.getPhysicalConnection();
/*      */     
/* 1187 */     return localT2CConnection == localPhysicalConnection;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   native int blobRead(long paramLong1, byte[] paramArrayOfByte1, int paramInt1, long paramLong2, int paramInt2, byte[] paramArrayOfByte2, int paramInt3);
/*      */   
/*      */ 
/*      */ 
/*      */   native int clobRead(long paramLong1, byte[] paramArrayOfByte, int paramInt1, long paramLong2, int paramInt2, char[] paramArrayOfChar, int paramInt3, boolean paramBoolean);
/*      */   
/*      */ 
/*      */ 
/*      */   native int blobWrite(long paramLong1, byte[] paramArrayOfByte1, int paramInt1, long paramLong2, int paramInt2, byte[] paramArrayOfByte2, int paramInt3, byte[][] paramArrayOfByte);
/*      */   
/*      */ 
/*      */ 
/*      */   native int clobWrite(long paramLong1, byte[] paramArrayOfByte, int paramInt1, long paramLong2, int paramInt2, char[] paramArrayOfChar, int paramInt3, byte[][] paramArrayOfByte1, boolean paramBoolean);
/*      */   
/*      */ 
/*      */ 
/*      */   native long lobGetLength(long paramLong, byte[] paramArrayOfByte, int paramInt);
/*      */   
/*      */ 
/*      */ 
/*      */   native int bfileOpen(long paramLong, byte[] paramArrayOfByte, int paramInt, byte[][] paramArrayOfByte1);
/*      */   
/*      */ 
/*      */ 
/*      */   native int bfileIsOpen(long paramLong, byte[] paramArrayOfByte, int paramInt, boolean[] paramArrayOfBoolean);
/*      */   
/*      */ 
/*      */ 
/*      */   native int bfileExists(long paramLong, byte[] paramArrayOfByte, int paramInt, boolean[] paramArrayOfBoolean);
/*      */   
/*      */ 
/*      */ 
/*      */   native String bfileGetName(long paramLong, byte[] paramArrayOfByte, int paramInt);
/*      */   
/*      */ 
/*      */ 
/*      */   native String bfileGetDirAlias(long paramLong, byte[] paramArrayOfByte, int paramInt);
/*      */   
/*      */ 
/*      */   native int bfileClose(long paramLong, byte[] paramArrayOfByte, int paramInt, byte[][] paramArrayOfByte1);
/*      */   
/*      */ 
/*      */   native int lobGetChunkSize(long paramLong, byte[] paramArrayOfByte, int paramInt);
/*      */   
/*      */ 
/*      */   native int lobTrim(long paramLong1, int paramInt1, long paramLong2, byte[] paramArrayOfByte, int paramInt2, byte[][] paramArrayOfByte1);
/*      */   
/*      */ 
/*      */   native int lobCreateTemporary(long paramLong, int paramInt1, boolean paramBoolean, int paramInt2, short paramShort, byte[][] paramArrayOfByte);
/*      */   
/*      */ 
/*      */   native int lobFreeTemporary(long paramLong, int paramInt1, byte[] paramArrayOfByte, int paramInt2, byte[][] paramArrayOfByte1);
/*      */   
/*      */ 
/*      */   native int lobIsTemporary(long paramLong, int paramInt1, byte[] paramArrayOfByte, int paramInt2, boolean[] paramArrayOfBoolean);
/*      */   
/*      */ 
/*      */   native int lobOpen(long paramLong, int paramInt1, byte[] paramArrayOfByte, int paramInt2, int paramInt3, byte[][] paramArrayOfByte1);
/*      */   
/*      */ 
/*      */   native int lobIsOpen(long paramLong, int paramInt1, byte[] paramArrayOfByte, int paramInt2, boolean[] paramArrayOfBoolean);
/*      */   
/*      */ 
/*      */   native int lobClose(long paramLong, int paramInt1, byte[] paramArrayOfByte, int paramInt2, byte[][] paramArrayOfByte1);
/*      */   
/*      */ 
/*      */   private long lobLength(byte[] paramArrayOfByte)
/*      */     throws SQLException
/*      */   {
/* 1261 */     long l = 0L;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1266 */     l = lobGetLength(this.m_nativeState, paramArrayOfByte, paramArrayOfByte.length);
/*      */     
/* 1268 */     checkError((int)l);
/*      */     
/* 1270 */     return l;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private int blobRead(byte[] paramArrayOfByte1, long paramLong, int paramInt, byte[] paramArrayOfByte2)
/*      */     throws SQLException
/*      */   {
/* 1284 */     int i = 0;
/*      */     
/* 1286 */     i = blobRead(this.m_nativeState, paramArrayOfByte1, paramArrayOfByte1.length, paramLong, paramInt, paramArrayOfByte2, paramArrayOfByte2.length);
/*      */     
/*      */ 
/* 1289 */     checkError(i);
/*      */     
/* 1291 */     return i;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private int blobWrite(byte[] paramArrayOfByte1, long paramLong, byte[] paramArrayOfByte2, byte[][] paramArrayOfByte, int paramInt1, int paramInt2)
/*      */     throws SQLException
/*      */   {
/* 1307 */     int i = 0;
/*      */     
/* 1309 */     i = blobWrite(this.m_nativeState, paramArrayOfByte1, paramArrayOfByte1.length, paramLong, paramInt2, paramArrayOfByte2, paramInt1, paramArrayOfByte);
/*      */     
/*      */ 
/* 1312 */     checkError(i);
/*      */     
/* 1314 */     return i;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private int clobWrite(byte[] paramArrayOfByte, long paramLong, char[] paramArrayOfChar, byte[][] paramArrayOfByte1, boolean paramBoolean, int paramInt1, int paramInt2)
/*      */     throws SQLException
/*      */   {
/* 1331 */     int i = 0;
/*      */     
/* 1333 */     i = clobWrite(this.m_nativeState, paramArrayOfByte, paramArrayOfByte.length, paramLong, paramInt2, paramArrayOfChar, paramInt1, paramArrayOfByte1, paramBoolean);
/*      */     
/*      */ 
/* 1336 */     checkError(i);
/*      */     
/* 1338 */     return i;
/*      */   }
/*      */   
/*      */   private int lobGetChunkSize(byte[] paramArrayOfByte)
/*      */     throws SQLException
/*      */   {
/* 1344 */     int i = 0;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1349 */     i = lobGetChunkSize(this.m_nativeState, paramArrayOfByte, paramArrayOfByte.length);
/*      */     
/* 1351 */     checkError(i);
/*      */     
/* 1353 */     return i;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public long length(BFILE paramBFILE)
/*      */     throws SQLException
/*      */   {
/* 1364 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1369 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1370 */     checkTrue((paramBFILE != null) && ((arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 1373 */     return lobLength(arrayOfByte);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public long position(BFILE paramBFILE, byte[] paramArrayOfByte, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 1391 */     if (paramLong < 1L)
/*      */     {
/*      */ 
/*      */ 
/* 1395 */       DatabaseError.throwSqlException(68, "position()");
/*      */     }
/*      */     
/*      */ 
/* 1399 */     long l = LobPlsqlUtil.hasPattern(paramBFILE, paramArrayOfByte, paramLong);
/*      */     
/* 1401 */     l = l == 0L ? -1L : l;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1406 */     return l;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public long position(BFILE paramBFILE1, BFILE paramBFILE2, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 1424 */     if (paramLong < 1L)
/*      */     {
/*      */ 
/*      */ 
/* 1428 */       DatabaseError.throwSqlException(68, "position()");
/*      */     }
/*      */     
/*      */ 
/* 1432 */     long l = LobPlsqlUtil.isSubLob(paramBFILE1, paramBFILE2, paramLong);
/*      */     
/* 1434 */     l = l == 0L ? -1L : l;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1439 */     return l;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public int getBytes(BFILE paramBFILE, long paramLong, int paramInt, byte[] paramArrayOfByte)
/*      */     throws SQLException
/*      */   {
/* 1453 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1458 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1459 */     checkTrue((paramBFILE != null) && ((arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 1462 */     if ((paramInt <= 0) || (paramArrayOfByte == null)) {
/* 1463 */       return 0;
/*      */     }
/* 1465 */     if (paramInt > paramArrayOfByte.length) {
/* 1466 */       paramInt = paramArrayOfByte.length;
/*      */     }
/* 1468 */     return blobRead(arrayOfByte, paramLong, paramInt, paramArrayOfByte);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public String getName(BFILE paramBFILE)
/*      */     throws SQLException
/*      */   {
/* 1480 */     byte[] arrayOfByte = null;
/* 1481 */     String str = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1486 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1487 */     checkTrue((paramBFILE != null) && ((arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 1490 */     str = bfileGetName(this.m_nativeState, arrayOfByte, arrayOfByte.length);
/*      */     
/* 1492 */     checkError(str.length());
/*      */     
/* 1494 */     return str;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public String getDirAlias(BFILE paramBFILE)
/*      */     throws SQLException
/*      */   {
/* 1506 */     byte[] arrayOfByte = null;
/* 1507 */     String str = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1512 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1513 */     checkTrue((paramBFILE != null) && ((arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 1516 */     str = bfileGetDirAlias(this.m_nativeState, arrayOfByte, arrayOfByte.length);
/*      */     
/* 1518 */     checkError(str.length());
/*      */     
/* 1520 */     return str;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void openFile(BFILE paramBFILE)
/*      */     throws SQLException
/*      */   {
/* 1531 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1536 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1537 */     checkTrue((paramBFILE != null) && ((arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 1540 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 1542 */     checkError(bfileOpen(this.m_nativeState, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */     
/*      */ 
/* 1545 */     paramBFILE.setLocator(arrayOfByte1[0]);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public boolean isFileOpen(BFILE paramBFILE)
/*      */     throws SQLException
/*      */   {
/* 1560 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1565 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1566 */     checkTrue((paramBFILE != null) && ((arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 1569 */     boolean[] arrayOfBoolean = new boolean[1];
/*      */     
/* 1571 */     checkError(bfileIsOpen(this.m_nativeState, arrayOfByte, arrayOfByte.length, arrayOfBoolean));
/*      */     
/* 1573 */     return arrayOfBoolean[0];
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public boolean fileExists(BFILE paramBFILE)
/*      */     throws SQLException
/*      */   {
/* 1587 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1592 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1593 */     checkTrue((paramBFILE != null) && ((arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 1596 */     boolean[] arrayOfBoolean = new boolean[1];
/*      */     
/* 1598 */     checkError(bfileExists(this.m_nativeState, arrayOfByte, arrayOfByte.length, arrayOfBoolean));
/*      */     
/* 1600 */     return arrayOfBoolean[0];
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void closeFile(BFILE paramBFILE)
/*      */     throws SQLException
/*      */   {
/* 1611 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1616 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1617 */     checkTrue((paramBFILE != null) && ((arrayOfByte = paramBFILE.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 1620 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 1622 */     checkError(bfileClose(this.m_nativeState, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */     
/*      */ 
/* 1625 */     paramBFILE.setLocator(arrayOfByte1[0]);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void open(BFILE paramBFILE, int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1638 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1643 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1644 */     checkTrue((paramBFILE != null) && ((arrayOfByte = paramBFILE.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 1647 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 1649 */     checkError(lobOpen(this.m_nativeState, 114, arrayOfByte, arrayOfByte.length, paramInt, arrayOfByte1));
/*      */     
/*      */ 
/* 1652 */     paramBFILE.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void close(BFILE paramBFILE)
/*      */     throws SQLException
/*      */   {
/* 1663 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1668 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1669 */     checkTrue((paramBFILE != null) && ((arrayOfByte = paramBFILE.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 1672 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 1674 */     checkError(lobClose(this.m_nativeState, 114, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */     
/*      */ 
/* 1677 */     paramBFILE.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public boolean isOpen(BFILE paramBFILE)
/*      */     throws SQLException
/*      */   {
/* 1689 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1694 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1695 */     checkTrue((paramBFILE != null) && ((arrayOfByte = paramBFILE.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 1698 */     boolean[] arrayOfBoolean = new boolean[1];
/*      */     
/* 1700 */     checkError(lobIsOpen(this.m_nativeState, 114, arrayOfByte, arrayOfByte.length, arrayOfBoolean));
/*      */     
/*      */ 
/* 1703 */     return arrayOfBoolean[0];
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public InputStream newInputStream(BFILE paramBFILE, int paramInt, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 1723 */     if (paramLong == 0L)
/*      */     {
/* 1725 */       return new OracleBlobInputStream(paramBFILE, paramInt);
/*      */     }
/*      */     
/*      */ 
/* 1729 */     return new OracleBlobInputStream(paramBFILE, paramInt, paramLong);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public InputStream newConversionInputStream(BFILE paramBFILE, int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1749 */     checkTrue((paramBFILE != null) && (paramBFILE.shareBytes() != null), 54);
/*      */     
/*      */ 
/* 1752 */     OracleConversionInputStream localOracleConversionInputStream = new OracleConversionInputStream(this.conversion, paramBFILE.getBinaryStream(), paramInt);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1757 */     return localOracleConversionInputStream;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public Reader newConversionReader(BFILE paramBFILE, int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1777 */     checkTrue((paramBFILE != null) && (paramBFILE.shareBytes() != null), 54);
/*      */     
/*      */ 
/* 1780 */     OracleConversionReader localOracleConversionReader = new OracleConversionReader(this.conversion, paramBFILE.getBinaryStream(), paramInt);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1785 */     return localOracleConversionReader;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public long length(BLOB paramBLOB)
/*      */     throws SQLException
/*      */   {
/* 1797 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1802 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1803 */     checkTrue((paramBLOB != null) && ((arrayOfByte = paramBLOB.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 1806 */     return lobLength(arrayOfByte);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public long position(BLOB paramBLOB, byte[] paramArrayOfByte, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 1825 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1826 */     checkTrue((paramBLOB != null) && (paramBLOB.shareBytes() != null), 54);
/*      */     
/*      */ 
/* 1829 */     if (paramLong < 1L)
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/* 1834 */       DatabaseError.throwSqlException(68, "position()");
/*      */     }
/*      */     
/*      */ 
/* 1838 */     long l = LobPlsqlUtil.hasPattern(paramBLOB, paramArrayOfByte, paramLong);
/*      */     
/* 1840 */     l = l == 0L ? -1L : l;
/*      */     
/*      */ 
/*      */ 
/* 1844 */     return l;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public long position(BLOB paramBLOB1, BLOB paramBLOB2, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 1861 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1862 */     checkTrue((paramBLOB1 != null) && (paramBLOB1.shareBytes() != null), 54);
/*      */     
/* 1864 */     checkTrue((paramBLOB2 != null) && (paramBLOB2.shareBytes() != null), 54);
/*      */     
/*      */ 
/* 1867 */     if (paramLong < 1L)
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/* 1872 */       DatabaseError.throwSqlException(68, "position()");
/*      */     }
/*      */     
/*      */ 
/* 1876 */     long l = LobPlsqlUtil.isSubLob(paramBLOB1, paramBLOB2, paramLong);
/*      */     
/* 1878 */     l = l == 0L ? -1L : l;
/*      */     
/*      */ 
/*      */ 
/* 1882 */     return l;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public int getBytes(BLOB paramBLOB, long paramLong, int paramInt, byte[] paramArrayOfByte)
/*      */     throws SQLException
/*      */   {
/* 1897 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1902 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1903 */     checkTrue((paramBLOB != null) && ((arrayOfByte = paramBLOB.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 1906 */     if ((paramInt <= 0) || (paramArrayOfByte == null)) {
/* 1907 */       return 0;
/*      */     }
/* 1909 */     if (paramInt > paramArrayOfByte.length) {
/* 1910 */       paramInt = paramArrayOfByte.length;
/*      */     }
/* 1912 */     return blobRead(arrayOfByte, paramLong, paramInt, paramArrayOfByte);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public int putBytes(BLOB paramBLOB, long paramLong, byte[] paramArrayOfByte, int paramInt1, int paramInt2)
/*      */     throws SQLException
/*      */   {
/* 1929 */     checkTrue(paramLong >= 0L, 68);
/*      */     
/* 1931 */     int i = 0;
/*      */     
/* 1933 */     if ((paramArrayOfByte == null) || (paramArrayOfByte.length == 0) || (paramInt2 <= 0)) {
/* 1934 */       i = 0;
/*      */     }
/*      */     else {
/* 1937 */       byte[] arrayOfByte = null;
/*      */       
/* 1939 */       checkTrue(this.m_nativeState != 0L, 8);
/* 1940 */       checkTrue((paramBLOB != null) && ((arrayOfByte = paramBLOB.getLocator()) != null), 54);
/*      */       
/*      */ 
/* 1943 */       if (paramArrayOfByte == null) {
/* 1944 */         return 0;
/*      */       }
/* 1946 */       byte[][] arrayOfByte1 = new byte[1][];
/*      */       
/* 1948 */       i = blobWrite(arrayOfByte, paramLong, paramArrayOfByte, arrayOfByte1, paramInt1, paramInt2);
/*      */       
/*      */ 
/* 1951 */       paramBLOB.setLocator(arrayOfByte1[0]);
/*      */     }
/*      */     
/* 1954 */     return i;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public int getChunkSize(BLOB paramBLOB)
/*      */     throws SQLException
/*      */   {
/* 1964 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1969 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1970 */     checkTrue((paramBLOB != null) && ((arrayOfByte = paramBLOB.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 1973 */     return lobGetChunkSize(arrayOfByte);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void trim(BLOB paramBLOB, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 1985 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1990 */     checkTrue(this.m_nativeState != 0L, 8);
/* 1991 */     checkTrue((paramBLOB != null) && ((arrayOfByte = paramBLOB.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 1994 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 1996 */     checkError(lobTrim(this.m_nativeState, 113, paramLong, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */     
/*      */ 
/* 1999 */     paramBLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public BLOB createTemporaryBlob(Connection paramConnection, boolean paramBoolean, int paramInt)
/*      */     throws SQLException
/*      */   {
/* 2016 */     BLOB localBLOB = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2021 */     checkTrue(this.m_nativeState != 0L, 8);
/*      */     
/* 2023 */     localBLOB = new BLOB((PhysicalConnection)paramConnection);
/*      */     
/* 2025 */     byte[][] arrayOfByte = new byte[1][];
/*      */     
/* 2027 */     checkError(lobCreateTemporary(this.m_nativeState, 113, paramBoolean, paramInt, (short)0, arrayOfByte));
/*      */     
/*      */ 
/* 2030 */     localBLOB.setShareBytes(arrayOfByte[0]);
/*      */     
/* 2032 */     return localBLOB;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void freeTemporary(BLOB paramBLOB)
/*      */     throws SQLException
/*      */   {
/* 2044 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2049 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2050 */     checkTrue((paramBLOB != null) && ((arrayOfByte = paramBLOB.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 2053 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2055 */     checkError(lobFreeTemporary(this.m_nativeState, 113, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */     
/*      */ 
/* 2058 */     paramBLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public boolean isTemporary(BLOB paramBLOB)
/*      */     throws SQLException
/*      */   {
/* 2073 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2078 */     checkTrue((paramBLOB != null) && ((arrayOfByte = paramBLOB.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 2081 */     boolean[] arrayOfBoolean = new boolean[1];
/*      */     
/* 2083 */     checkError(lobIsTemporary(this.m_nativeState, 113, arrayOfByte, arrayOfByte.length, arrayOfBoolean));
/*      */     
/*      */ 
/* 2086 */     return arrayOfBoolean[0];
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void open(BLOB paramBLOB, int paramInt)
/*      */     throws SQLException
/*      */   {
/* 2097 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2102 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2103 */     checkTrue((paramBLOB != null) && ((arrayOfByte = paramBLOB.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 2106 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2108 */     checkError(lobOpen(this.m_nativeState, 113, arrayOfByte, arrayOfByte.length, paramInt, arrayOfByte1));
/*      */     
/*      */ 
/* 2111 */     paramBLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void close(BLOB paramBLOB)
/*      */     throws SQLException
/*      */   {
/* 2122 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2127 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2128 */     checkTrue((paramBLOB != null) && ((arrayOfByte = paramBLOB.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 2131 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2133 */     checkError(lobClose(this.m_nativeState, 113, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */     
/*      */ 
/* 2136 */     paramBLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public boolean isOpen(BLOB paramBLOB)
/*      */     throws SQLException
/*      */   {
/* 2148 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2153 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2154 */     checkTrue((paramBLOB != null) && ((arrayOfByte = paramBLOB.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 2157 */     boolean[] arrayOfBoolean = new boolean[1];
/*      */     
/* 2159 */     checkError(lobIsOpen(this.m_nativeState, 113, arrayOfByte, arrayOfByte.length, arrayOfBoolean));
/*      */     
/*      */ 
/* 2162 */     return arrayOfBoolean[0];
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public InputStream newInputStream(BLOB paramBLOB, int paramInt, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 2181 */     if (paramLong == 0L)
/*      */     {
/* 2183 */       return new OracleBlobInputStream(paramBLOB, paramInt);
/*      */     }
/*      */     
/*      */ 
/* 2187 */     return new OracleBlobInputStream(paramBLOB, paramInt, paramLong);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public OutputStream newOutputStream(BLOB paramBLOB, int paramInt, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 2207 */     if (paramLong == 0L)
/*      */     {
/* 2209 */       return new OracleBlobOutputStream(paramBLOB, paramInt);
/*      */     }
/*      */     
/*      */ 
/* 2213 */     return new OracleBlobOutputStream(paramBLOB, paramInt, paramLong);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public InputStream newConversionInputStream(BLOB paramBLOB, int paramInt)
/*      */     throws SQLException
/*      */   {
/* 2234 */     checkTrue((paramBLOB != null) && (paramBLOB.shareBytes() != null), 54);
/*      */     
/*      */ 
/* 2237 */     OracleConversionInputStream localOracleConversionInputStream = new OracleConversionInputStream(this.conversion, paramBLOB.getBinaryStream(), paramInt);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2242 */     return localOracleConversionInputStream;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public Reader newConversionReader(BLOB paramBLOB, int paramInt)
/*      */     throws SQLException
/*      */   {
/* 2261 */     checkTrue((paramBLOB != null) && (paramBLOB.shareBytes() != null), 54);
/*      */     
/*      */ 
/* 2264 */     OracleConversionReader localOracleConversionReader = new OracleConversionReader(this.conversion, paramBLOB.getBinaryStream(), paramInt);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2269 */     return localOracleConversionReader;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public long length(CLOB paramCLOB)
/*      */     throws SQLException
/*      */   {
/* 2285 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2290 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2291 */     checkTrue((paramCLOB != null) && ((arrayOfByte = paramCLOB.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 2294 */     return lobLength(arrayOfByte);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public long position(CLOB paramCLOB, String paramString, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 2312 */     if (paramString == null) {
/* 2313 */       throw new SQLException("pattern cannot be null.");
/*      */     }
/* 2315 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2316 */     checkTrue((paramCLOB != null) && (paramCLOB.shareBytes() != null), 54);
/*      */     
/*      */ 
/* 2319 */     if (paramLong < 1L)
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/* 2324 */       DatabaseError.throwSqlException(68, "position()");
/*      */     }
/*      */     
/*      */ 
/* 2328 */     char[] arrayOfChar = new char[paramString.length()];
/*      */     
/* 2330 */     paramString.getChars(0, arrayOfChar.length, arrayOfChar, 0);
/*      */     
/* 2332 */     long l = LobPlsqlUtil.hasPattern(paramCLOB, arrayOfChar, paramLong);
/*      */     
/* 2334 */     l = l == 0L ? -1L : l;
/*      */     
/*      */ 
/*      */ 
/* 2338 */     return l;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public long position(CLOB paramCLOB1, CLOB paramCLOB2, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 2355 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2356 */     checkTrue((paramCLOB1 != null) && (paramCLOB1.shareBytes() != null), 54);
/*      */     
/* 2358 */     checkTrue((paramCLOB2 != null) && (paramCLOB2.shareBytes() != null), 54);
/*      */     
/*      */ 
/* 2361 */     if (paramLong < 1L)
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/* 2366 */       DatabaseError.throwSqlException(68, "position()");
/*      */     }
/*      */     
/*      */ 
/* 2370 */     long l = LobPlsqlUtil.isSubLob(paramCLOB1, paramCLOB2, paramLong);
/*      */     
/* 2372 */     l = l == 0L ? -1L : l;
/*      */     
/*      */ 
/*      */ 
/* 2376 */     return l;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public int getChars(CLOB paramCLOB, long paramLong, int paramInt, char[] paramArrayOfChar)
/*      */     throws SQLException
/*      */   {
/* 2391 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2396 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2397 */     checkTrue((paramCLOB != null) && ((arrayOfByte = paramCLOB.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 2400 */     if ((paramInt <= 0) || (paramArrayOfChar == null)) {
/* 2401 */       return 0;
/*      */     }
/* 2403 */     if (paramInt > paramArrayOfChar.length) {
/* 2404 */       paramInt = paramArrayOfChar.length;
/*      */     }
/* 2406 */     int i = 0;
/*      */     
/* 2408 */     i = clobRead(this.m_nativeState, arrayOfByte, arrayOfByte.length, paramLong, paramInt, paramArrayOfChar, paramArrayOfChar.length, paramCLOB.isNCLOB());
/*      */     
/*      */ 
/* 2411 */     checkError(i);
/*      */     
/* 2413 */     return i;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public int putChars(CLOB paramCLOB, long paramLong, char[] paramArrayOfChar, int paramInt1, int paramInt2)
/*      */     throws SQLException
/*      */   {
/* 2432 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2437 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2438 */     checkTrue(paramLong >= 0L, 68);
/*      */     
/* 2440 */     checkTrue((paramCLOB != null) && ((arrayOfByte = paramCLOB.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 2443 */     if (paramArrayOfChar == null) {
/* 2444 */       return 0;
/*      */     }
/* 2446 */     byte[][] arrayOfByte1 = new byte[1][];
/* 2447 */     int i = clobWrite(arrayOfByte, paramLong, paramArrayOfChar, arrayOfByte1, paramCLOB.isNCLOB(), paramInt1, paramInt2);
/*      */     
/*      */ 
/* 2450 */     paramCLOB.setLocator(arrayOfByte1[0]);
/*      */     
/* 2452 */     return i;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public int getChunkSize(CLOB paramCLOB)
/*      */     throws SQLException
/*      */   {
/* 2462 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2467 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2468 */     checkTrue((paramCLOB != null) && ((arrayOfByte = paramCLOB.getLocator()) != null), 54);
/*      */     
/*      */ 
/* 2471 */     return lobGetChunkSize(arrayOfByte);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void trim(CLOB paramCLOB, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 2483 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2488 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2489 */     checkTrue((paramCLOB != null) && ((arrayOfByte = paramCLOB.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 2492 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2494 */     checkError(lobTrim(this.m_nativeState, 112, paramLong, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */     
/*      */ 
/* 2497 */     paramCLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public CLOB createTemporaryClob(Connection paramConnection, boolean paramBoolean, int paramInt, short paramShort)
/*      */     throws SQLException
/*      */   {
/* 2515 */     CLOB localCLOB = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2520 */     checkTrue(this.m_nativeState != 0L, 8);
/*      */     
/* 2522 */     localCLOB = new CLOB((PhysicalConnection)paramConnection);
/*      */     
/* 2524 */     byte[][] arrayOfByte = new byte[1][];
/*      */     
/* 2526 */     checkError(lobCreateTemporary(this.m_nativeState, 112, paramBoolean, paramInt, paramShort, arrayOfByte));
/*      */     
/*      */ 
/* 2529 */     localCLOB.setShareBytes(arrayOfByte[0]);
/*      */     
/* 2531 */     return localCLOB;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void freeTemporary(CLOB paramCLOB)
/*      */     throws SQLException
/*      */   {
/* 2543 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2548 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2549 */     checkTrue((paramCLOB != null) && ((arrayOfByte = paramCLOB.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 2552 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2554 */     checkError(lobFreeTemporary(this.m_nativeState, 112, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */     
/*      */ 
/* 2557 */     paramCLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public boolean isTemporary(CLOB paramCLOB)
/*      */     throws SQLException
/*      */   {
/* 2573 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2578 */     checkTrue((paramCLOB != null) && ((arrayOfByte = paramCLOB.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 2581 */     boolean[] arrayOfBoolean = new boolean[1];
/*      */     
/* 2583 */     checkError(lobIsTemporary(this.m_nativeState, 112, arrayOfByte, arrayOfByte.length, arrayOfBoolean));
/*      */     
/*      */ 
/* 2586 */     return arrayOfBoolean[0];
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void open(CLOB paramCLOB, int paramInt)
/*      */     throws SQLException
/*      */   {
/* 2597 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2602 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2603 */     checkTrue((paramCLOB != null) && ((arrayOfByte = paramCLOB.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 2606 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2608 */     checkError(lobOpen(this.m_nativeState, 112, arrayOfByte, arrayOfByte.length, paramInt, arrayOfByte1));
/*      */     
/*      */ 
/* 2611 */     paramCLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void close(CLOB paramCLOB)
/*      */     throws SQLException
/*      */   {
/* 2622 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2627 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2628 */     checkTrue((paramCLOB != null) && ((arrayOfByte = paramCLOB.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 2631 */     byte[][] arrayOfByte1 = new byte[1][];
/*      */     
/* 2633 */     checkError(lobClose(this.m_nativeState, 112, arrayOfByte, arrayOfByte.length, arrayOfByte1));
/*      */     
/*      */ 
/* 2636 */     paramCLOB.setShareBytes(arrayOfByte1[0]);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public boolean isOpen(CLOB paramCLOB)
/*      */     throws SQLException
/*      */   {
/* 2648 */     byte[] arrayOfByte = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2653 */     checkTrue(this.m_nativeState != 0L, 8);
/* 2654 */     checkTrue((paramCLOB != null) && ((arrayOfByte = paramCLOB.shareBytes()) != null), 54);
/*      */     
/*      */ 
/* 2657 */     boolean[] arrayOfBoolean = new boolean[1];
/*      */     
/* 2659 */     checkError(lobIsOpen(this.m_nativeState, 112, arrayOfByte, arrayOfByte.length, arrayOfBoolean));
/*      */     
/*      */ 
/* 2662 */     return arrayOfBoolean[0];
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public InputStream newInputStream(CLOB paramCLOB, int paramInt, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 2682 */     if (paramLong == 0L)
/*      */     {
/* 2684 */       return new OracleClobInputStream(paramCLOB, paramInt);
/*      */     }
/*      */     
/*      */ 
/* 2688 */     return new OracleClobInputStream(paramCLOB, paramInt, paramLong);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public OutputStream newOutputStream(CLOB paramCLOB, int paramInt, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 2708 */     if (paramLong == 0L)
/*      */     {
/* 2710 */       return new OracleClobOutputStream(paramCLOB, paramInt);
/*      */     }
/*      */     
/*      */ 
/* 2714 */     return new OracleClobOutputStream(paramCLOB, paramInt, paramLong);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public Reader newReader(CLOB paramCLOB, int paramInt, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 2734 */     if (paramLong == 0L)
/*      */     {
/* 2736 */       return new OracleClobReader(paramCLOB, paramInt);
/*      */     }
/*      */     
/*      */ 
/* 2740 */     return new OracleClobReader(paramCLOB, paramInt, paramLong);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public Writer newWriter(CLOB paramCLOB, int paramInt, long paramLong)
/*      */     throws SQLException
/*      */   {
/* 2760 */     if (paramLong == 0L)
/*      */     {
/* 2762 */       return new OracleClobWriter(paramCLOB, paramInt);
/*      */     }
/*      */     
/*      */ 
/* 2766 */     return new OracleClobWriter(paramCLOB, paramInt, paramLong);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void registerTAFCallback(OracleOCIFailover paramOracleOCIFailover, Object paramObject)
/*      */     throws SQLException
/*      */   {
/* 2791 */     this.appCallback = paramOracleOCIFailover;
/* 2792 */     this.appCallbackObject = paramObject;
/*      */     
/* 2794 */     checkError(t2cRegisterTAFCallback(this.m_nativeState));
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   synchronized int callTAFCallbackMethod(int paramInt1, int paramInt2)
/*      */   {
/* 2802 */     int i = 0;
/*      */     
/*      */ 
/* 2805 */     if (this.appCallback != null) {
/* 2806 */       i = this.appCallback.callbackFn(this, this.appCallbackObject, paramInt1, paramInt2);
/*      */     }
/* 2808 */     return i;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public int getHeapAllocSize()
/*      */     throws SQLException
/*      */   {
/* 2822 */     if (this.lifecycle != 1) {
/* 2823 */       DatabaseError.throwSqlException(8);
/*      */     }
/*      */     
/*      */ 
/* 2827 */     int i = t2cGetHeapAllocSize(this.m_nativeState);
/*      */     
/* 2829 */     if (i < 0)
/*      */     {
/* 2831 */       if (i == 64537) {
/* 2832 */         DatabaseError.throwSqlException(23);
/*      */       }
/*      */       
/*      */ 
/* 2836 */       DatabaseError.throwSqlException(89);
/*      */     }
/*      */     
/* 2839 */     return i;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public int getOCIEnvHeapAllocSize()
/*      */     throws SQLException
/*      */   {
/* 2854 */     if (this.lifecycle != 1) {
/* 2855 */       DatabaseError.throwSqlException(8);
/*      */     }
/*      */     
/*      */ 
/* 2859 */     int i = t2cGetOciEnvHeapAllocSize(this.m_nativeState);
/*      */     
/* 2861 */     if (i < 0)
/*      */     {
/* 2863 */       if (i == 64537) {
/* 2864 */         DatabaseError.throwSqlException(23);
/*      */       } else {
/* 2866 */         checkError(i);
/*      */       }
/*      */       
/* 2869 */       DatabaseError.throwSqlException(89);
/*      */     }
/*      */     
/* 2872 */     return i;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public static final short getClientCharSetId()
/*      */   {
/* 2881 */     return 871;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public static short getDriverCharSetIdFromNLS_LANG(Properties paramProperties)
/*      */     throws SQLException
/*      */   {
/* 2897 */     if (!isLibraryLoaded) {
/* 2898 */       loadNativeLibrary(paramProperties);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 2903 */     short s = t2cGetDriverCharSetFromNlsLang();
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2908 */     if (s < 0) {
/* 2909 */       DatabaseError.throwSqlException(8);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 2914 */     return s;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   void doProxySession(int paramInt, Properties paramProperties)
/*      */     throws SQLException
/*      */   {
/* 2925 */     byte[][] arrayOfByte = (byte[][])null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2931 */     int i = 0;
/*      */     
/* 2933 */     this.savedUser = this.user;
/* 2934 */     this.user = null;
/*      */     byte[] arrayOfByte4;
/* 2936 */     byte[] arrayOfByte3; byte[] arrayOfByte2; byte[] arrayOfByte1 = arrayOfByte2 = arrayOfByte3 = arrayOfByte4 = new byte[0];
/*      */     
/* 2938 */     switch (paramInt)
/*      */     {
/*      */     case 1: 
/* 2941 */       this.user = paramProperties.getProperty("PROXY_USER_NAME");
/* 2942 */       String str1 = paramProperties.getProperty("PROXY_USER_PASSWORD");
/* 2943 */       if (this.user != null) {
/* 2944 */         arrayOfByte1 = DBConversion.stringToDriverCharBytes(this.user, this.m_clientCharacterSet);
/*      */       }
/* 2946 */       if (str1 != null)
/* 2947 */         arrayOfByte2 = DBConversion.stringToAsciiBytes(str1);
/*      */       break;
/*      */     case 2: 
/* 2950 */       String str2 = paramProperties.getProperty("PROXY_DISTINGUISHED_NAME");
/* 2951 */       if (str2 != null) {
/* 2952 */         arrayOfByte3 = DBConversion.stringToDriverCharBytes(str2, this.m_clientCharacterSet);
/*      */       }
/*      */       break;
/*      */     case 3: 
/* 2956 */       Object localObject = paramProperties.get("PROXY_CERTIFICATE");
/* 2957 */       arrayOfByte4 = (byte[])localObject;
/*      */     }
/*      */     
/* 2960 */     String[] arrayOfString = (String[])paramProperties.get("PROXY_ROLES");
/*      */     
/* 2962 */     if (arrayOfString != null)
/*      */     {
/* 2964 */       i = arrayOfString.length;
/* 2965 */       arrayOfByte = new byte[i][];
/* 2966 */       for (int j = 0; j < i; j++)
/*      */       {
/* 2968 */         if (arrayOfString[j] == null) {
/* 2969 */           DatabaseError.throwSqlException(150);
/*      */         }
/* 2971 */         arrayOfByte[j] = DBConversion.stringToDriverCharBytes(arrayOfString[j], this.m_clientCharacterSet);
/*      */       }
/*      */     }
/*      */     
/*      */ 
/* 2976 */     this.sqlWarning = checkError(t2cDoProxySession(this.m_nativeState, paramInt, arrayOfByte1, arrayOfByte1.length, arrayOfByte2, arrayOfByte2.length, arrayOfByte3, arrayOfByte3.length, arrayOfByte4, arrayOfByte4.length, i, arrayOfByte), this.sqlWarning);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2990 */     this.isProxy = true;
/*      */   }
/*      */   
/*      */   void closeProxySession() throws SQLException
/*      */   {
/* 2995 */     checkError(t2cCloseProxySession(this.m_nativeState));
/* 2996 */     this.user = this.savedUser;
/*      */   }
/*      */   
/*      */   protected void doDescribeTable(AutoKeyInfo paramAutoKeyInfo)
/*      */     throws SQLException
/*      */   {
/* 3002 */     String str = paramAutoKeyInfo.getTableName();
/*      */     
/* 3004 */     byte[] arrayOfByte = DBConversion.stringToDriverCharBytes(str, this.m_clientCharacterSet);
/*      */     
/*      */ 
/* 3007 */     int i = 0;
/*      */     
/*      */     int j;
/*      */     do
/*      */     {
/* 3012 */       j = t2cDescribeTable(this.m_nativeState, arrayOfByte, arrayOfByte.length, this.queryMetaData1, this.queryMetaData2, this.queryMetaData1Offset, this.queryMetaData2Offset, this.queryMetaData1Size, this.queryMetaData2Size);
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3022 */       if (j == -1)
/*      */       {
/* 3024 */         checkError(j);
/*      */       }
/*      */       
/*      */ 
/* 3028 */       if (j == T2CStatement.T2C_EXTEND_BUFFER)
/*      */       {
/* 3030 */         i = 1;
/*      */         
/* 3032 */         reallocateQueryMetaData(this.queryMetaData1Size * 2, this.queryMetaData2Size * 2);
/*      */       }
/*      */       
/* 3035 */     } while (i != 0);
/*      */     
/* 3037 */     processDescribeTableData(j, paramAutoKeyInfo);
/*      */   }
/*      */   
/*      */ 
/*      */   private void processDescribeTableData(int paramInt, AutoKeyInfo paramAutoKeyInfo)
/*      */     throws SQLException
/*      */   {
/* 3044 */     short[] arrayOfShort = this.queryMetaData1;
/* 3045 */     byte[] arrayOfByte = this.queryMetaData2;
/* 3046 */     int i = this.queryMetaData1Offset;
/* 3047 */     int j = this.queryMetaData2Offset;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3061 */     paramAutoKeyInfo.allocateSpaceForDescribedData(paramInt);
/*      */     
/* 3063 */     for (int i5 = 0; i5 < paramInt; i5++)
/*      */     {
/* 3065 */       int m = arrayOfShort[(i + 0)];
/* 3066 */       int k = arrayOfShort[(i + 6)];
/* 3067 */       String str1 = bytes2String(arrayOfByte, j, k, this.conversion);
/*      */       
/*      */ 
/* 3070 */       int n = arrayOfShort[(i + 1)];
/* 3071 */       int i1 = arrayOfShort[(i + 11)];
/* 3072 */       boolean bool = arrayOfShort[(i + 2)] != 0;
/* 3073 */       short s = arrayOfShort[(i + 5)];
/* 3074 */       int i2 = arrayOfShort[(i + 3)];
/* 3075 */       int i3 = arrayOfShort[(i + 4)];
/* 3076 */       int i4 = arrayOfShort[(i + 12)];
/*      */       
/* 3078 */       j += k;
/* 3079 */       i += 13;
/*      */       
/* 3081 */       String str2 = null;
/* 3082 */       if (i4 > 0)
/*      */       {
/* 3084 */         str2 = bytes2String(arrayOfByte, j, i4, this.conversion);
/*      */         
/* 3086 */         j += i4;
/*      */       }
/*      */       
/*      */ 
/* 3090 */       paramAutoKeyInfo.fillDescribedData(i5, str1, m, i1 > 0 ? i1 : n, bool, s, i2, i3, str2);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   void doSetApplicationContext(String paramString1, String paramString2, String paramString3)
/*      */     throws SQLException
/*      */   {
/* 3102 */     checkError(t2cSetApplicationContext(this.m_nativeState, paramString1, paramString2, paramString3));
/*      */   }
/*      */   
/*      */ 
/*      */   void doClearAllApplicationContext(String paramString)
/*      */     throws SQLException
/*      */   {
/* 3109 */     checkError(t2cClearAllApplicationContext(this.m_nativeState, paramString));
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private static final void loadNativeLibrary(Properties paramProperties)
/*      */     throws SQLException
/*      */   {
/* 3119 */     String str = null;
/* 3120 */     if (paramProperties != null) {
/* 3121 */       str = paramProperties.getProperty("oracle.jdbc.ocinativelibrary");
/*      */     }
/*      */     
/*      */ 
/* 3125 */     if ((str == null) || (str.equals("ocijdbc10")))
/*      */     {
/* 3127 */       synchronized (T2CConnection.class)
/*      */       {
/* 3129 */         if (!isLibraryLoaded)
/*      */         {
/* 3131 */           AccessController.doPrivileged(new PrivilegedAction()
/*      */           {
/*      */             public Object run()
/*      */             {
/* 3135 */               System.loadLibrary("ocijdbc10");
/* 3136 */               return null;
/*      */             }
/* 3138 */           });
/* 3139 */           isLibraryLoaded = true;
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3148 */     synchronized (T2CConnection.class)
/*      */     {
/*      */       try
/*      */       {
/* 3152 */         System.loadLibrary(str);
/* 3153 */         isLibraryLoaded = true;
/*      */       }
/*      */       catch (SecurityException localSecurityException)
/*      */       {
/* 3157 */         if (!isLibraryLoaded)
/*      */         {
/* 3159 */           System.loadLibrary(str);
/* 3160 */           isLibraryLoaded = true;
/*      */         }
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private final void checkTrue(boolean paramBoolean, int paramInt)
/*      */     throws SQLException
/*      */   {
/* 3173 */     if (!paramBoolean) {
/* 3174 */       DatabaseError.throwSqlException(paramInt);
/*      */     }
/*      */   }
/*      */   
/*      */   boolean useLittleEndianSetCHARBinder() throws SQLException {
/* 3179 */     return t2cPlatformIsLittleEndian(this.m_nativeState);
/*      */   }
/*      */   
/*      */   public void getPropertyForPooledConnection(OraclePooledConnection paramOraclePooledConnection)
/*      */     throws SQLException
/*      */   {
/* 3185 */     super.getPropertyForPooledConnection(paramOraclePooledConnection, this.password);
/*      */   }
/*      */   
/*      */   static final char[] getCharArray(String paramString)
/*      */   {
/* 3190 */     char[] arrayOfChar = null;
/*      */     
/* 3192 */     if (paramString == null)
/*      */     {
/* 3194 */       arrayOfChar = new char[0];
/*      */     }
/*      */     else
/*      */     {
/* 3198 */       arrayOfChar = new char[paramString.length()];
/*      */       
/* 3200 */       paramString.getChars(0, paramString.length(), arrayOfChar, 0);
/*      */     }
/*      */     
/* 3203 */     return arrayOfChar;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   static String bytes2String(byte[] paramArrayOfByte, int paramInt1, int paramInt2, DBConversion paramDBConversion)
/*      */     throws SQLException
/*      */   {
/* 3211 */     byte[] arrayOfByte = new byte[paramInt2];
/* 3212 */     System.arraycopy(paramArrayOfByte, paramInt1, arrayOfByte, 0, paramInt2);
/*      */     
/* 3214 */     return paramDBConversion.CharBytesToString(arrayOfByte, paramInt2);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3353 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Wed_Jun_22_11:18:52_PDT_2005";
/*      */   
/*      */   static native short t2cGetServerSessionInfo(long paramLong, Properties paramProperties);
/*      */   
/*      */   static native short t2cGetDriverCharSetFromNlsLang();
/*      */   
/*      */   native int t2cDescribeError(long paramLong, T2CError paramT2CError, byte[] paramArrayOfByte);
/*      */   
/*      */   native int t2cCreateState(byte[] paramArrayOfByte1, int paramInt1, byte[] paramArrayOfByte2, int paramInt2, byte[] paramArrayOfByte3, int paramInt3, byte[] paramArrayOfByte4, int paramInt4, short paramShort, int paramInt5, short[] paramArrayOfShort, byte[] paramArrayOfByte5, byte[] paramArrayOfByte6);
/*      */   
/*      */   native int t2cLogon(long paramLong, byte[] paramArrayOfByte1, int paramInt1, byte[] paramArrayOfByte2, int paramInt2, byte[] paramArrayOfByte3, int paramInt3, byte[] paramArrayOfByte4, int paramInt4, int paramInt5, short[] paramArrayOfShort, byte[] paramArrayOfByte5, byte[] paramArrayOfByte6);
/*      */   
/*      */   private native int t2cLogoff(long paramLong);
/*      */   
/*      */   private native int t2cCancel(long paramLong);
/*      */   
/*      */   private native int t2cCreateStatement(long paramLong1, long paramLong2, byte[] paramArrayOfByte, int paramInt1, OracleStatement paramOracleStatement, boolean paramBoolean, int paramInt2);
/*      */   
/*      */   private native int t2cSetAutoCommit(long paramLong, boolean paramBoolean);
/*      */   
/*      */   private native int t2cCommit(long paramLong);
/*      */   
/*      */   private native int t2cRollback(long paramLong);
/*      */   
/*      */   private native byte[] t2cGetProductionVersion(long paramLong);
/*      */   
/*      */   private native int t2cGetVersionNumber(long paramLong);
/*      */   
/*      */   private native int t2cGetDefaultStreamChunkSize(long paramLong);
/*      */   
/*      */   native int t2cGetFormOfUse(long paramLong, OracleTypeCLOB paramOracleTypeCLOB, byte[] paramArrayOfByte, int paramInt1, int paramInt2);
/*      */   
/*      */   native long t2cGetTDO(long paramLong, byte[] paramArrayOfByte, int paramInt, int[] paramArrayOfInt);
/*      */   
/*      */   native int t2cCreateConnPool(byte[] paramArrayOfByte1, int paramInt1, byte[] paramArrayOfByte2, int paramInt2, byte[] paramArrayOfByte3, int paramInt3, short paramShort, int paramInt4, int paramInt5, int paramInt6, int paramInt7, int paramInt8, int paramInt9, int paramInt10);
/*      */   
/*      */   native int t2cConnPoolLogon(long paramLong, byte[] paramArrayOfByte1, int paramInt1, byte[] paramArrayOfByte2, int paramInt2, byte[] paramArrayOfByte3, int paramInt3, int paramInt4, int paramInt5, int paramInt6, String[] paramArrayOfString, byte[] paramArrayOfByte4, int paramInt7, byte[] paramArrayOfByte5, int paramInt8, byte[] paramArrayOfByte6, int paramInt9, byte[] paramArrayOfByte7, int paramInt10, byte[] paramArrayOfByte8, int paramInt11, short[] paramArrayOfShort, byte[] paramArrayOfByte9, byte[] paramArrayOfByte10);
/*      */   
/*      */   native int t2cGetConnPoolInfo(long paramLong, Properties paramProperties);
/*      */   
/*      */   native int t2cSetConnPoolInfo(long paramLong, int paramInt1, int paramInt2, int paramInt3, int paramInt4, int paramInt5, int paramInt6);
/*      */   
/*      */   native int t2cPasswordChange(long paramLong, byte[] paramArrayOfByte1, int paramInt1, byte[] paramArrayOfByte2, int paramInt2, byte[] paramArrayOfByte3, int paramInt3);
/*      */   
/*      */   protected native byte[] t2cGetConnectionId(long paramLong);
/*      */   
/*      */   native int t2cGetHandles(long paramLong, long[] paramArrayOfLong);
/*      */   
/*      */   native int t2cUseConnection(long paramLong1, long paramLong2, long paramLong3, long paramLong4, short[] paramArrayOfShort);
/*      */   
/*      */   native boolean t2cPlatformIsLittleEndian(long paramLong);
/*      */   
/*      */   native int t2cRegisterTAFCallback(long paramLong);
/*      */   
/*      */   native int t2cGetHeapAllocSize(long paramLong);
/*      */   
/*      */   native int t2cGetOciEnvHeapAllocSize(long paramLong);
/*      */   
/*      */   native int t2cDoProxySession(long paramLong, int paramInt1, byte[] paramArrayOfByte1, int paramInt2, byte[] paramArrayOfByte2, int paramInt3, byte[] paramArrayOfByte3, int paramInt4, byte[] paramArrayOfByte4, int paramInt5, int paramInt6, byte[][] paramArrayOfByte);
/*      */   
/*      */   native int t2cCloseProxySession(long paramLong);
/*      */   
/*      */   static native int t2cDescribeTable(long paramLong, byte[] paramArrayOfByte1, int paramInt1, short[] paramArrayOfShort, byte[] paramArrayOfByte2, int paramInt2, int paramInt3, int paramInt4, int paramInt5);
/*      */   
/*      */   native int t2cSetApplicationContext(long paramLong, String paramString1, String paramString2, String paramString3);
/*      */   
/*      */   native int t2cClearAllApplicationContext(long paramLong, String paramString);
/*      */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\ojdbc14.jar!\oracle\jdbc\driver\T2CConnection.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       0.7.1
 */