/*      */ package oracle.jdbc.pool;
/*      */ 
/*      */ import java.io.UnsupportedEncodingException;
/*      */ import java.security.AccessController;
/*      */ import java.security.PrivilegedActionException;
/*      */ import java.security.PrivilegedExceptionAction;
/*      */ import java.sql.SQLException;
/*      */ import java.util.Collection;
/*      */ import java.util.Enumeration;
/*      */ import java.util.Hashtable;
/*      */ import java.util.Iterator;
/*      */ import java.util.Properties;
/*      */ import java.util.Set;
/*      */ import java.util.StringTokenizer;
/*      */ import javax.sql.ConnectionPoolDataSource;
/*      */ import oracle.jdbc.driver.DatabaseError;
/*      */ import oracle.ons.ONS;
/*      */ import oracle.ons.ONSException;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public class OracleConnectionCacheManager
/*      */ {
/*   55 */   private static OracleConnectionCacheManager cacheManagerInstance = null;
/*      */   
/*   57 */   protected Hashtable m_connCache = null;
/*      */   
/*      */ 
/*      */   public static final int REFRESH_INVALID_CONNECTIONS = 4096;
/*      */   
/*      */ 
/*      */   public static final int REFRESH_ALL_CONNECTIONS = 8192;
/*      */   
/*      */   protected static final int FAILOVER_EVENT_TYPE_SERVICE = 256;
/*      */   
/*      */   protected static final int FAILOVER_EVENT_TYPE_HOST = 512;
/*      */   
/*      */   protected static final String EVENT_DELIMITER = "{} =";
/*      */   
/*   71 */   protected OracleFailoverEventHandlerThread failoverEventHandlerThread = null;
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*   76 */   private static boolean isONSInitializedForRemoteSubscription = false;
/*      */   
/*      */   static final int ORAERROR_END_OF_FILE_ON_COM_CHANNEL = 3113;
/*      */   
/*      */   static final int ORAERROR_NOT_CONNECTED_TO_ORACLE = 3114;
/*      */   
/*      */   static final int ORAERROR_INIT_SHUTDOWN_IN_PROGRESS = 1033;
/*      */   
/*      */   static final int ORAERROR_ORACLE_NOT_AVAILABLE = 1034;
/*      */   
/*      */   static final int ORAERROR_IMMEDIATE_SHUTDOWN_IN_PROGRESS = 1089;
/*      */   static final int ORAERROR_SHUTDOWN_IN_PROGRESS_NO_CONN = 1090;
/*      */   static final int ORAERROR_NET_IO_EXCEPTION = 17002;
/*   89 */   protected int[] fatalErrorCodes = null;
/*   90 */   protected int failoverEnabledCacheCount = 0;
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private OracleConnectionCacheManager()
/*      */   {
/*  100 */     this.m_connCache = new Hashtable();
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public static synchronized OracleConnectionCacheManager getConnectionCacheManagerInstance()
/*      */     throws SQLException
/*      */   {
/*      */     try
/*      */     {
/*  117 */       if (cacheManagerInstance == null) {
/*  118 */         cacheManagerInstance = new OracleConnectionCacheManager();
/*      */       }
/*      */     }
/*      */     catch (RuntimeException localRuntimeException) {}
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*  126 */     return cacheManagerInstance;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public String createCache(OracleDataSource paramOracleDataSource, Properties paramProperties)
/*      */     throws SQLException
/*      */   {
/*  146 */     String str = null;
/*      */     
/*  148 */     if ((paramOracleDataSource == null) || (!paramOracleDataSource.getConnectionCachingEnabled()))
/*      */     {
/*  150 */       DatabaseError.throwSqlException(137);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  157 */     if (paramOracleDataSource.connCacheName != null)
/*      */     {
/*  159 */       str = paramOracleDataSource.connCacheName;
/*      */     }
/*      */     else
/*      */     {
/*  163 */       str = paramOracleDataSource.dataSourceName + "#0x" + Integer.toHexString(this.m_connCache.size());
/*      */     }
/*      */     
/*      */ 
/*  167 */     createCache(str, paramOracleDataSource, paramProperties);
/*      */     
/*  169 */     return str;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void createCache(String paramString, OracleDataSource paramOracleDataSource, Properties paramProperties)
/*      */     throws SQLException
/*      */   {
/*  190 */     if ((paramOracleDataSource == null) || (!paramOracleDataSource.getConnectionCachingEnabled()))
/*      */     {
/*  192 */       DatabaseError.throwSqlException(137);
/*      */     }
/*      */     
/*  195 */     if (paramString == null)
/*      */     {
/*  197 */       DatabaseError.throwSqlException(138);
/*      */     }
/*      */     
/*      */ 
/*  201 */     if (this.m_connCache.containsKey(paramString))
/*      */     {
/*  203 */       DatabaseError.throwSqlException(140);
/*      */     }
/*      */     
/*  206 */     boolean bool = paramOracleDataSource.getFastConnectionFailoverEnabled();
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  214 */     if ((bool) && (this.failoverEventHandlerThread == null))
/*      */     {
/*      */ 
/*      */ 
/*  218 */       localObject1 = paramOracleDataSource.getONSConfiguration();
/*      */       
/*      */ 
/*      */ 
/*  222 */       if ((localObject1 != null) && (!((String)localObject1).equals("")))
/*      */       {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  230 */         synchronized (this)
/*      */         {
/*  232 */           if (!isONSInitializedForRemoteSubscription)
/*      */           {
/*      */ 
/*      */             try
/*      */             {
/*  237 */               AccessController.doPrivileged(new PrivilegedExceptionAction()
/*      */               {
/*      */                 private final String val$onsConfigStr;
/*      */                 
/*      */ 
/*      */                 public Object run()
/*      */                   throws ONSException
/*      */                 {
/*  245 */                   ONS localONS = new ONS(this.val$onsConfigStr);
/*  246 */                   return null;
/*      */                 }
/*      */               });
/*      */             }
/*      */             catch (PrivilegedActionException localPrivilegedActionException)
/*      */             {
/*  252 */               DatabaseError.throwSqlException(175, localPrivilegedActionException);
/*      */             }
/*      */             
/*      */ 
/*  256 */             isONSInitializedForRemoteSubscription = true;
/*      */           }
/*      */         }
/*      */       }
/*      */       
/*  261 */       this.failoverEventHandlerThread = new OracleFailoverEventHandlerThread();
/*      */     }
/*      */     
/*      */ 
/*  265 */     Object localObject1 = new OracleImplicitConnectionCache(paramOracleDataSource, paramProperties);
/*      */     
/*      */ 
/*  268 */     ((OracleImplicitConnectionCache)localObject1).cacheName = paramString;
/*  269 */     paramOracleDataSource.odsCache = ((OracleImplicitConnectionCache)localObject1);
/*      */     
/*      */ 
/*  272 */     this.m_connCache.put(paramString, localObject1);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  280 */     if (bool)
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/*  285 */       checkAndStartThread(this.failoverEventHandlerThread);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void removeCache(String paramString, long paramLong)
/*      */     throws SQLException
/*      */   {
/*  309 */     OracleImplicitConnectionCache localOracleImplicitConnectionCache = paramString != null ? (OracleImplicitConnectionCache)this.m_connCache.remove(paramString) : null;
/*      */     
/*      */ 
/*  312 */     if (localOracleImplicitConnectionCache != null)
/*      */     {
/*  314 */       localOracleImplicitConnectionCache.disableConnectionCache();
/*      */       
/*      */ 
/*  317 */       if (paramLong > 0L)
/*      */       {
/*      */         try
/*      */         {
/*  321 */           Thread.currentThread();Thread.sleep(paramLong * 1000L);
/*      */         }
/*      */         catch (InterruptedException localInterruptedException) {}
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  331 */       if (localOracleImplicitConnectionCache.cacheEnabledDS.getFastConnectionFailoverEnabled()) {
/*  332 */         cleanupFCFThreads(localOracleImplicitConnectionCache);
/*      */       }
/*      */       
/*  335 */       localOracleImplicitConnectionCache.closeConnectionCache();
/*      */       
/*  337 */       localOracleImplicitConnectionCache = null;
/*      */     }
/*      */     else
/*      */     {
/*  341 */       DatabaseError.throwSqlException(141);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void reinitializeCache(String paramString, Properties paramProperties)
/*      */     throws SQLException
/*      */   {
/*  359 */     Object localObject = paramString != null ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */     
/*      */ 
/*  362 */     if (localObject != null)
/*      */     {
/*  364 */       disableCache(paramString);
/*  365 */       ((OracleImplicitConnectionCache)localObject).reinitializeCacheConnections(paramProperties);
/*  366 */       enableCache(paramString);
/*      */     }
/*      */     else
/*      */     {
/*  370 */       DatabaseError.throwSqlException(141);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public boolean existsCache(String paramString)
/*      */     throws SQLException
/*      */   {
/*  389 */     return this.m_connCache.containsKey(paramString);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void enableCache(String paramString)
/*      */     throws SQLException
/*      */   {
/*  404 */     Object localObject = paramString != null ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */     
/*      */ 
/*  407 */     if (localObject != null)
/*      */     {
/*  409 */       ((OracleImplicitConnectionCache)localObject).enableConnectionCache();
/*      */     }
/*      */     else
/*      */     {
/*  413 */       DatabaseError.throwSqlException(141);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void disableCache(String paramString)
/*      */     throws SQLException
/*      */   {
/*  431 */     Object localObject = paramString != null ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */     
/*      */ 
/*  434 */     if (localObject != null)
/*      */     {
/*  436 */       ((OracleImplicitConnectionCache)localObject).disableConnectionCache();
/*      */     }
/*      */     else
/*      */     {
/*  440 */       DatabaseError.throwSqlException(141);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void refreshCache(String paramString, int paramInt)
/*      */     throws SQLException
/*      */   {
/*  460 */     Object localObject = paramString != null ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */     
/*      */ 
/*  463 */     if (localObject != null)
/*      */     {
/*  465 */       if ((paramInt == 4096) || (paramInt == 8192))
/*      */       {
/*  467 */         ((OracleImplicitConnectionCache)localObject).refreshCacheConnections(paramInt);
/*      */       } else {
/*  469 */         DatabaseError.throwSqlException(68);
/*      */       }
/*      */     }
/*      */     else {
/*  473 */       DatabaseError.throwSqlException(141);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void purgeCache(String paramString, boolean paramBoolean)
/*      */     throws SQLException
/*      */   {
/*  495 */     Object localObject = paramString != null ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */     
/*      */ 
/*  498 */     if (localObject != null)
/*      */     {
/*  500 */       ((OracleImplicitConnectionCache)localObject).purgeCacheConnections(paramBoolean);
/*      */     }
/*      */     else
/*      */     {
/*  504 */       DatabaseError.throwSqlException(141);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public Properties getCacheProperties(String paramString)
/*      */     throws SQLException
/*      */   {
/*  524 */     Object localObject = paramString != null ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */     
/*      */ 
/*  527 */     if (localObject != null)
/*      */     {
/*  529 */       return ((OracleImplicitConnectionCache)localObject).getConnectionCacheProperties();
/*      */     }
/*      */     
/*      */ 
/*  533 */     DatabaseError.throwSqlException(141);
/*      */     
/*      */ 
/*  536 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public String[] getCacheNameList()
/*      */     throws SQLException
/*      */   {
/*  551 */     return (String[])this.m_connCache.keySet().toArray(new String[this.m_connCache.size()]);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public int getNumberOfAvailableConnections(String paramString)
/*      */     throws SQLException
/*      */   {
/*  568 */     Object localObject = paramString != null ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */     
/*      */ 
/*  571 */     if (localObject != null)
/*      */     {
/*  573 */       return ((OracleImplicitConnectionCache)localObject).cacheSize;
/*      */     }
/*      */     
/*      */ 
/*  577 */     DatabaseError.throwSqlException(141);
/*      */     
/*      */ 
/*  580 */     return 0;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public int getNumberOfActiveConnections(String paramString)
/*      */     throws SQLException
/*      */   {
/*  595 */     Object localObject = paramString != null ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */     
/*      */ 
/*  598 */     if (localObject != null)
/*      */     {
/*  600 */       return ((OracleImplicitConnectionCache)localObject).getNumberOfCheckedOutConnections();
/*      */     }
/*      */     
/*      */ 
/*  604 */     DatabaseError.throwSqlException(141);
/*      */     
/*      */ 
/*  607 */     return 0;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void setConnectionPoolDataSource(String paramString, ConnectionPoolDataSource paramConnectionPoolDataSource)
/*      */     throws SQLException
/*      */   {
/*  631 */     Object localObject = paramString != null ? (OracleImplicitConnectionCache)this.m_connCache.get(paramString) : null;
/*      */     
/*      */ 
/*  634 */     if (localObject != null)
/*      */     {
/*  636 */       if (((OracleImplicitConnectionCache)localObject).cacheSize > 0)
/*      */       {
/*  638 */         DatabaseError.throwSqlException(78);
/*      */       }
/*      */       else
/*      */       {
/*  642 */         ((OracleConnectionPoolDataSource)paramConnectionPoolDataSource).makeURL();
/*  643 */         ((OracleConnectionPoolDataSource)paramConnectionPoolDataSource).setURL(((OracleConnectionPoolDataSource)paramConnectionPoolDataSource).url);
/*      */         
/*  645 */         ((OracleImplicitConnectionCache)localObject).connectionPoolDS = ((OracleConnectionPoolDataSource)paramConnectionPoolDataSource);
/*      */       }
/*      */       
/*      */     }
/*      */     else {
/*  650 */       DatabaseError.throwSqlException(141);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void verifyAndHandleEvent(int paramInt, byte[] paramArrayOfByte)
/*      */     throws SQLException
/*      */   {
/*  671 */     Object localObject1 = null;
/*  672 */     String str1 = null;
/*  673 */     String str2 = null;
/*  674 */     String str3 = null;
/*  675 */     Object localObject2 = null;
/*      */     
/*  677 */     int i = 0;
/*  678 */     StringTokenizer localStringTokenizer = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */     try
/*      */     {
/*  685 */       localStringTokenizer = new StringTokenizer(new String(paramArrayOfByte, "UTF-8"), "{} =", true);
/*      */     }
/*      */     catch (UnsupportedEncodingException localUnsupportedEncodingException) {}
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  694 */     String str4 = null;
/*  695 */     String str5 = null;
/*  696 */     String str6 = null;
/*      */     
/*      */ 
/*      */ 
/*  700 */     while (localStringTokenizer.hasMoreTokens())
/*      */     {
/*  702 */       str5 = null;
/*  703 */       str4 = localStringTokenizer.nextToken();
/*  704 */       if ((str4.equals("=")) && (localStringTokenizer.hasMoreTokens()))
/*      */       {
/*  706 */         str5 = localStringTokenizer.nextToken();
/*      */       }
/*      */       else
/*      */       {
/*  710 */         str6 = str4;
/*      */       }
/*      */       
/*  713 */       if ((str6.equalsIgnoreCase("version")) && (str5 != null) && (!str5.equals("1.0")))
/*      */       {
/*      */ 
/*  716 */         DatabaseError.throwSqlException(146);
/*      */       }
/*      */       
/*  719 */       if ((str6.equalsIgnoreCase("service")) && (str5 != null)) {
/*  720 */         localObject1 = str5;
/*      */       }
/*  722 */       if ((str6.equalsIgnoreCase("instance")) && (str5 != null) && (!str5.equals(" ")))
/*      */       {
/*      */ 
/*  725 */         str1 = str5.intern();
/*      */       }
/*      */       
/*  728 */       if ((str6.equalsIgnoreCase("database")) && (str5 != null)) {
/*  729 */         str2 = str5.intern();
/*      */       }
/*  731 */       if ((str6.equalsIgnoreCase("host")) && (str5 != null)) {
/*  732 */         str3 = str5.intern();
/*      */       }
/*  734 */       if ((str6.equalsIgnoreCase("status")) && (str5 != null)) {
/*  735 */         localObject2 = str5;
/*      */       }
/*  737 */       if ((str6.equalsIgnoreCase("card")) && (str5 != null))
/*      */       {
/*      */         try
/*      */         {
/*  741 */           i = Integer.parseInt(str5);
/*      */         }
/*      */         catch (NumberFormatException localNumberFormatException) {}
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  751 */     invokeFailoverProcessingThreads(paramInt, (String)localObject1, str1, str2, str3, (String)localObject2, i);
/*      */     
/*      */ 
/*  754 */     localStringTokenizer = null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void invokeFailoverProcessingThreads(int paramInt1, String paramString1, String paramString2, String paramString3, String paramString4, String paramString5, int paramInt2)
/*      */     throws SQLException
/*      */   {
/*  769 */     OracleImplicitConnectionCache localOracleImplicitConnectionCache = null;
/*  770 */     int i = 0;
/*  771 */     int j = 0;
/*      */     
/*  773 */     if (paramInt1 == 256) {
/*  774 */       i = 1;
/*      */     }
/*  776 */     if (paramInt1 == 512) {
/*  777 */       j = 1;
/*      */     }
/*  779 */     Iterator localIterator = this.m_connCache.values().iterator();
/*      */     
/*  781 */     while (localIterator.hasNext())
/*      */     {
/*  783 */       localOracleImplicitConnectionCache = (OracleImplicitConnectionCache)localIterator.next();
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  793 */       if (((i != 0) && (paramString1.equalsIgnoreCase(localOracleImplicitConnectionCache.dataSourceServiceName))) || (j != 0))
/*      */       {
/*      */ 
/*      */ 
/*  797 */         OracleFailoverWorkerThread localOracleFailoverWorkerThread = new OracleFailoverWorkerThread(localOracleImplicitConnectionCache, paramInt1, paramString2, paramString3, paramString4, paramString5, paramInt2);
/*      */         
/*      */ 
/*      */ 
/*  801 */         checkAndStartThread(localOracleFailoverWorkerThread);
/*      */         
/*  803 */         localOracleImplicitConnectionCache.failoverWorkerThread = localOracleFailoverWorkerThread;
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void checkAndStartThread(Thread paramThread)
/*      */     throws SQLException
/*      */   {
/*      */     try
/*      */     {
/*  820 */       if (!paramThread.isAlive())
/*      */       {
/*  822 */         paramThread.setDaemon(true);
/*  823 */         paramThread.start();
/*      */       }
/*      */     }
/*      */     catch (IllegalThreadStateException localIllegalThreadStateException) {}
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected boolean failoverEnabledCacheExists()
/*      */   {
/*  841 */     if (this.failoverEnabledCacheCount > 0) {
/*  842 */       return true;
/*      */     }
/*  844 */     return false;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void parseRuntimeLoadBalancingEvent(String paramString, byte[] paramArrayOfByte)
/*      */     throws SQLException
/*      */   {
/*  858 */     OracleImplicitConnectionCache localOracleImplicitConnectionCache = null;
/*  859 */     Enumeration localEnumeration = this.m_connCache.elements();
/*      */     
/*  861 */     while (localEnumeration.hasMoreElements())
/*      */     {
/*      */       try
/*      */       {
/*  865 */         localOracleImplicitConnectionCache = (OracleImplicitConnectionCache)localEnumeration.nextElement();
/*  866 */         if (paramString.equalsIgnoreCase(localOracleImplicitConnectionCache.dataSourceServiceName))
/*      */         {
/*  868 */           if (paramArrayOfByte == null) {
/*  869 */             localOracleImplicitConnectionCache.zapRLBInfo();
/*      */           } else {
/*  871 */             retrieveServiceMetrics(localOracleImplicitConnectionCache, paramArrayOfByte);
/*      */           }
/*      */         }
/*      */       }
/*      */       catch (Exception localException) {}
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void retrieveServiceMetrics(OracleImplicitConnectionCache paramOracleImplicitConnectionCache, byte[] paramArrayOfByte)
/*      */     throws SQLException
/*      */   {
/*  896 */     StringTokenizer localStringTokenizer = null;
/*  897 */     String str1 = null;
/*  898 */     String str2 = null;
/*  899 */     int i = 0;
/*  900 */     int j = 0;
/*  901 */     int k = 0;
/*      */     
/*      */     try
/*      */     {
/*  905 */       localStringTokenizer = new StringTokenizer(new String(paramArrayOfByte, "UTF-8"), "{} =", true);
/*      */     }
/*      */     catch (UnsupportedEncodingException localUnsupportedEncodingException) {}
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  914 */     String str3 = null;
/*  915 */     String str4 = null;
/*  916 */     String str5 = null;
/*      */     
/*  918 */     while (localStringTokenizer.hasMoreTokens())
/*      */     {
/*  920 */       str4 = null;
/*  921 */       str3 = localStringTokenizer.nextToken();
/*      */       
/*  923 */       if ((str3.equals("=")) && (localStringTokenizer.hasMoreTokens()))
/*      */       {
/*  925 */         str4 = localStringTokenizer.nextToken();
/*      */       } else {
/*  927 */         if (str3.equals("}"))
/*      */         {
/*      */ 
/*  930 */           if (k == 0)
/*      */             continue;
/*  932 */           paramOracleImplicitConnectionCache.updateDatabaseInstance(str2, str1, i, j);
/*  933 */           k = 0; continue;
/*      */         }
/*      */         
/*      */ 
/*  937 */         if ((str3.equals("{")) || (str3.equals(" "))) {
/*      */           continue;
/*      */         }
/*      */         
/*      */ 
/*      */ 
/*  943 */         str5 = str3;
/*  944 */         k = 1;
/*      */       }
/*      */       
/*  947 */       if ((str5.equalsIgnoreCase("version")) && (str4 != null))
/*      */       {
/*  949 */         if (!str4.equals("1.0"))
/*      */         {
/*  951 */           DatabaseError.throwSqlException(146);
/*      */         }
/*      */       }
/*      */       
/*  955 */       if ((str5.equalsIgnoreCase("database")) && (str4 != null)) {
/*  956 */         str2 = str4.intern();
/*      */       }
/*  958 */       if ((str5.equalsIgnoreCase("instance")) && (str4 != null)) {
/*  959 */         str1 = str4.intern();
/*      */       }
/*  961 */       if ((str5.equalsIgnoreCase("percent")) && (str4 != null))
/*      */       {
/*      */         try
/*      */         {
/*  965 */           i = Integer.parseInt(str4);
/*  966 */           if (i == 0) { i = 1;
/*      */           }
/*      */         }
/*      */         catch (NumberFormatException localNumberFormatException) {}
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*  975 */       if ((str5.equalsIgnoreCase("flag")) && (str4 != null))
/*      */       {
/*  977 */         if (str4.equalsIgnoreCase("good")) {
/*  978 */           j = 1;
/*  979 */         } else if (str4.equalsIgnoreCase("violating")) {
/*  980 */           j = 3;
/*  981 */         } else if (str4.equalsIgnoreCase("NO_DATA")) {
/*  982 */           j = 4;
/*  983 */         } else if (str4.equalsIgnoreCase("UNKNOWN")) {
/*  984 */           j = 2;
/*  985 */         } else if (str4.equalsIgnoreCase("BLOCKED")) {
/*  986 */           j = 5;
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*  991 */     paramOracleImplicitConnectionCache.processDatabaseInstances();
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void cleanupFCFThreads(OracleImplicitConnectionCache paramOracleImplicitConnectionCache)
/*      */     throws SQLException
/*      */   {
/* 1002 */     cleanupFCFWorkerThread(paramOracleImplicitConnectionCache);
/* 1003 */     paramOracleImplicitConnectionCache.cleanupRLBThreads();
/*      */     
/*      */ 
/* 1006 */     if (this.failoverEnabledCacheCount <= 0) {
/* 1007 */       cleanupFCFEventHandlerThread();
/*      */     }
/*      */     
/* 1010 */     this.failoverEnabledCacheCount -= 1;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void cleanupFCFWorkerThread(OracleImplicitConnectionCache paramOracleImplicitConnectionCache)
/*      */     throws SQLException
/*      */   {
/* 1023 */     if (paramOracleImplicitConnectionCache.failoverWorkerThread != null)
/*      */     {
/*      */       try
/*      */       {
/* 1027 */         if (paramOracleImplicitConnectionCache.failoverWorkerThread.isAlive()) {
/* 1028 */           paramOracleImplicitConnectionCache.failoverWorkerThread.join();
/*      */         }
/*      */       }
/*      */       catch (InterruptedException localInterruptedException) {}
/*      */       
/*      */ 
/*      */ 
/*      */ 
/* 1036 */       paramOracleImplicitConnectionCache.failoverWorkerThread = null;
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void cleanupFCFEventHandlerThread()
/*      */     throws SQLException
/*      */   {
/* 1053 */     if (this.failoverEventHandlerThread != null)
/*      */     {
/*      */       try
/*      */       {
/* 1057 */         this.failoverEventHandlerThread.interrupt();
/*      */       }
/*      */       catch (Exception localException) {}
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1065 */       this.failoverEventHandlerThread = null;
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public boolean isFatalConnectionError(SQLException paramSQLException)
/*      */   {
/* 1081 */     boolean bool = false;
/* 1082 */     int i = paramSQLException.getErrorCode();
/*      */     
/*      */ 
/* 1085 */     if ((i == 3113) || (i == 3114) || (i == 1033) || (i == 1034) || (i == 1089) || (i == 1090) || (i == 17002))
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1093 */       bool = true;
/*      */     }
/*      */     
/*      */ 
/* 1097 */     if ((!bool) && (this.fatalErrorCodes != null))
/*      */     {
/* 1099 */       for (int j = 0; j < this.fatalErrorCodes.length; j++) {
/* 1100 */         if (i == this.fatalErrorCodes[j])
/*      */         {
/* 1102 */           bool = true;
/* 1103 */           break;
/*      */         }
/*      */       }
/*      */     }
/* 1107 */     return bool;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void setConnectionErrorCodes(int[] paramArrayOfInt)
/*      */     throws SQLException
/*      */   {
/* 1120 */     if (paramArrayOfInt != null) {
/* 1121 */       this.fatalErrorCodes = paramArrayOfInt;
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public int[] getConnectionErrorCodes()
/*      */     throws SQLException
/*      */   {
/* 1135 */     return this.fatalErrorCodes;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/* 1140 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Wed_Jun_22_11:18:55_PDT_2005";
/*      */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\ojdbc14.jar!\oracle\jdbc\pool\OracleConnectionCacheManager.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       0.7.1
 */