/*      */ package oracle.jdbc.pool;
/*      */ 
/*      */ import java.sql.Connection;
/*      */ import java.sql.SQLException;
/*      */ import java.util.HashMap;
/*      */ import java.util.Iterator;
/*      */ import java.util.LinkedList;
/*      */ import java.util.Map.Entry;
/*      */ import java.util.Properties;
/*      */ import java.util.Random;
/*      */ import java.util.Set;
/*      */ import java.util.Vector;
/*      */ import javax.sql.PooledConnection;
/*      */ import oracle.jdbc.driver.DatabaseError;
/*      */ import oracle.jdbc.internal.OracleConnection;
/*      */ import oracle.jdbc.xa.client.OracleXADataSource;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ class OracleImplicitConnectionCache
/*      */ {
/*   47 */   protected OracleDataSource cacheEnabledDS = null;
/*   48 */   protected String cacheName = null;
/*   49 */   protected OracleConnectionPoolDataSource connectionPoolDS = null;
/*   50 */   protected boolean fastConnectionFailoverEnabled = false;
/*      */   
/*      */ 
/*   53 */   protected String defaultUser = null;
/*   54 */   protected String defaultPassword = null;
/*      */   
/*      */   protected static final int DEFAULT_MIN_LIMIT = 0;
/*      */   
/*      */   protected static final int DEFAULT_MAX_LIMIT = Integer.MAX_VALUE;
/*      */   
/*      */   protected static final int DEFAULT_INITIAL_LIMIT = 0;
/*      */   
/*      */   protected static final int DEFAULT_MAX_STATEMENTS_LIMIT = 0;
/*      */   
/*      */   protected static final int DEFAULT_INACTIVITY_TIMEOUT = 0;
/*      */   
/*      */   protected static final int DEFAULT_TIMETOLIVE_TIMEOUT = 0;
/*      */   protected static final int DEFAULT_ABANDONED_CONN_TIMEOUT = 0;
/*      */   protected static final int DEFAULT_CONNECTION_WAIT_TIMEOUT = 0;
/*      */   protected static final String DEFAULT_ATTRIBUTE_WEIGHT = "0";
/*      */   protected static final int DEFAULT_LOWER_THRESHOLD_LIMIT = 20;
/*      */   protected static final int DEFAULT_PROPERTY_CHECK_INTERVAL = 900;
/*      */   protected static final int CLOSE_AND_REMOVE_ALL_CONNECTIONS = 1;
/*      */   protected static final int CLOSE_AND_REMOVE_FAILOVER_CONNECTIONS = 2;
/*      */   protected static final int PROCESS_INACTIVITY_TIMEOUT = 4;
/*      */   protected static final int CLOSE_AND_REMOVE_N_CONNECTIONS = 8;
/*      */   protected static final int DISABLE_STATEMENT_CACHING = 16;
/*      */   protected static final int RESET_STATEMENT_CACHE_SIZE = 18;
/*      */   protected static final int CLOSE_AND_REMOVE_RLB_CONNECTIONS = 24;
/*      */   private static final String ATTRKEY_DELIM = "0xffff";
/*   80 */   protected int cacheMinLimit = 0;
/*   81 */   protected int cacheMaxLimit = Integer.MAX_VALUE;
/*   82 */   protected int cacheInitialLimit = 0;
/*   83 */   protected int cacheMaxStatementsLimit = 0;
/*   84 */   protected Properties cacheAttributeWeights = null;
/*   85 */   protected int cacheInactivityTimeout = 0;
/*   86 */   protected int cacheTimeToLiveTimeout = 0;
/*   87 */   protected int cacheAbandonedConnectionTimeout = 0;
/*   88 */   protected int cacheLowerThresholdLimit = 20;
/*   89 */   protected int cachePropertyCheckInterval = 900;
/*   90 */   protected boolean cacheClosestConnectionMatch = false;
/*   91 */   protected boolean cacheValidateConnection = false;
/*   92 */   protected int cacheConnectionWaitTimeout = 0;
/*      */   
/*      */   static final String MIN_LIMIT_KEY = "MinLimit";
/*      */   
/*      */   static final String MAX_LIMIT_KEY = "MaxLimit";
/*      */   
/*      */   static final String INITIAL_LIMIT_KEY = "InitialLimit";
/*      */   
/*      */   static final String MAX_STATEMENTS_LIMIT_KEY = "MaxStatementsLimit";
/*      */   
/*      */   static final String ATTRIBUTE_WEIGHTS_KEY = "AttributeWeights";
/*      */   
/*      */   static final String INACTIVITY_TIMEOUT_KEY = "InactivityTimeout";
/*      */   
/*      */   static final String TIME_TO_LIVE_TIMEOUT_KEY = "TimeToLiveTimeout";
/*      */   static final String ABANDONED_CONNECTION_TIMEOUT_KEY = "AbandonedConnectionTimeout";
/*      */   static final String LOWER_THRESHOLD_LIMIT_KEY = "LowerThresholdLimit";
/*      */   static final String PROPERTY_CHECK_INTERVAL_KEY = "PropertyCheckInterval";
/*      */   static final String VALIDATE_CONNECTION_KEY = "ValidateConnection";
/*      */   static final String CLOSEST_CONNECTION_MATCH_KEY = "ClosestConnectionMatch";
/*      */   static final String CONNECTION_WAIT_TIMEOUT_KEY = "ConnectionWaitTimeout";
/*      */   static final int INSTANCE_GOOD = 1;
/*      */   static final int INSTANCE_UNKNOWN = 2;
/*      */   static final int INSTANCE_VIOLATING = 3;
/*      */   static final int INSTANCE_NO_DATA = 4;
/*      */   static final int INSTANCE_BLOCKED = 5;
/*      */   static final int RLB_NUMBER_OF_HITS_PER_INSTANCE = 1000;
/*  119 */   int dbInstancePercentTotal = 0;
/*  120 */   boolean useGoodGroup = false;
/*  121 */   LinkedList instancesToRetireList = null;
/*  122 */   OracleDatabaseInstance instanceToRetire = null;
/*  123 */   int retireConnectionsCount = 0;
/*  124 */   int countTotal = 0;
/*      */   
/*  126 */   protected OracleConnectionCacheManager cacheManager = null;
/*  127 */   protected boolean disableConnectionRequest = false;
/*  128 */   protected OracleImplicitConnectionCacheThread timeoutThread = null;
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  135 */   protected OracleRuntimeLoadBalancingEventHandlerThread runtimeLoadBalancingThread = null;
/*      */   
/*      */ 
/*  138 */   protected OracleGravitateConnectionCacheThread gravitateCacheThread = null;
/*  139 */   protected int connectionsToRemove = 0;
/*      */   
/*      */ 
/*      */ 
/*  143 */   private HashMap userMap = null;
/*  144 */   Vector checkedOutConnectionList = null;
/*      */   
/*      */ 
/*  147 */   LinkedList databaseInstancesList = null;
/*      */   
/*  149 */   int cacheSize = 0;
/*      */   
/*      */   protected static final String EVENT_DELIMITER = " ";
/*      */   
/*  153 */   protected boolean isEntireServiceDownProcessed = false;
/*  154 */   protected int defaultUserPreFailureSize = 0;
/*  155 */   protected String dataSourceServiceName = null;
/*  156 */   protected OracleFailoverWorkerThread failoverWorkerThread = null;
/*  157 */   protected Random rand = null;
/*  158 */   protected int downEventCount = 0;
/*  159 */   protected int upEventCount = 0;
/*  160 */   protected int pendingCreationRequests = 0;
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   OracleImplicitConnectionCache(OracleDataSource paramOracleDataSource, Properties paramProperties)
/*      */     throws SQLException
/*      */   {
/*  171 */     this.cacheEnabledDS = paramOracleDataSource;
/*      */     
/*  173 */     initializeConnectionCache();
/*  174 */     setConnectionCacheProperties(paramProperties);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  181 */     defaultUserPrePopulateCache(this.cacheInitialLimit);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void defaultUserPrePopulateCache(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  194 */     if (paramInt > 0)
/*      */     {
/*  196 */       String str1 = this.defaultUser;
/*  197 */       String str2 = this.defaultPassword;
/*      */       
/*  199 */       validateUser(str1, str2);
/*      */       
/*  201 */       OraclePooledConnection localOraclePooledConnection = null;
/*      */       
/*  203 */       for (int i = 0; i < paramInt; i++)
/*      */       {
/*  205 */         if (getTotalCachedConnections() < this.cacheMaxLimit)
/*      */         {
/*  207 */           localOraclePooledConnection = makeCacheConnection(str1, str2);
/*      */           
/*  209 */           if (localOraclePooledConnection != null)
/*      */           {
/*  211 */             synchronized (this)
/*      */             {
/*      */ 
/*      */ 
/*  215 */               this.cacheSize -= 1;
/*      */             }
/*  217 */             storeCacheConnection(str1, null, localOraclePooledConnection);
/*      */           }
/*      */         }
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void initializeConnectionCache()
/*      */     throws SQLException
/*      */   {
/*  233 */     this.userMap = new HashMap();
/*  234 */     this.checkedOutConnectionList = new Vector();
/*      */     
/*  236 */     if (this.cacheManager == null) {
/*  237 */       this.cacheManager = OracleConnectionCacheManager.getConnectionCacheManagerInstance();
/*      */     }
/*      */     
/*  240 */     this.defaultUser = this.cacheEnabledDS.getUser();
/*  241 */     this.defaultPassword = this.cacheEnabledDS.getPassword();
/*      */     
/*  243 */     if (this.connectionPoolDS == null)
/*      */     {
/*  245 */       if ((this.cacheEnabledDS instanceof OracleXADataSource))
/*      */       {
/*  247 */         this.connectionPoolDS = new OracleXADataSource();
/*      */       }
/*      */       else
/*      */       {
/*  251 */         this.connectionPoolDS = new OracleConnectionPoolDataSource();
/*      */       }
/*      */       
/*      */ 
/*  255 */       this.cacheEnabledDS.copy(this.connectionPoolDS);
/*      */     }
/*      */     
/*  258 */     if ((this.fastConnectionFailoverEnabled = this.cacheEnabledDS.getFastConnectionFailoverEnabled()))
/*      */     {
/*      */ 
/*  261 */       this.rand = new Random(0L);
/*  262 */       this.cacheManager.failoverEnabledCacheCount += 1;
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void validateUser(String paramString1, String paramString2)
/*      */     throws SQLException
/*      */   {
/*  277 */     if ((paramString1 == null) || (paramString2 == null)) {
/*  278 */       DatabaseError.throwSqlException(79);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected Connection getConnection(String paramString1, String paramString2, Properties paramProperties)
/*      */     throws SQLException
/*      */   {
/*  297 */     OraclePooledConnection localOraclePooledConnection = null;
/*  298 */     Connection localConnection = null;
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     try
/*      */     {
/*  307 */       if (this.disableConnectionRequest)
/*      */       {
/*  309 */         DatabaseError.throwSqlException(142);
/*      */       }
/*      */       
/*      */ 
/*  313 */       validateUser(paramString1, paramString2);
/*      */       
/*      */ 
/*  316 */       if (!paramString1.startsWith("\"")) {
/*  317 */         paramString1 = paramString1.toLowerCase();
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  332 */       if (getNumberOfCheckedOutConnections() < this.cacheMaxLimit) {
/*  333 */         localOraclePooledConnection = getCacheConnection(paramString1, paramString2, paramProperties);
/*      */       }
/*      */       
/*  336 */       if (localOraclePooledConnection == null)
/*      */       {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  343 */         processConnectionCacheCallback();
/*      */         
/*  345 */         if (this.cacheSize > 0) {
/*  346 */           localOraclePooledConnection = getCacheConnection(paramString1, paramString2, paramProperties);
/*      */         }
/*      */         
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  355 */         if ((localOraclePooledConnection == null) && (this.cacheConnectionWaitTimeout > 0))
/*      */         {
/*  357 */           long l1 = this.cacheConnectionWaitTimeout * 1000L;
/*  358 */           long l2 = System.currentTimeMillis();
/*  359 */           long l3 = 0L;
/*      */           do
/*      */           {
/*  362 */             processConnectionWaitTimeout(l1);
/*      */             
/*  364 */             if (this.cacheSize > 0) {
/*  365 */               localOraclePooledConnection = getCacheConnection(paramString1, paramString2, paramProperties);
/*      */             }
/*  367 */             l3 = System.currentTimeMillis();
/*  368 */             l1 -= System.currentTimeMillis() - l2;
/*  369 */             l2 = l3;
/*      */ 
/*      */           }
/*  372 */           while ((localOraclePooledConnection == null) && (l1 > 0L));
/*      */         }
/*      */       }
/*      */       
/*      */ 
/*  377 */       if ((localOraclePooledConnection != null) && (localOraclePooledConnection.physicalConn != null))
/*      */       {
/*      */ 
/*      */ 
/*  381 */         localConnection = localOraclePooledConnection.getConnection();
/*      */         
/*  383 */         if (localConnection != null)
/*      */         {
/*  385 */           if ((this.cacheValidateConnection) && (testDatabaseConnection((OracleConnection)localConnection) != 0))
/*      */           {
/*      */ 
/*      */ 
/*  389 */             ((OracleConnection)localConnection).close(4096);
/*  390 */             DatabaseError.throwSqlException(143);
/*      */           }
/*      */           
/*      */ 
/*  394 */           if (this.cacheAbandonedConnectionTimeout > 0) {
/*  395 */             ((OracleConnection)localConnection).setAbandonedTimeoutEnabled(true);
/*      */           }
/*      */           
/*  398 */           if (this.cacheTimeToLiveTimeout > 0) {
/*  399 */             ((OracleConnection)localConnection).setStartTime(System.currentTimeMillis());
/*      */           }
/*  401 */           synchronized (this)
/*      */           {
/*      */ 
/*      */ 
/*  405 */             this.cacheSize -= 1;
/*  406 */             this.checkedOutConnectionList.addElement(localOraclePooledConnection);
/*      */           }
/*      */         }
/*      */       }
/*      */     }
/*      */     catch (SQLException localSQLException) {
/*  412 */       synchronized (this)
/*      */       {
/*  414 */         if (localOraclePooledConnection != null)
/*      */         {
/*  416 */           this.cacheSize -= 1;
/*  417 */           abortConnection(localOraclePooledConnection);
/*      */         }
/*      */       }
/*  420 */       throw localSQLException;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  427 */     return localConnection;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private OraclePooledConnection getCacheConnection(String paramString1, String paramString2, Properties paramProperties)
/*      */     throws SQLException
/*      */   {
/*  443 */     OraclePooledConnection localOraclePooledConnection = retrieveCacheConnection(paramString1, paramString2, paramProperties);
/*  444 */     int i = 0;
/*      */     
/*  446 */     if (localOraclePooledConnection == null)
/*      */     {
/*  448 */       synchronized (this)
/*      */       {
/*      */ 
/*  451 */         if (getTotalCachedConnections() + this.pendingCreationRequests < this.cacheMaxLimit)
/*      */         {
/*      */ 
/*  454 */           this.pendingCreationRequests += 1;
/*  455 */           i = 1;
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*  460 */     if (i != 0)
/*      */     {
/*      */       try
/*      */       {
/*  464 */         localOraclePooledConnection = makeCacheConnection(paramString1, paramString2);
/*      */ 
/*      */ 
/*      */       }
/*      */       finally
/*      */       {
/*      */ 
/*      */ 
/*  472 */         synchronized (this)
/*      */         {
/*  474 */           this.pendingCreationRequests -= 1;
/*      */         }
/*      */       }
/*      */       
/*      */ 
/*  479 */       if ((paramProperties != null) && (!paramProperties.isEmpty())) {
/*  480 */         setUnMatchedAttributes(paramProperties, localOraclePooledConnection);
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  491 */     return localOraclePooledConnection;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected int getTotalCachedConnections()
/*      */   {
/*  500 */     return this.cacheSize + getNumberOfCheckedOutConnections();
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected int getNumberOfCheckedOutConnections()
/*      */   {
/*  509 */     return this.checkedOutConnectionList.size();
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private synchronized OraclePooledConnection retrieveCacheConnection(String paramString1, String paramString2, Properties paramProperties)
/*      */     throws SQLException
/*      */   {
/*  522 */     OraclePooledConnection localOraclePooledConnection = null;
/*  523 */     OracleConnectionCacheEntry localOracleConnectionCacheEntry = (OracleConnectionCacheEntry)this.userMap.get(paramString1 + paramString2.toUpperCase());
/*      */     
/*      */ 
/*  526 */     if (localOracleConnectionCacheEntry != null)
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/*  531 */       if ((paramProperties == null) || ((paramProperties != null) && (paramProperties.isEmpty())))
/*      */       {
/*  533 */         if (localOracleConnectionCacheEntry.userConnList != null) {
/*  534 */           localOraclePooledConnection = retrieveFromConnectionList(localOracleConnectionCacheEntry.userConnList);
/*      */         }
/*  536 */       } else if (localOracleConnectionCacheEntry.attrConnMap != null)
/*      */       {
/*  538 */         String str = buildAttrKey(paramProperties);
/*  539 */         Vector localVector = (Vector)localOracleConnectionCacheEntry.attrConnMap.get(str);
/*      */         
/*      */ 
/*  542 */         if (localVector != null)
/*      */         {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  549 */           localOraclePooledConnection = retrieveFromConnectionList(localVector);
/*      */         }
/*      */         
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  557 */         if ((localOraclePooledConnection == null) && (this.cacheClosestConnectionMatch)) {
/*  558 */           localOraclePooledConnection = retrieveClosestConnectionMatch(localOracleConnectionCacheEntry.attrConnMap, paramProperties);
/*      */         }
/*      */         
/*      */ 
/*      */ 
/*  563 */         if ((localOraclePooledConnection == null) && (localOracleConnectionCacheEntry.userConnList != null)) {
/*  564 */           localOraclePooledConnection = retrieveFromConnectionList(localOracleConnectionCacheEntry.userConnList);
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*  569 */     if (localOraclePooledConnection != null)
/*      */     {
/*  571 */       if ((paramProperties != null) && (!paramProperties.isEmpty())) {
/*  572 */         setUnMatchedAttributes(paramProperties, localOraclePooledConnection);
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*  579 */     return localOraclePooledConnection;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private OraclePooledConnection retrieveClosestConnectionMatch(HashMap paramHashMap, Properties paramProperties)
/*      */     throws SQLException
/*      */   {
/*  592 */     OraclePooledConnection localOraclePooledConnection1 = null;
/*  593 */     OraclePooledConnection localOraclePooledConnection2 = null;
/*      */     
/*  595 */     int i = paramProperties.size();
/*  596 */     int j = 0;
/*  597 */     int k = 0;
/*  598 */     int m = 0;
/*  599 */     int n = 0;
/*  600 */     int i1 = 0;
/*      */     
/*  602 */     if (this.cacheAttributeWeights != null) {
/*  603 */       j = getAttributesWeightCount(paramProperties, null);
/*      */     }
/*  605 */     if ((paramHashMap != null) && (!paramHashMap.isEmpty()))
/*      */     {
/*      */ 
/*      */ 
/*  609 */       Iterator localIterator = paramHashMap.entrySet().iterator();
/*      */       
/*  611 */       while (localIterator.hasNext())
/*      */       {
/*  613 */         Map.Entry localEntry = (Map.Entry)localIterator.next();
/*      */         
/*  615 */         Vector localVector = (Vector)localEntry.getValue();
/*  616 */         Object[] arrayOfObject = localVector.toArray();
/*  617 */         int i2 = localVector.size();
/*      */         
/*  619 */         for (int i3 = 0; i3 < i2; i3++)
/*      */         {
/*  621 */           localOraclePooledConnection1 = (OraclePooledConnection)arrayOfObject[i3];
/*      */           
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  628 */           if ((localOraclePooledConnection1.cachedConnectionAttributes != null) && (!localOraclePooledConnection1.cachedConnectionAttributes.isEmpty()) && (localOraclePooledConnection1.cachedConnectionAttributes.size() <= i))
/*      */           {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  642 */             if (j > 0)
/*      */             {
/*  644 */               m = getAttributesWeightCount(paramProperties, localOraclePooledConnection1.cachedConnectionAttributes);
/*      */               
/*      */ 
/*      */ 
/*  648 */               if (m > k)
/*      */               {
/*  650 */                 localOraclePooledConnection2 = localOraclePooledConnection1;
/*  651 */                 k = m;
/*      */               }
/*      */             }
/*      */             else
/*      */             {
/*  656 */               i1 = getAttributesMatchCount(paramProperties, localOraclePooledConnection1.cachedConnectionAttributes);
/*      */               
/*      */ 
/*  659 */               if (i1 > n)
/*      */               {
/*  661 */                 localOraclePooledConnection2 = localOraclePooledConnection1;
/*  662 */                 n = i1;
/*      */               }
/*      */             }
/*      */           }
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*  670 */     return localOraclePooledConnection2;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private int getAttributesMatchCount(Properties paramProperties1, Properties paramProperties2)
/*      */     throws SQLException
/*      */   {
/*  686 */     int i = 0;
/*  687 */     Map.Entry localEntry = null;
/*  688 */     Object localObject1 = null;
/*  689 */     Object localObject2 = null;
/*      */     
/*  691 */     Iterator localIterator = paramProperties1.entrySet().iterator();
/*      */     
/*  693 */     while (localIterator.hasNext())
/*      */     {
/*  695 */       localEntry = (Map.Entry)localIterator.next();
/*  696 */       localObject1 = localEntry.getKey();
/*  697 */       localObject2 = localEntry.getValue();
/*      */       
/*  699 */       if ((paramProperties2.containsKey(localObject1)) && (localObject2.equals(paramProperties2.get(localObject1))))
/*      */       {
/*  701 */         i++;
/*      */       }
/*      */     }
/*  704 */     return i;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private int getAttributesWeightCount(Properties paramProperties1, Properties paramProperties2)
/*      */     throws SQLException
/*      */   {
/*  734 */     Map.Entry localEntry = null;
/*  735 */     Object localObject1 = null;
/*  736 */     Object localObject2 = null;
/*  737 */     int i = 0;
/*      */     
/*  739 */     Iterator localIterator = paramProperties1.entrySet().iterator();
/*      */     
/*  741 */     while (localIterator.hasNext())
/*      */     {
/*  743 */       localEntry = (Map.Entry)localIterator.next();
/*  744 */       localObject1 = localEntry.getKey();
/*  745 */       localObject2 = localEntry.getValue();
/*      */       
/*      */ 
/*  748 */       if (paramProperties2 == null)
/*      */       {
/*  750 */         if (this.cacheAttributeWeights.containsKey(localObject1))
/*      */         {
/*  752 */           i += Integer.parseInt((String)this.cacheAttributeWeights.get(localObject1));
/*      */         }
/*      */         
/*      */       }
/*  756 */       else if ((paramProperties2.containsKey(localObject1)) && (localObject2.equals(paramProperties2.get(localObject1))))
/*      */       {
/*      */ 
/*  759 */         if (this.cacheAttributeWeights.containsKey(localObject1))
/*      */         {
/*  761 */           i += Integer.parseInt((String)this.cacheAttributeWeights.get(localObject1));
/*      */ 
/*      */ 
/*      */         }
/*      */         else
/*      */         {
/*      */ 
/*  768 */           i++;
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*  773 */     return i;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void setUnMatchedAttributes(Properties paramProperties, OraclePooledConnection paramOraclePooledConnection)
/*      */     throws SQLException
/*      */   {
/*  788 */     if (paramOraclePooledConnection.unMatchedCachedConnAttr == null) {
/*  789 */       paramOraclePooledConnection.unMatchedCachedConnAttr = new Properties();
/*      */     } else {
/*  791 */       paramOraclePooledConnection.unMatchedCachedConnAttr.clear();
/*      */     }
/*  793 */     if (!this.cacheClosestConnectionMatch)
/*      */     {
/*  795 */       paramOraclePooledConnection.unMatchedCachedConnAttr.putAll(paramProperties);
/*      */     }
/*      */     else
/*      */     {
/*  799 */       Properties localProperties = paramOraclePooledConnection.cachedConnectionAttributes;
/*  800 */       Map.Entry localEntry = null;
/*  801 */       Object localObject1 = null;
/*  802 */       Object localObject2 = null;
/*      */       
/*  804 */       Iterator localIterator = paramProperties.entrySet().iterator();
/*      */       
/*  806 */       while (localIterator.hasNext())
/*      */       {
/*  808 */         localEntry = (Map.Entry)localIterator.next();
/*  809 */         localObject1 = localEntry.getKey();
/*  810 */         localObject2 = localEntry.getValue();
/*      */         
/*  812 */         if ((!localProperties.containsKey(localObject1)) && (!localObject2.equals(localProperties.get(localObject1))))
/*      */         {
/*  814 */           paramOraclePooledConnection.unMatchedCachedConnAttr.put(localObject1, localObject2);
/*      */         }
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private OraclePooledConnection retrieveFromConnectionList(Vector paramVector)
/*      */     throws SQLException
/*      */   {
/*  832 */     if (paramVector.isEmpty()) {
/*  833 */       return null;
/*      */     }
/*  835 */     Object localObject1 = null;
/*      */     
/*  837 */     if (this.fastConnectionFailoverEnabled)
/*      */     {
/*      */ 
/*  840 */       if ((this.useGoodGroup) && (this.databaseInstancesList != null) && (this.databaseInstancesList.size() > 0)) {
/*      */         label234:
/*      */         
/*  843 */         synchronized (this.databaseInstancesList)
/*      */         {
/*  845 */           i = this.databaseInstancesList.size();
/*  846 */           localObject2 = null;
/*  847 */           localObject3 = 0;
/*      */           
/*  849 */           boolean[] arrayOfBoolean = new boolean[i];
/*  850 */           int j = this.dbInstancePercentTotal;
/*      */           
/*  852 */           for (int k = 0; k < i; k++)
/*      */           {
/*  854 */             Object localObject4 = 0;
/*      */             
/*      */ 
/*  857 */             if (j <= 1) {
/*  858 */               localObject3 = 0;
/*      */             } else {
/*  860 */               localObject3 = this.rand.nextInt(j - 1);
/*      */             }
/*      */             
/*  863 */             for (int m = 0; m < i; m++)
/*      */             {
/*  865 */               localObject2 = (OracleDatabaseInstance)this.databaseInstancesList.get(m);
/*      */               
/*  867 */               if ((arrayOfBoolean[m] == 0) && (((OracleDatabaseInstance)localObject2).flag <= 3))
/*      */               {
/*  869 */                 localObject4 += ((OracleDatabaseInstance)localObject2).percent;
/*      */                 
/*      */ 
/*      */ 
/*      */ 
/*  874 */                 if (localObject3 <= localObject4)
/*      */                 {
/*      */ 
/*  877 */                   if (k == 0) { localObject2.attemptedConnRequestCount += 1;
/*      */                   }
/*  879 */                   if ((localObject1 = selectConnectionFromList(paramVector, (OracleDatabaseInstance)localObject2)) != null) {
/*      */                     break label234;
/*      */                   }
/*      */                   
/*      */ 
/*      */ 
/*  885 */                   j -= ((OracleDatabaseInstance)localObject2).percent;
/*  886 */                   arrayOfBoolean[m] = true;
/*  887 */                   break;
/*      */                 }
/*      */               }
/*      */             }
/*      */           }
/*      */         }
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  903 */       ??? = paramVector.size();
/*  904 */       int i = this.rand.nextInt(???);
/*  905 */       Object localObject2 = null;
/*      */       
/*  907 */       for (Object localObject3 = 0; localObject3 < ???; localObject3++)
/*      */       {
/*  909 */         localObject2 = (OraclePooledConnection)paramVector.get((i++ + ???) % ???);
/*      */         
/*      */ 
/*  912 */         if (!((OraclePooledConnection)localObject2).connectionMarkedDown)
/*      */         {
/*  914 */           localObject1 = localObject2;
/*  915 */           paramVector.remove(localObject1);
/*  916 */           break;
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*  923 */     localObject1 = (OraclePooledConnection)paramVector.remove(0);
/*      */     
/*      */ 
/*  926 */     return (OraclePooledConnection)localObject1;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private OraclePooledConnection selectConnectionFromList(Vector paramVector, OracleDatabaseInstance paramOracleDatabaseInstance)
/*      */   {
/*  937 */     Object localObject = null;
/*  938 */     OraclePooledConnection localOraclePooledConnection = null;
/*      */     
/*      */ 
/*  941 */     int i = paramVector.size();
/*  942 */     for (int j = 0; j < i; j++)
/*      */     {
/*  944 */       localOraclePooledConnection = (OraclePooledConnection)paramVector.get(j);
/*      */       
/*  946 */       if ((!localOraclePooledConnection.connectionMarkedDown) && (localOraclePooledConnection.dataSourceDbUniqNameKey == paramOracleDatabaseInstance.databaseUniqName) && (localOraclePooledConnection.dataSourceInstanceNameKey == paramOracleDatabaseInstance.instanceName))
/*      */       {
/*      */ 
/*      */ 
/*  950 */         localObject = localOraclePooledConnection;
/*  951 */         paramVector.remove(localObject);
/*  952 */         break;
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*  960 */     return (OraclePooledConnection)localObject;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void removeCacheConnection(OraclePooledConnection paramOraclePooledConnection)
/*      */     throws SQLException
/*      */   {
/*  972 */     boolean bool = false;
/*      */     
/*  974 */     String str1 = paramOraclePooledConnection.pcUser;
/*      */     
/*  976 */     OracleConnectionCacheEntry localOracleConnectionCacheEntry = paramOraclePooledConnection.removeFromImplictCache(this.userMap);
/*      */     
/*      */ 
/*  979 */     if (localOracleConnectionCacheEntry != null)
/*      */     {
/*  981 */       Properties localProperties = paramOraclePooledConnection.cachedConnectionAttributes;
/*      */       
/*  983 */       if ((localProperties == null) || ((localProperties != null) && (localProperties.isEmpty())))
/*      */       {
/*  985 */         if (localOracleConnectionCacheEntry.userConnList != null) {
/*  986 */           bool = localOracleConnectionCacheEntry.userConnList.removeElement(paramOraclePooledConnection);
/*      */         }
/*  988 */       } else if (localOracleConnectionCacheEntry.attrConnMap != null)
/*      */       {
/*  990 */         String str2 = buildAttrKey(localProperties);
/*      */         
/*  992 */         Vector localVector = (Vector)localOracleConnectionCacheEntry.attrConnMap.get(str2);
/*      */         
/*      */ 
/*  995 */         if (localVector != null)
/*      */         {
/*      */ 
/*      */ 
/*  999 */           if (paramOraclePooledConnection.unMatchedCachedConnAttr != null)
/*      */           {
/* 1001 */             paramOraclePooledConnection.unMatchedCachedConnAttr.clear();
/* 1002 */             paramOraclePooledConnection.unMatchedCachedConnAttr = null;
/*      */           }
/*      */           
/* 1005 */           if (paramOraclePooledConnection.cachedConnectionAttributes != null)
/*      */           {
/* 1007 */             paramOraclePooledConnection.cachedConnectionAttributes.clear();
/* 1008 */             paramOraclePooledConnection.cachedConnectionAttributes = null;
/*      */           }
/*      */           
/* 1011 */           localProperties = null;
/* 1012 */           bool = localVector.removeElement(paramOraclePooledConnection);
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*      */ 
/* 1018 */     if (bool)
/*      */     {
/* 1020 */       this.cacheSize -= 1;
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void doForEveryCachedConnection(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1046 */     int i = 0;
/*      */     
/* 1048 */     synchronized (this)
/*      */     {
/* 1050 */       if ((this.userMap != null) && (!this.userMap.isEmpty()))
/*      */       {
/* 1052 */         Iterator localIterator = this.userMap.entrySet().iterator();
/*      */         
/* 1054 */         while (localIterator.hasNext())
/*      */         {
/* 1056 */           Map.Entry localEntry = (Map.Entry)localIterator.next();
/* 1057 */           OracleConnectionCacheEntry localOracleConnectionCacheEntry = (OracleConnectionCacheEntry)localEntry.getValue();
/*      */           Object localObject1;
/*      */           Object localObject2;
/* 1060 */           OraclePooledConnection localOraclePooledConnection; if ((localOracleConnectionCacheEntry.userConnList != null) && (!localOracleConnectionCacheEntry.userConnList.isEmpty()))
/*      */           {
/* 1062 */             localObject1 = localOracleConnectionCacheEntry.userConnList;
/* 1063 */             localObject2 = ((Vector)localObject1).toArray();
/*      */             
/* 1065 */             for (int j = 0; j < localObject2.length; j++)
/*      */             {
/* 1067 */               localOraclePooledConnection = (OraclePooledConnection)localObject2[j];
/*      */               
/* 1069 */               if ((localOraclePooledConnection != null) && (performPooledConnectionTask(localOraclePooledConnection, paramInt))) {
/* 1070 */                 i++;
/*      */               }
/*      */             }
/*      */           }
/* 1074 */           if ((localOracleConnectionCacheEntry.attrConnMap != null) && (!localOracleConnectionCacheEntry.attrConnMap.isEmpty()))
/*      */           {
/* 1076 */             localObject1 = localOracleConnectionCacheEntry.attrConnMap.entrySet().iterator();
/*      */             
/* 1078 */             while (((Iterator)localObject1).hasNext())
/*      */             {
/* 1080 */               localObject2 = (Map.Entry)((Iterator)localObject1).next();
/*      */               
/* 1082 */               Vector localVector = (Vector)((Map.Entry)localObject2).getValue();
/* 1083 */               Object[] arrayOfObject = localVector.toArray();
/*      */               
/* 1085 */               for (int k = 0; k < arrayOfObject.length; k++)
/*      */               {
/* 1087 */                 localOraclePooledConnection = (OraclePooledConnection)arrayOfObject[k];
/*      */                 
/* 1089 */                 if ((localOraclePooledConnection != null) && (performPooledConnectionTask(localOraclePooledConnection, paramInt))) {
/* 1090 */                   i++;
/*      */                 }
/*      */               }
/*      */             }
/* 1094 */             if (paramInt == 1) {
/* 1095 */               localOracleConnectionCacheEntry.attrConnMap.clear();
/*      */             }
/*      */           }
/*      */         }
/*      */         
/* 1100 */         if (paramInt == 1)
/*      */         {
/* 1102 */           this.userMap.clear();
/*      */           
/* 1104 */           this.cacheSize = 0;
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1114 */     if (i > 0)
/*      */     {
/*      */ 
/* 1117 */       defaultUserPrePopulateCache(i);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private boolean performPooledConnectionTask(OraclePooledConnection paramOraclePooledConnection, int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1138 */     boolean bool = false;
/*      */     
/* 1140 */     switch (paramInt)
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/*      */     case 2: 
/* 1146 */       if (paramOraclePooledConnection.connectionMarkedDown)
/*      */       {
/* 1148 */         closeAndRemovePooledConnection(paramOraclePooledConnection);
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       break;
/*      */     case 8: 
/* 1157 */       if (this.connectionsToRemove > 0)
/*      */       {
/* 1159 */         closeAndRemovePooledConnection(paramOraclePooledConnection);
/*      */         
/* 1161 */         this.connectionsToRemove -= 1;
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       break;
/*      */     case 24: 
/* 1170 */       if (this.retireConnectionsCount > 0)
/*      */       {
/* 1172 */         if ((this.instanceToRetire.databaseUniqName == paramOraclePooledConnection.dataSourceDbUniqNameKey) && (this.instanceToRetire.instanceName == paramOraclePooledConnection.dataSourceInstanceNameKey))
/*      */         {
/*      */ 
/* 1175 */           closeAndRemovePooledConnection(paramOraclePooledConnection);
/* 1176 */           this.retireConnectionsCount -= 1;
/*      */           
/* 1178 */           if (getTotalCachedConnections() < this.cacheMinLimit) {
/* 1179 */             bool = true;
/*      */           }
/*      */         }
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */       break;
/*      */     case 4096: 
/* 1188 */       Connection localConnection = paramOraclePooledConnection.getLogicalHandle();
/*      */       
/* 1190 */       if (localConnection != null)
/*      */       {
/* 1192 */         if (testDatabaseConnection((OracleConnection)localConnection) != 0)
/*      */         {
/*      */ 
/* 1195 */           closeAndRemovePooledConnection(paramOraclePooledConnection);
/*      */           
/* 1197 */           bool = true;
/*      */         }
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */       break;
/*      */     case 8192: 
/* 1206 */       closeAndRemovePooledConnection(paramOraclePooledConnection);
/*      */       
/* 1208 */       bool = true;
/*      */       
/* 1210 */       break;
/*      */     
/*      */ 
/*      */ 
/*      */     case 1: 
/* 1215 */       closeAndRemovePooledConnection(paramOraclePooledConnection);
/*      */       
/* 1217 */       break;
/*      */     
/*      */ 
/*      */ 
/*      */     case 4: 
/* 1222 */       processInactivityTimeout(paramOraclePooledConnection);
/*      */       
/* 1224 */       break;
/*      */     
/*      */ 
/*      */ 
/*      */     case 16: 
/* 1229 */       setStatementCaching(paramOraclePooledConnection, this.cacheMaxStatementsLimit, false);
/*      */       
/* 1231 */       break;
/*      */     
/*      */ 
/*      */ 
/*      */     case 18: 
/* 1236 */       setStatementCaching(paramOraclePooledConnection, this.cacheMaxStatementsLimit, true);
/*      */       
/* 1238 */       break;
/*      */     }
/*      */     
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1245 */     return bool;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected synchronized void doForEveryCheckedOutConnection(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1262 */     int i = this.checkedOutConnectionList.size();
/*      */     
/*      */     int j;
/* 1265 */     if (paramInt == 1)
/*      */     {
/* 1267 */       for (j = 0; j < i; j++)
/*      */       {
/* 1269 */         closeCheckedOutConnection((OraclePooledConnection)this.checkedOutConnectionList.get(j), false);
/*      */       }
/*      */       
/*      */ 
/* 1273 */       this.checkedOutConnectionList.removeAllElements();
/*      */     }
/* 1275 */     else if (paramInt == 24)
/*      */     {
/* 1277 */       for (j = 0; (j < i) && (this.retireConnectionsCount > 0); j++)
/*      */       {
/* 1279 */         OraclePooledConnection localOraclePooledConnection = (OraclePooledConnection)this.checkedOutConnectionList.get(j);
/* 1280 */         if ((this.instanceToRetire.databaseUniqName == localOraclePooledConnection.dataSourceDbUniqNameKey) && (this.instanceToRetire.instanceName == localOraclePooledConnection.dataSourceInstanceNameKey))
/*      */         {
/*      */ 
/* 1283 */           localOraclePooledConnection.closeOption = 4096;
/*      */           
/*      */ 
/* 1286 */           this.retireConnectionsCount -= 2;
/*      */         }
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void closeCheckedOutConnection(OraclePooledConnection paramOraclePooledConnection, boolean paramBoolean)
/*      */     throws SQLException
/*      */   {
/* 1309 */     if (paramOraclePooledConnection != null)
/*      */     {
/* 1311 */       OracleConnection localOracleConnection = (OracleConnection)paramOraclePooledConnection.getLogicalHandle();
/*      */       
/*      */ 
/*      */       try
/*      */       {
/* 1316 */         if ((!localOracleConnection.getAutoCommit()) && (!paramOraclePooledConnection.isHostDown)) {
/* 1317 */           localOracleConnection.rollback();
/*      */         }
/*      */       }
/*      */       catch (SQLException localSQLException1) {}
/*      */       
/*      */ 
/*      */ 
/*      */ 
/* 1325 */       if (paramBoolean)
/*      */       {
/*      */         try
/*      */         {
/*      */ 
/* 1330 */           localOracleConnection.close();
/*      */ 
/*      */ 
/*      */         }
/*      */         catch (SQLException localSQLException2) {}
/*      */ 
/*      */       }
/*      */       else
/*      */       {
/*      */ 
/* 1340 */         actualPooledConnectionClose(paramOraclePooledConnection);
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private synchronized void storeCacheConnection(String paramString, Properties paramProperties, OraclePooledConnection paramOraclePooledConnection)
/*      */     throws SQLException
/*      */   {
/* 1360 */     boolean bool = false;
/*      */     
/* 1362 */     if ((paramOraclePooledConnection == null) || (paramOraclePooledConnection.physicalConn == null))
/*      */     {
/* 1364 */       return;
/*      */     }
/*      */     
/* 1367 */     if (this.cacheInactivityTimeout > 0)
/*      */     {
/* 1369 */       paramOraclePooledConnection.setLastAccessedTime(System.currentTimeMillis());
/*      */     }
/*      */     
/* 1372 */     if (paramOraclePooledConnection.unMatchedCachedConnAttr != null)
/*      */     {
/* 1374 */       paramOraclePooledConnection.unMatchedCachedConnAttr.clear();
/* 1375 */       paramOraclePooledConnection.unMatchedCachedConnAttr = null;
/*      */     }
/*      */     
/*      */ 
/* 1379 */     if (!paramString.startsWith("\"")) {
/* 1380 */       paramString = paramString.toLowerCase();
/*      */     }
/* 1382 */     OracleConnectionCacheEntry localOracleConnectionCacheEntry = paramOraclePooledConnection.removeFromImplictCache(this.userMap);
/*      */     Object localObject1;
/*      */     Object localObject2;
/* 1385 */     if (localOracleConnectionCacheEntry != null)
/*      */     {
/* 1387 */       if ((paramProperties == null) || ((paramProperties != null) && (paramProperties.isEmpty())))
/*      */       {
/* 1389 */         if (localOracleConnectionCacheEntry.userConnList == null) {
/* 1390 */           localOracleConnectionCacheEntry.userConnList = new Vector();
/*      */         }
/* 1392 */         bool = localOracleConnectionCacheEntry.userConnList.add(paramOraclePooledConnection);
/*      */ 
/*      */       }
/*      */       else
/*      */       {
/*      */ 
/* 1398 */         paramOraclePooledConnection.cachedConnectionAttributes = paramProperties;
/*      */         
/* 1400 */         if (localOracleConnectionCacheEntry.attrConnMap == null) {
/* 1401 */           localOracleConnectionCacheEntry.attrConnMap = new HashMap();
/*      */         }
/* 1403 */         localObject1 = buildAttrKey(paramProperties);
/* 1404 */         localObject2 = (Vector)localOracleConnectionCacheEntry.attrConnMap.get(localObject1);
/*      */         
/*      */ 
/* 1407 */         if (localObject2 != null)
/*      */         {
/* 1409 */           bool = ((Vector)localObject2).add(paramOraclePooledConnection);
/*      */         }
/*      */         else
/*      */         {
/* 1413 */           localObject2 = new Vector();
/*      */           
/* 1415 */           bool = ((Vector)localObject2).add(paramOraclePooledConnection);
/* 1416 */           localOracleConnectionCacheEntry.attrConnMap.put(localObject1, localObject2);
/*      */         }
/*      */       }
/*      */     }
/*      */     else
/*      */     {
/* 1422 */       localOracleConnectionCacheEntry = new OracleConnectionCacheEntry();
/*      */       
/* 1424 */       paramOraclePooledConnection.addToImplicitCache(this.userMap, localOracleConnectionCacheEntry);
/*      */       
/* 1426 */       if ((paramProperties == null) || ((paramProperties != null) && (paramProperties.isEmpty())))
/*      */       {
/* 1428 */         localObject1 = new Vector();
/*      */         
/* 1430 */         bool = ((Vector)localObject1).add(paramOraclePooledConnection);
/*      */         
/* 1432 */         localOracleConnectionCacheEntry.userConnList = ((Vector)localObject1);
/*      */       }
/*      */       else
/*      */       {
/* 1436 */         localObject1 = buildAttrKey(paramProperties);
/*      */         
/*      */ 
/* 1439 */         paramOraclePooledConnection.cachedConnectionAttributes = paramProperties;
/*      */         
/* 1441 */         localObject2 = new HashMap();
/* 1442 */         Vector localVector = new Vector();
/*      */         
/* 1444 */         bool = localVector.add(paramOraclePooledConnection);
/* 1445 */         ((HashMap)localObject2).put(localObject1, localVector);
/*      */         
/* 1447 */         localOracleConnectionCacheEntry.attrConnMap = ((HashMap)localObject2);
/*      */       }
/*      */     }
/*      */     
/*      */ 
/* 1452 */     if (bool) {
/* 1453 */       this.cacheSize += 1;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1464 */     if (this.cacheConnectionWaitTimeout > 0)
/*      */     {
/* 1466 */       notifyAll();
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private String buildAttrKey(Properties paramProperties)
/*      */     throws SQLException
/*      */   {
/* 1484 */     int i = paramProperties.keySet().size();
/* 1485 */     Object[] arrayOfObject = paramProperties.keySet().toArray();
/* 1486 */     int j = 1;
/* 1487 */     StringBuffer localStringBuffer = new StringBuffer();
/*      */     
/*      */ 
/* 1490 */     while (j != 0)
/*      */     {
/* 1492 */       j = 0;
/*      */       
/* 1494 */       for (k = 0; k < i - 1; k++)
/*      */       {
/* 1496 */         if (((String)arrayOfObject[k]).compareTo((String)arrayOfObject[(k + 1)]) > 0)
/*      */         {
/* 1498 */           j = 1;
/*      */           
/* 1500 */           Object localObject = arrayOfObject[k];
/*      */           
/* 1502 */           arrayOfObject[k] = arrayOfObject[(k + 1)];
/* 1503 */           arrayOfObject[(k + 1)] = localObject;
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*      */ 
/* 1509 */     for (int k = 0; k < i; k++) {
/* 1510 */       localStringBuffer.append(arrayOfObject[k] + "0xffff" + paramProperties.get(arrayOfObject[k]));
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 1515 */     return localStringBuffer.toString();
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected OraclePooledConnection makeCacheConnection(String paramString1, String paramString2)
/*      */     throws SQLException
/*      */   {
/* 1529 */     OraclePooledConnection localOraclePooledConnection = (OraclePooledConnection)this.connectionPoolDS.getPooledConnection(paramString1, paramString2);
/*      */     
/*      */ 
/*      */ 
/* 1533 */     if (localOraclePooledConnection != null)
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1541 */       if (this.cacheMaxStatementsLimit > 0) {
/* 1542 */         setStatementCaching(localOraclePooledConnection, this.cacheMaxStatementsLimit, true);
/*      */       }
/*      */       
/* 1545 */       localOraclePooledConnection.registerImplicitCacheConnectionEventListener(new OracleConnectionCacheEventListener(this));
/*      */       
/*      */ 
/* 1548 */       localOraclePooledConnection.cachedConnectionAttributes = new Properties();
/*      */       
/*      */ 
/* 1551 */       if (this.fastConnectionFailoverEnabled)
/*      */       {
/* 1553 */         initFailoverParameters(localOraclePooledConnection);
/*      */       }
/*      */       
/*      */ 
/* 1557 */       synchronized (this)
/*      */       {
/* 1559 */         this.cacheSize += 1;
/*      */         
/*      */ 
/*      */ 
/*      */ 
/* 1564 */         if ((this.fastConnectionFailoverEnabled) && (this.runtimeLoadBalancingThread == null))
/*      */         {
/*      */ 
/* 1567 */           this.runtimeLoadBalancingThread = new OracleRuntimeLoadBalancingEventHandlerThread(this.dataSourceServiceName);
/*      */           
/* 1569 */           this.cacheManager.checkAndStartThread(this.runtimeLoadBalancingThread);
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*      */ 
/* 1575 */     return localOraclePooledConnection;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   private void setStatementCaching(OraclePooledConnection paramOraclePooledConnection, int paramInt, boolean paramBoolean)
/*      */     throws SQLException
/*      */   {
/* 1583 */     if (paramInt > 0) {
/* 1584 */       paramOraclePooledConnection.setStatementCacheSize(paramInt);
/*      */     }
/* 1586 */     paramOraclePooledConnection.setImplicitCachingEnabled(paramBoolean);
/* 1587 */     paramOraclePooledConnection.setExplicitCachingEnabled(paramBoolean);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected synchronized void reusePooledConnection(PooledConnection paramPooledConnection)
/*      */     throws SQLException
/*      */   {
/* 1608 */     OraclePooledConnection localOraclePooledConnection = (OraclePooledConnection)paramPooledConnection;
/* 1609 */     if ((localOraclePooledConnection != null) && (localOraclePooledConnection.physicalConn != null))
/*      */     {
/* 1611 */       storeCacheConnection(localOraclePooledConnection.pcUser, localOraclePooledConnection.cachedConnectionAttributes, localOraclePooledConnection);
/*      */       
/*      */ 
/* 1614 */       this.checkedOutConnectionList.removeElement(localOraclePooledConnection);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void closePooledConnection(PooledConnection paramPooledConnection)
/*      */     throws SQLException
/*      */   {
/* 1638 */     if (paramPooledConnection != null)
/*      */     {
/* 1640 */       actualPooledConnectionClose((OraclePooledConnection)paramPooledConnection);
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1646 */       if (((OraclePooledConnection)paramPooledConnection).closeOption == 4096) {
/* 1647 */         this.checkedOutConnectionList.removeElement(paramPooledConnection);
/*      */       }
/* 1649 */       paramPooledConnection = null;
/*      */       
/* 1651 */       if (getTotalCachedConnections() < this.cacheMinLimit) {
/* 1652 */         defaultUserPrePopulateCache(1);
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void refreshCacheConnections(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1670 */     doForEveryCachedConnection(paramInt);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected synchronized void reinitializeCacheConnections(Properties paramProperties)
/*      */     throws SQLException
/*      */   {
/* 1686 */     this.defaultUser = this.cacheEnabledDS.getUser();
/* 1687 */     this.defaultPassword = this.cacheEnabledDS.getPassword();
/* 1688 */     this.fastConnectionFailoverEnabled = this.cacheEnabledDS.getFastConnectionFailoverEnabled();
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1696 */     cleanupTimeoutThread();
/*      */     
/*      */ 
/*      */ 
/* 1700 */     doForEveryCheckedOutConnection(1);
/*      */     
/*      */ 
/* 1703 */     int i = this.cacheInitialLimit;
/* 1704 */     int j = this.cacheMaxLimit;
/* 1705 */     int k = this.cacheMaxStatementsLimit;
/*      */     
/*      */ 
/* 1708 */     setConnectionCacheProperties(paramProperties);
/*      */     
/*      */ 
/* 1711 */     if (this.cacheInitialLimit > i)
/*      */     {
/* 1713 */       int m = this.cacheInitialLimit - i;
/*      */       
/* 1715 */       defaultUserPrePopulateCache(m);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1722 */     if (j != Integer.MAX_VALUE)
/*      */     {
/* 1724 */       if ((this.cacheMaxLimit < j) && (this.cacheSize > this.cacheMaxLimit))
/*      */       {
/* 1726 */         this.connectionsToRemove = (this.cacheSize - this.cacheMaxLimit);
/*      */         
/* 1728 */         doForEveryCachedConnection(8);
/*      */         
/* 1730 */         this.connectionsToRemove = 0;
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 1736 */     if (this.cacheMaxStatementsLimit != k)
/*      */     {
/* 1738 */       if (this.cacheMaxStatementsLimit == 0) {
/* 1739 */         doForEveryCachedConnection(16);
/*      */       } else {
/* 1741 */         doForEveryCachedConnection(18);
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected synchronized void setConnectionCacheProperties(Properties paramProperties)
/*      */     throws SQLException
/*      */   {
/*      */     try
/*      */     {
/* 1768 */       if (paramProperties != null)
/*      */       {
/* 1770 */         String str = null;
/*      */         
/*      */ 
/* 1773 */         if ((str = paramProperties.getProperty("MinLimit")) != null)
/*      */         {
/* 1775 */           if ((this.cacheMinLimit = Integer.parseInt(str)) < 0) {
/* 1776 */             this.cacheMinLimit = 0;
/*      */           }
/*      */         }
/*      */         
/* 1780 */         if ((str = paramProperties.getProperty("MaxLimit")) != null)
/*      */         {
/* 1782 */           if ((this.cacheMaxLimit = Integer.parseInt(str)) < 0) {
/* 1783 */             this.cacheMaxLimit = Integer.MAX_VALUE;
/*      */           }
/*      */         }
/*      */         
/* 1787 */         if (this.cacheMaxLimit < this.cacheMinLimit) {
/* 1788 */           this.cacheMinLimit = this.cacheMaxLimit;
/*      */         }
/*      */         
/* 1791 */         if ((str = paramProperties.getProperty("InitialLimit")) != null)
/*      */         {
/* 1793 */           if ((this.cacheInitialLimit = Integer.parseInt(str)) < 0) {
/* 1794 */             this.cacheInitialLimit = 0;
/*      */           }
/*      */         }
/* 1797 */         if (this.cacheInitialLimit > this.cacheMaxLimit) {
/* 1798 */           this.cacheInitialLimit = this.cacheMaxLimit;
/*      */         }
/*      */         
/* 1801 */         if ((str = paramProperties.getProperty("MaxStatementsLimit")) != null)
/*      */         {
/* 1803 */           if ((this.cacheMaxStatementsLimit = Integer.parseInt(str)) < 0) {
/* 1804 */             this.cacheMaxStatementsLimit = 0;
/*      */           }
/*      */         }
/*      */         
/* 1808 */         Properties localProperties = (Properties)paramProperties.get("AttributeWeights");
/*      */         
/*      */ 
/* 1811 */         if (localProperties != null)
/*      */         {
/* 1813 */           Map.Entry localEntry = null;
/* 1814 */           int i = 0;
/* 1815 */           Object localObject = null;
/*      */           
/* 1817 */           Iterator localIterator = localProperties.entrySet().iterator();
/*      */           
/* 1819 */           while (localIterator.hasNext())
/*      */           {
/* 1821 */             localEntry = (Map.Entry)localIterator.next();
/* 1822 */             localObject = localEntry.getKey();
/*      */             
/* 1824 */             if (((str = (String)localProperties.get(localObject)) != null) && 
/*      */             
/* 1826 */               ((i = Integer.parseInt(str)) < 0)) {
/* 1827 */               localProperties.put(localObject, "0");
/*      */             }
/*      */           }
/*      */           
/* 1831 */           if (this.cacheAttributeWeights == null) {
/* 1832 */             this.cacheAttributeWeights = new Properties();
/*      */           }
/* 1834 */           this.cacheAttributeWeights.putAll(localProperties);
/*      */         }
/*      */         
/*      */ 
/* 1838 */         if ((str = paramProperties.getProperty("InactivityTimeout")) != null)
/*      */         {
/* 1840 */           if ((this.cacheInactivityTimeout = Integer.parseInt(str)) < 0) {
/* 1841 */             this.cacheInactivityTimeout = 0;
/*      */           }
/*      */         }
/*      */         
/* 1845 */         if ((str = paramProperties.getProperty("TimeToLiveTimeout")) != null)
/*      */         {
/* 1847 */           if ((this.cacheTimeToLiveTimeout = Integer.parseInt(str)) < 0) {
/* 1848 */             this.cacheTimeToLiveTimeout = 0;
/*      */           }
/*      */         }
/*      */         
/* 1852 */         if ((str = paramProperties.getProperty("AbandonedConnectionTimeout")) != null)
/*      */         {
/* 1854 */           if ((this.cacheAbandonedConnectionTimeout = Integer.parseInt(str)) < 0) {
/* 1855 */             this.cacheAbandonedConnectionTimeout = 0;
/*      */           }
/*      */         }
/*      */         
/* 1859 */         if ((str = paramProperties.getProperty("LowerThresholdLimit")) != null)
/*      */         {
/* 1861 */           this.cacheLowerThresholdLimit = Integer.parseInt(str);
/*      */           
/* 1863 */           if ((this.cacheLowerThresholdLimit < 0) || (this.cacheLowerThresholdLimit > 100))
/*      */           {
/* 1865 */             this.cacheLowerThresholdLimit = 20;
/*      */           }
/*      */         }
/*      */         
/* 1869 */         if ((str = paramProperties.getProperty("PropertyCheckInterval")) != null)
/*      */         {
/* 1871 */           if ((this.cachePropertyCheckInterval = Integer.parseInt(str)) < 0) {
/* 1872 */             this.cachePropertyCheckInterval = 900;
/*      */           }
/*      */         }
/*      */         
/* 1876 */         if ((str = paramProperties.getProperty("ValidateConnection")) != null) {
/* 1877 */           this.cacheValidateConnection = Boolean.valueOf(str).booleanValue();
/*      */         }
/*      */         
/*      */ 
/* 1881 */         if ((str = paramProperties.getProperty("ClosestConnectionMatch")) != null)
/*      */         {
/* 1883 */           this.cacheClosestConnectionMatch = Boolean.valueOf(str).booleanValue();
/*      */         }
/*      */         
/*      */ 
/* 1887 */         if ((str = paramProperties.getProperty("ConnectionWaitTimeout")) != null)
/*      */         {
/* 1889 */           if ((this.cacheConnectionWaitTimeout = Integer.parseInt(str)) < 0) {
/* 1890 */             this.cacheConnectionWaitTimeout = 0;
/*      */           }
/*      */         }
/*      */       }
/*      */       else
/*      */       {
/* 1896 */         this.cacheMinLimit = 0;
/* 1897 */         this.cacheMaxLimit = Integer.MAX_VALUE;
/* 1898 */         this.cacheInitialLimit = 0;
/* 1899 */         this.cacheMaxStatementsLimit = 0;
/* 1900 */         this.cacheAttributeWeights = null;
/* 1901 */         this.cacheInactivityTimeout = 0;
/* 1902 */         this.cacheTimeToLiveTimeout = 0;
/* 1903 */         this.cacheAbandonedConnectionTimeout = 0;
/* 1904 */         this.cacheLowerThresholdLimit = 20;
/* 1905 */         this.cachePropertyCheckInterval = 900;
/* 1906 */         this.cacheClosestConnectionMatch = false;
/* 1907 */         this.cacheValidateConnection = false;
/* 1908 */         this.cacheConnectionWaitTimeout = 0;
/*      */       }
/*      */       
/*      */ 
/* 1912 */       if ((this.cacheInactivityTimeout > 0) || (this.cacheTimeToLiveTimeout > 0) || (this.cacheAbandonedConnectionTimeout > 0))
/*      */       {
/*      */ 
/* 1915 */         if (this.timeoutThread == null) {
/* 1916 */           this.timeoutThread = new OracleImplicitConnectionCacheThread(this);
/*      */         }
/* 1918 */         this.cacheManager.checkAndStartThread(this.timeoutThread);
/*      */       }
/*      */     }
/*      */     catch (NumberFormatException localNumberFormatException)
/*      */     {
/* 1923 */       DatabaseError.throwSqlException(139);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected Properties getConnectionCacheProperties()
/*      */     throws SQLException
/*      */   {
/* 1936 */     Properties localProperties = new Properties();
/*      */     
/* 1938 */     localProperties.setProperty("MinLimit", String.valueOf(this.cacheMinLimit));
/* 1939 */     localProperties.setProperty("MaxLimit", String.valueOf(this.cacheMaxLimit));
/* 1940 */     localProperties.setProperty("InitialLimit", String.valueOf(this.cacheInitialLimit));
/* 1941 */     localProperties.setProperty("MaxStatementsLimit", String.valueOf(this.cacheMaxStatementsLimit));
/*      */     
/*      */ 
/* 1944 */     if (this.cacheAttributeWeights != null) {
/* 1945 */       localProperties.put("AttributeWeights", this.cacheAttributeWeights);
/*      */     } else {
/* 1947 */       localProperties.setProperty("AttributeWeights", "NULL");
/*      */     }
/* 1949 */     localProperties.setProperty("InactivityTimeout", String.valueOf(this.cacheInactivityTimeout));
/*      */     
/* 1951 */     localProperties.setProperty("TimeToLiveTimeout", String.valueOf(this.cacheTimeToLiveTimeout));
/*      */     
/* 1953 */     localProperties.setProperty("AbandonedConnectionTimeout", String.valueOf(this.cacheAbandonedConnectionTimeout));
/*      */     
/* 1955 */     localProperties.setProperty("LowerThresholdLimit", String.valueOf(this.cacheLowerThresholdLimit));
/*      */     
/* 1957 */     localProperties.setProperty("PropertyCheckInterval", String.valueOf(this.cachePropertyCheckInterval));
/*      */     
/* 1959 */     localProperties.setProperty("ConnectionWaitTimeout", String.valueOf(this.cacheConnectionWaitTimeout));
/*      */     
/* 1961 */     localProperties.setProperty("ValidateConnection", String.valueOf(this.cacheValidateConnection));
/*      */     
/* 1963 */     localProperties.setProperty("ClosestConnectionMatch", String.valueOf(this.cacheClosestConnectionMatch));
/*      */     
/*      */ 
/* 1966 */     return localProperties;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected int testDatabaseConnection(OracleConnection paramOracleConnection)
/*      */     throws SQLException
/*      */   {
/* 1979 */     return paramOracleConnection.pingDatabase(0);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected synchronized void closeConnectionCache()
/*      */     throws SQLException
/*      */   {
/* 1996 */     cleanupTimeoutThread();
/*      */     
/*      */ 
/*      */ 
/* 2000 */     purgeCacheConnections(true);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2007 */     this.connectionPoolDS = null;
/* 2008 */     this.cacheEnabledDS = null;
/* 2009 */     this.checkedOutConnectionList = null;
/* 2010 */     this.userMap = null;
/* 2011 */     this.cacheManager = null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected synchronized void disableConnectionCache()
/*      */     throws SQLException
/*      */   {
/* 2023 */     this.disableConnectionRequest = true;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected synchronized void enableConnectionCache()
/*      */     throws SQLException
/*      */   {
/* 2037 */     this.disableConnectionRequest = false;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void initFailoverParameters(OraclePooledConnection paramOraclePooledConnection)
/*      */     throws SQLException
/*      */   {
/* 2052 */     String str1 = null;
/* 2053 */     String str2 = null;
/* 2054 */     String str3 = null;
/*      */     
/* 2056 */     Properties localProperties = ((OracleConnection)paramOraclePooledConnection.getPhysicalHandle()).getServerSessionInfo();
/*      */     
/* 2058 */     str3 = localProperties.getProperty("INSTANCE_NAME");
/* 2059 */     if (str3 != null) {
/* 2060 */       str1 = paramOraclePooledConnection.dataSourceInstanceNameKey = str3.trim().intern();
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 2065 */     str3 = localProperties.getProperty("SERVER_HOST");
/* 2066 */     if (str3 != null) {
/* 2067 */       paramOraclePooledConnection.dataSourceHostNameKey = str3.trim().intern();
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2073 */     str3 = localProperties.getProperty("SERVICE_NAME");
/* 2074 */     if (str3 != null) {
/* 2075 */       this.dataSourceServiceName = str3.trim();
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 2080 */     str3 = localProperties.getProperty("DATABASE_NAME");
/* 2081 */     if (str3 != null) {
/* 2082 */       str2 = paramOraclePooledConnection.dataSourceDbUniqNameKey = str3.trim().intern();
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2090 */     if (this.databaseInstancesList == null) {
/* 2091 */       this.databaseInstancesList = new LinkedList();
/*      */     }
/* 2093 */     int i = this.databaseInstancesList.size();
/* 2094 */     synchronized (this.databaseInstancesList)
/*      */     {
/* 2096 */       OracleDatabaseInstance localOracleDatabaseInstance1 = null;
/* 2097 */       int j = 0;
/*      */       
/* 2099 */       for (int k = 0; k < i; k++)
/*      */       {
/* 2101 */         localOracleDatabaseInstance1 = (OracleDatabaseInstance)this.databaseInstancesList.get(k);
/* 2102 */         if ((localOracleDatabaseInstance1.databaseUniqName == str2) && (localOracleDatabaseInstance1.instanceName == str1))
/*      */         {
/*      */ 
/* 2105 */           localOracleDatabaseInstance1.numberOfConnectionsCount += 1;
/* 2106 */           j = 1;
/* 2107 */           break;
/*      */         }
/*      */       }
/*      */       
/* 2111 */       if (j == 0)
/*      */       {
/* 2113 */         OracleDatabaseInstance localOracleDatabaseInstance2 = new OracleDatabaseInstance(str2, str1);
/*      */         
/*      */ 
/* 2116 */         localOracleDatabaseInstance2.numberOfConnectionsCount += 1;
/* 2117 */         this.databaseInstancesList.add(localOracleDatabaseInstance2);
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void processFailoverEvent(int paramInt1, String paramString1, String paramString2, String paramString3, String paramString4, int paramInt2)
/*      */   {
/* 2144 */     if (paramInt1 == 256)
/*      */     {
/* 2146 */       if ((paramString4.equalsIgnoreCase("down")) || (paramString4.equalsIgnoreCase("not_restarting")) || (paramString4.equalsIgnoreCase("restart_failed")))
/*      */       {
/*      */ 
/*      */ 
/* 2150 */         this.downEventCount += 1;
/*      */         
/* 2152 */         markDownLostConnections(true, false, paramString1, paramString2, paramString3, paramString4);
/*      */         
/* 2154 */         cleanupFailoverConnections(true, false, paramString1, paramString2, paramString3, paramString4);
/*      */ 
/*      */       }
/* 2157 */       else if (paramString4.equalsIgnoreCase("up"))
/*      */       {
/*      */ 
/*      */ 
/* 2161 */         if (this.downEventCount > 0) {
/* 2162 */           this.upEventCount += 1;
/*      */         }
/*      */         try
/*      */         {
/* 2166 */           processUpEvent(paramInt2);
/*      */         }
/*      */         catch (Exception localException) {}
/*      */         
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2175 */         this.isEntireServiceDownProcessed = false;
/*      */       }
/*      */     }
/* 2178 */     else if ((paramInt1 == 512) && (paramString4.equalsIgnoreCase("nodedown")))
/*      */     {
/*      */ 
/* 2181 */       markDownLostConnections(false, true, paramString1, paramString2, paramString3, paramString4);
/*      */       
/* 2183 */       cleanupFailoverConnections(false, true, paramString1, paramString2, paramString3, paramString4);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   synchronized void processUpEvent(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 2262 */     int i = 0;
/* 2263 */     int j = 0;
/* 2264 */     int k = getTotalCachedConnections();
/* 2265 */     boolean bool = false;
/*      */     
/*      */ 
/* 2268 */     if (paramInt <= 1) {
/* 2269 */       paramInt = 2;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2276 */     if ((this.downEventCount == 0) && (this.upEventCount == 0) && (getNumberOfDefaultUserConnections() > 0))
/*      */     {
/*      */ 
/*      */ 
/* 2280 */       i = (int)(this.cacheSize * 0.25D);
/*      */     }
/*      */     else
/*      */     {
/* 2284 */       i = this.defaultUserPreFailureSize;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2296 */     if (i <= 0)
/*      */     {
/* 2298 */       if (getNumberOfDefaultUserConnections() > 0)
/*      */       {
/* 2300 */         j = (int)(this.cacheSize * 0.25D);
/* 2301 */         bool = true;
/*      */ 
/*      */       }
/*      */       
/*      */ 
/*      */     }
/*      */     else
/*      */     {
/*      */ 
/* 2310 */       j = i / paramInt;
/*      */       
/*      */ 
/*      */ 
/* 2314 */       if (j + k > this.cacheMaxLimit) {
/* 2315 */         bool = true;
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 2321 */     if (j > 0) {
/* 2322 */       loadBalanceConnections(j, bool);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2335 */     if (this.downEventCount == this.upEventCount)
/*      */     {
/* 2337 */       this.defaultUserPreFailureSize = 0;
/* 2338 */       this.downEventCount = 0;
/* 2339 */       this.upEventCount = 0;
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void loadBalanceConnections(int paramInt, boolean paramBoolean)
/*      */     throws SQLException
/*      */   {
/* 2352 */     if (paramBoolean)
/*      */     {
/* 2354 */       this.connectionsToRemove = paramInt;
/*      */       
/* 2356 */       doForEveryCachedConnection(8);
/*      */       
/* 2358 */       this.connectionsToRemove = 0;
/*      */     }
/*      */     
/*      */ 
/* 2362 */     if (paramInt <= 10)
/*      */     {
/*      */       try
/*      */       {
/* 2366 */         defaultUserPrePopulateCache(paramInt);
/*      */ 
/*      */ 
/*      */ 
/*      */       }
/*      */       catch (Exception localException1) {}
/*      */ 
/*      */ 
/*      */     }
/*      */     else
/*      */     {
/*      */ 
/*      */ 
/* 2379 */       int i = (int)(paramInt * 0.25D);
/*      */       
/* 2381 */       for (int j = 0; j < 4; j++)
/*      */       {
/*      */         try
/*      */         {
/* 2385 */           defaultUserPrePopulateCache(i);
/*      */         }
/*      */         catch (Exception localException2) {}
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private int getNumberOfDefaultUserConnections()
/*      */   {
/* 2404 */     int i = 0;
/*      */     
/* 2406 */     if ((this.userMap != null) && (!this.userMap.isEmpty()))
/*      */     {
/* 2408 */       OracleConnectionCacheEntry localOracleConnectionCacheEntry = (OracleConnectionCacheEntry)this.userMap.get(this.defaultUser + this.defaultPassword.toUpperCase());
/*      */       
/*      */ 
/*      */ 
/* 2412 */       if ((localOracleConnectionCacheEntry != null) && (localOracleConnectionCacheEntry.userConnList != null) && (!localOracleConnectionCacheEntry.userConnList.isEmpty()))
/*      */       {
/*      */ 
/* 2415 */         i = localOracleConnectionCacheEntry.userConnList.size();
/*      */       }
/*      */     }
/*      */     
/* 2419 */     return i;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   synchronized void markDownLostConnections(boolean paramBoolean1, boolean paramBoolean2, String paramString1, String paramString2, String paramString3, String paramString4)
/*      */   {
/* 2440 */     if (!this.isEntireServiceDownProcessed)
/*      */     {
/* 2442 */       if ((this.userMap != null) && (!this.userMap.isEmpty()))
/*      */       {
/*      */ 
/*      */ 
/* 2446 */         Iterator localIterator1 = this.userMap.entrySet().iterator();
/*      */         
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2454 */         while (localIterator1.hasNext())
/*      */         {
/* 2456 */           int i = 0;
/*      */           
/* 2458 */           Map.Entry localEntry = (Map.Entry)localIterator1.next();
/*      */           
/*      */ 
/* 2461 */           if ((this.defaultUser != null) && (this.defaultUser.equalsIgnoreCase((String)localEntry.getKey())))
/*      */           {
/* 2463 */             i = 1;
/*      */           }
/* 2465 */           OracleConnectionCacheEntry localOracleConnectionCacheEntry = (OracleConnectionCacheEntry)localEntry.getValue();
/*      */           
/*      */           Object localObject1;
/*      */           Object localObject2;
/* 2469 */           if ((localOracleConnectionCacheEntry != null) && (localOracleConnectionCacheEntry.userConnList != null) && (!localOracleConnectionCacheEntry.userConnList.isEmpty()))
/*      */           {
/*      */ 
/* 2472 */             boolean bool = false;
/* 2473 */             localObject1 = localOracleConnectionCacheEntry.userConnList.iterator();
/*      */             
/* 2475 */             while (((Iterator)localObject1).hasNext())
/*      */             {
/* 2477 */               localObject2 = (OraclePooledConnection)((Iterator)localObject1).next();
/*      */               
/* 2479 */               if (paramBoolean1) {
/* 2480 */                 bool = markDownConnectionsForServiceEvent(paramString1, paramString2, (OraclePooledConnection)localObject2);
/*      */               }
/* 2482 */               else if (paramBoolean2) {
/* 2483 */                 bool = markDownConnectionsForHostEvent(paramString3, (OraclePooledConnection)localObject2);
/*      */               }
/*      */               
/*      */ 
/* 2487 */               if ((bool) && (i != 0)) {
/* 2488 */                 this.defaultUserPreFailureSize += 1;
/*      */               }
/*      */             }
/*      */           }
/*      */           
/* 2493 */           if ((localOracleConnectionCacheEntry != null) && (localOracleConnectionCacheEntry.attrConnMap != null) && (!localOracleConnectionCacheEntry.attrConnMap.isEmpty()))
/*      */           {
/*      */ 
/* 2496 */             Iterator localIterator2 = localOracleConnectionCacheEntry.attrConnMap.entrySet().iterator();
/*      */             
/* 2498 */             while (localIterator2.hasNext())
/*      */             {
/* 2500 */               localObject1 = (Map.Entry)localIterator2.next();
/* 2501 */               localObject2 = ((Vector)((Map.Entry)localObject1).getValue()).iterator();
/*      */               
/* 2503 */               while (((Iterator)localObject2).hasNext())
/*      */               {
/* 2505 */                 OraclePooledConnection localOraclePooledConnection = (OraclePooledConnection)((Iterator)localObject2).next();
/*      */                 
/* 2507 */                 if (paramBoolean1) {
/* 2508 */                   markDownConnectionsForServiceEvent(paramString1, paramString2, localOraclePooledConnection);
/*      */                 }
/* 2510 */                 else if (paramBoolean2) {
/* 2511 */                   markDownConnectionsForHostEvent(paramString3, localOraclePooledConnection);
/*      */                 }
/*      */               }
/*      */             }
/*      */           }
/*      */         }
/*      */       }
/* 2518 */       if (paramString1 == null) {
/* 2519 */         this.isEntireServiceDownProcessed = true;
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private boolean markDownConnectionsForServiceEvent(String paramString1, String paramString2, OraclePooledConnection paramOraclePooledConnection)
/*      */   {
/* 2531 */     boolean bool = false;
/*      */     
/* 2533 */     if ((paramString1 == null) || ((paramString2 == paramOraclePooledConnection.dataSourceDbUniqNameKey) && (paramString1 == paramOraclePooledConnection.dataSourceInstanceNameKey)))
/*      */     {
/*      */ 
/*      */ 
/* 2537 */       paramOraclePooledConnection.connectionMarkedDown = true;
/* 2538 */       bool = true;
/*      */     }
/*      */     
/* 2541 */     return bool;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private boolean markDownConnectionsForHostEvent(String paramString, OraclePooledConnection paramOraclePooledConnection)
/*      */   {
/* 2550 */     boolean bool = false;
/*      */     
/* 2552 */     if (paramString == paramOraclePooledConnection.dataSourceHostNameKey)
/*      */     {
/* 2554 */       paramOraclePooledConnection.connectionMarkedDown = true;
/* 2555 */       paramOraclePooledConnection.isHostDown = true;
/* 2556 */       bool = true;
/*      */     }
/*      */     
/* 2559 */     return bool;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   synchronized void cleanupFailoverConnections(boolean paramBoolean1, boolean paramBoolean2, String paramString1, String paramString2, String paramString3, String paramString4)
/*      */   {
/* 2581 */     OraclePooledConnection localOraclePooledConnection = null;
/* 2582 */     Object[] arrayOfObject = this.checkedOutConnectionList.toArray();
/* 2583 */     int i = this.checkedOutConnectionList.size();
/*      */     
/* 2585 */     OraclePooledConnection[] arrayOfOraclePooledConnection = new OraclePooledConnection[i];
/* 2586 */     int j = 0;
/*      */     
/* 2588 */     for (int k = 0; k < i; k++)
/*      */     {
/*      */       try
/*      */       {
/* 2592 */         localOraclePooledConnection = (OraclePooledConnection)arrayOfObject[k];
/*      */         
/* 2594 */         if (((paramBoolean1) && ((paramString1 == null) || (paramString1 == localOraclePooledConnection.dataSourceInstanceNameKey)) && (paramString2 == localOraclePooledConnection.dataSourceDbUniqNameKey)) || ((paramBoolean2) && (paramString3 == localOraclePooledConnection.dataSourceHostNameKey)))
/*      */         {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2601 */           if ((this.defaultUser != null) && (this.defaultUser.equalsIgnoreCase(localOraclePooledConnection.pcUser)) && (localOraclePooledConnection.cachedConnectionAttributes != null) && (localOraclePooledConnection.cachedConnectionAttributes.isEmpty()))
/*      */           {
/*      */ 
/*      */ 
/* 2605 */             this.defaultUserPreFailureSize += 1;
/*      */           }
/*      */           
/* 2608 */           this.checkedOutConnectionList.removeElement(localOraclePooledConnection);
/*      */           
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2615 */           abortConnection(localOraclePooledConnection);
/* 2616 */           localOraclePooledConnection.isHostDown = true;
/*      */           
/*      */ 
/* 2619 */           arrayOfOraclePooledConnection[(j++)] = localOraclePooledConnection;
/*      */         }
/*      */       }
/*      */       catch (Exception localException) {}
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2630 */     for (k = 0; k < j; k++)
/*      */     {
/*      */       try
/*      */       {
/* 2634 */         closeCheckedOutConnection(arrayOfOraclePooledConnection[k], false);
/*      */       }
/*      */       catch (SQLException localSQLException2) {}
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2644 */     if ((this.checkedOutConnectionList.size() < i) && (this.cacheConnectionWaitTimeout > 0))
/*      */     {
/*      */ 
/* 2647 */       notifyAll();
/*      */     }
/*      */     
/*      */ 
/*      */     try
/*      */     {
/* 2653 */       doForEveryCachedConnection(2);
/*      */     }
/*      */     catch (SQLException localSQLException1) {}
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2663 */     if ((this.databaseInstancesList != null) && ((i = this.databaseInstancesList.size()) > 0))
/*      */     {
/*      */ 
/* 2666 */       synchronized (this.databaseInstancesList)
/*      */       {
/* 2668 */         OracleDatabaseInstance localOracleDatabaseInstance = null;
/* 2669 */         arrayOfObject = this.databaseInstancesList.toArray();
/*      */         
/* 2671 */         for (int m = 0; m < i; m++)
/*      */         {
/* 2673 */           localOracleDatabaseInstance = (OracleDatabaseInstance)arrayOfObject[m];
/*      */           
/* 2675 */           if ((localOracleDatabaseInstance.databaseUniqName == paramString2) && (localOracleDatabaseInstance.instanceName == paramString1))
/*      */           {
/*      */ 
/*      */ 
/* 2679 */             if (localOracleDatabaseInstance.flag <= 3)
/* 2680 */               this.dbInstancePercentTotal -= localOracleDatabaseInstance.percent;
/* 2681 */             this.databaseInstancesList.remove(localOracleDatabaseInstance);
/*      */           }
/*      */         }
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   void zapRLBInfo()
/*      */   {
/* 2693 */     this.databaseInstancesList.clear();
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected synchronized void closeAndRemovePooledConnection(OraclePooledConnection paramOraclePooledConnection)
/*      */     throws SQLException
/*      */   {
/* 2705 */     if (paramOraclePooledConnection != null)
/*      */     {
/* 2707 */       if (paramOraclePooledConnection.isHostDown) {
/* 2708 */         abortConnection(paramOraclePooledConnection);
/*      */       }
/* 2710 */       actualPooledConnectionClose(paramOraclePooledConnection);
/* 2711 */       removeCacheConnection(paramOraclePooledConnection);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void abortConnection(OraclePooledConnection paramOraclePooledConnection)
/*      */   {
/*      */     try
/*      */     {
/* 2728 */       ((OracleConnection)paramOraclePooledConnection.getPhysicalHandle()).abort();
/*      */     }
/*      */     catch (Exception localException) {}
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void actualPooledConnectionClose(OraclePooledConnection paramOraclePooledConnection)
/*      */     throws SQLException
/*      */   {
/* 2751 */     int i = 0;
/* 2752 */     if ((this.databaseInstancesList != null) && ((i = this.databaseInstancesList.size()) > 0))
/*      */     {
/*      */ 
/* 2755 */       synchronized (this.databaseInstancesList)
/*      */       {
/* 2757 */         OracleDatabaseInstance localOracleDatabaseInstance = null;
/*      */         
/* 2759 */         for (int j = 0; j < i; j++)
/*      */         {
/* 2761 */           localOracleDatabaseInstance = (OracleDatabaseInstance)this.databaseInstancesList.get(j);
/* 2762 */           if ((localOracleDatabaseInstance.databaseUniqName == paramOraclePooledConnection.dataSourceDbUniqNameKey) && (localOracleDatabaseInstance.instanceName == paramOraclePooledConnection.dataSourceInstanceNameKey))
/*      */           {
/*      */ 
/* 2765 */             if (localOracleDatabaseInstance.numberOfConnectionsCount <= 0) break;
/* 2766 */             localOracleDatabaseInstance.numberOfConnectionsCount -= 1; break;
/*      */           }
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */     try
/*      */     {
/* 2776 */       paramOraclePooledConnection.close();
/*      */     }
/*      */     catch (SQLException localSQLException) {}
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected int getCacheTimeToLiveTimeout()
/*      */   {
/* 2787 */     return this.cacheTimeToLiveTimeout;
/*      */   }
/*      */   
/*      */   protected int getCacheInactivityTimeout()
/*      */   {
/* 2792 */     return this.cacheInactivityTimeout;
/*      */   }
/*      */   
/*      */   protected int getCachePropertyCheckInterval()
/*      */   {
/* 2797 */     return this.cachePropertyCheckInterval;
/*      */   }
/*      */   
/*      */   protected int getCacheAbandonedTimeout()
/*      */   {
/* 2802 */     return this.cacheAbandonedConnectionTimeout;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private synchronized void processConnectionCacheCallback()
/*      */     throws SQLException
/*      */   {
/* 2817 */     float f = this.cacheMaxLimit / 100.0F;
/* 2818 */     int i = (int)(this.cacheLowerThresholdLimit * f);
/*      */     
/*      */ 
/* 2821 */     releaseBasedOnPriority(1024, i);
/*      */     
/*      */ 
/* 2824 */     if (this.cacheSize < i) {
/* 2825 */       releaseBasedOnPriority(512, i);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void releaseBasedOnPriority(int paramInt1, int paramInt2)
/*      */     throws SQLException
/*      */   {
/* 2838 */     Object[] arrayOfObject = this.checkedOutConnectionList.toArray();
/*      */     
/* 2840 */     for (int i = 0; (i < arrayOfObject.length) && (this.cacheSize < paramInt2); i++)
/*      */     {
/* 2842 */       OraclePooledConnection localOraclePooledConnection = (OraclePooledConnection)arrayOfObject[i];
/* 2843 */       OracleConnection localOracleConnection = null;
/*      */       
/* 2845 */       if (localOraclePooledConnection != null) {
/* 2846 */         localOracleConnection = (OracleConnection)localOraclePooledConnection.getLogicalHandle();
/*      */       }
/* 2848 */       if (localOracleConnection != null)
/*      */       {
/* 2850 */         OracleConnectionCacheCallback localOracleConnectionCacheCallback = localOracleConnection.getConnectionCacheCallbackObj();
/*      */         
/*      */ 
/* 2853 */         if ((localOracleConnectionCacheCallback != null) && ((localOracleConnection.getConnectionCacheCallbackFlag() == 2) || (localOracleConnection.getConnectionCacheCallbackFlag() == 4)))
/*      */         {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2859 */           if (paramInt1 == localOracleConnection.getConnectionReleasePriority())
/*      */           {
/* 2861 */             Object localObject = localOracleConnection.getConnectionCacheCallbackPrivObj();
/* 2862 */             localOracleConnectionCacheCallback.releaseConnection(localOracleConnection, localObject);
/*      */           }
/*      */         }
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private synchronized void processConnectionWaitTimeout(long paramLong)
/*      */     throws SQLException
/*      */   {
/*      */     try
/*      */     {
/* 2884 */       wait(paramLong);
/*      */     }
/*      */     catch (InterruptedException localInterruptedException) {}
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void processInactivityTimeout(OraclePooledConnection paramOraclePooledConnection)
/*      */     throws SQLException
/*      */   {
/* 2908 */     long l1 = paramOraclePooledConnection.getLastAccessedTime();
/* 2909 */     long l2 = System.currentTimeMillis();
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2917 */     if ((getTotalCachedConnections() > this.cacheMinLimit) && (l2 - l1 > this.cacheInactivityTimeout * 1000))
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2924 */       closeAndRemovePooledConnection(paramOraclePooledConnection);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void cleanupTimeoutThread()
/*      */     throws SQLException
/*      */   {
/* 2939 */     if (this.timeoutThread != null)
/*      */     {
/* 2941 */       this.timeoutThread.timeToLive = false;
/*      */       
/*      */ 
/*      */ 
/* 2945 */       if (this.timeoutThread.isSleeping) {
/* 2946 */         this.timeoutThread.interrupt();
/*      */       }
/* 2948 */       this.timeoutThread = null;
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void purgeCacheConnections(boolean paramBoolean)
/*      */   {
/*      */     try
/*      */     {
/* 2963 */       if (paramBoolean) {
/* 2964 */         doForEveryCheckedOutConnection(1);
/*      */       }
/*      */       
/*      */ 
/* 2968 */       doForEveryCachedConnection(1);
/*      */     }
/*      */     catch (SQLException localSQLException) {}
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void updateDatabaseInstance(String paramString1, String paramString2, int paramInt1, int paramInt2)
/*      */   {
/* 2987 */     if (this.databaseInstancesList == null) {
/* 2988 */       this.databaseInstancesList = new LinkedList();
/*      */     }
/* 2990 */     synchronized (this.databaseInstancesList)
/*      */     {
/* 2992 */       int i = this.databaseInstancesList.size();
/* 2993 */       int j = 0;
/*      */       
/* 2995 */       for (int k = 0; k < i; k++)
/*      */       {
/* 2997 */         OracleDatabaseInstance localOracleDatabaseInstance2 = (OracleDatabaseInstance)this.databaseInstancesList.get(k);
/* 2998 */         if ((localOracleDatabaseInstance2.databaseUniqName == paramString1) && (localOracleDatabaseInstance2.instanceName == paramString2))
/*      */         {
/*      */ 
/* 3001 */           localOracleDatabaseInstance2.percent = paramInt1;
/* 3002 */           localOracleDatabaseInstance2.flag = paramInt2;
/* 3003 */           j = 1;
/* 3004 */           break;
/*      */         }
/*      */       }
/*      */       
/* 3008 */       if (j == 0)
/*      */       {
/* 3010 */         OracleDatabaseInstance localOracleDatabaseInstance1 = new OracleDatabaseInstance(paramString1, paramString2);
/*      */         
/*      */ 
/* 3013 */         localOracleDatabaseInstance1.percent = paramInt1;
/* 3014 */         localOracleDatabaseInstance1.flag = paramInt2;
/*      */         
/* 3016 */         this.databaseInstancesList.add(localOracleDatabaseInstance1);
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void processDatabaseInstances()
/*      */     throws SQLException
/*      */   {
/* 3032 */     OracleDatabaseInstance localOracleDatabaseInstance = null;
/* 3033 */     LinkedList localLinkedList = new LinkedList();
/*      */     
/* 3035 */     if (this.databaseInstancesList != null)
/*      */     {
/* 3037 */       synchronized (this.databaseInstancesList)
/*      */       {
/* 3039 */         int i = 0;
/* 3040 */         int j = 0;
/*      */         
/*      */ 
/* 3043 */         this.useGoodGroup = false;
/*      */         
/*      */ 
/* 3046 */         int k = this.databaseInstancesList.size();
/*      */         
/* 3048 */         for (int m = 0; m < k; m++)
/*      */         {
/* 3050 */           localOracleDatabaseInstance = (OracleDatabaseInstance)this.databaseInstancesList.get(m);
/*      */           
/*      */ 
/*      */ 
/* 3054 */           if (localOracleDatabaseInstance.flag <= 3) {
/* 3055 */             i += localOracleDatabaseInstance.percent;
/*      */           }
/*      */         }
/*      */         
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3063 */         if (i > 0)
/*      */         {
/* 3065 */           this.dbInstancePercentTotal = i;
/* 3066 */           this.useGoodGroup = true;
/*      */         }
/*      */         
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3073 */         if (k > 1)
/*      */         {
/*      */ 
/* 3076 */           for (m = 0; m < k; m++)
/*      */           {
/* 3078 */             localOracleDatabaseInstance = (OracleDatabaseInstance)this.databaseInstancesList.get(m);
/* 3079 */             this.countTotal += localOracleDatabaseInstance.attemptedConnRequestCount;
/*      */           }
/*      */           
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3087 */           if (this.countTotal > k * 1000)
/*      */           {
/* 3089 */             for (m = 0; m < k; m++)
/*      */             {
/* 3091 */               localOracleDatabaseInstance = (OracleDatabaseInstance)this.databaseInstancesList.get(m);
/*      */               
/*      */ 
/* 3094 */               float f1 = localOracleDatabaseInstance.attemptedConnRequestCount / this.countTotal;
/*      */               
/* 3096 */               float f2 = localOracleDatabaseInstance.numberOfConnectionsCount / getTotalCachedConnections();
/*      */               
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3110 */               if (f2 > f1 * 2.0F)
/*      */               {
/*      */ 
/*      */ 
/*      */ 
/* 3115 */                 if ((int)(localOracleDatabaseInstance.numberOfConnectionsCount * 0.25D) >= 1) {
/* 3116 */                   localLinkedList.add(localOracleDatabaseInstance);
/*      */                 }
/* 3118 */                 j = 1;
/*      */               }
/*      */             }
/*      */             
/*      */ 
/* 3123 */             if (j != 0)
/*      */             {
/* 3125 */               for (m = 0; m < k; m++)
/*      */               {
/* 3127 */                 localOracleDatabaseInstance = (OracleDatabaseInstance)this.databaseInstancesList.get(m);
/* 3128 */                 localOracleDatabaseInstance.attemptedConnRequestCount = 0;
/*      */               }
/* 3130 */               j = 0;
/*      */             }
/*      */           }
/*      */         }
/*      */       }
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3142 */       if (localLinkedList.size() > 0)
/*      */       {
/* 3144 */         this.instancesToRetireList = localLinkedList;
/*      */         
/* 3146 */         if (this.gravitateCacheThread != null)
/*      */         {
/*      */           try
/*      */           {
/* 3150 */             this.gravitateCacheThread.interrupt();
/* 3151 */             this.gravitateCacheThread.join();
/*      */           }
/*      */           catch (InterruptedException localInterruptedException) {}
/*      */           
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3159 */           this.gravitateCacheThread = null;
/*      */         }
/*      */         
/*      */ 
/* 3163 */         this.gravitateCacheThread = new OracleGravitateConnectionCacheThread(this);
/*      */         
/*      */ 
/* 3166 */         this.cacheManager.checkAndStartThread(this.gravitateCacheThread);
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void gravitateCache()
/*      */   {
/* 3182 */     if (this.instancesToRetireList != null)
/*      */     {
/* 3184 */       synchronized (this.instancesToRetireList)
/*      */       {
/* 3186 */         int i = this.instancesToRetireList.size();
/*      */         
/* 3188 */         for (int j = 0; j < i; j++)
/*      */         {
/* 3190 */           this.instanceToRetire = ((OracleDatabaseInstance)this.instancesToRetireList.get(j));
/* 3191 */           this.retireConnectionsCount = ((int)(this.instanceToRetire.numberOfConnectionsCount * 0.25D));
/*      */           
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           try
/*      */           {
/* 3200 */             doForEveryCachedConnection(24);
/*      */           }
/*      */           catch (SQLException localSQLException1) {}
/*      */           
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3215 */           if (this.retireConnectionsCount > 0)
/*      */           {
/*      */ 
/*      */             try
/*      */             {
/*      */ 
/*      */ 
/* 3222 */               doForEveryCheckedOutConnection(24);
/*      */             }
/*      */             catch (SQLException localSQLException2) {}
/*      */           }
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3235 */     this.retireConnectionsCount = 0;
/* 3236 */     this.instanceToRetire = null;
/* 3237 */     this.instancesToRetireList = null;
/* 3238 */     this.countTotal = 0;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   protected void cleanupRLBThreads()
/*      */   {
/* 3255 */     if (this.gravitateCacheThread != null)
/*      */     {
/*      */       try
/*      */       {
/* 3259 */         this.gravitateCacheThread.interrupt();
/* 3260 */         this.gravitateCacheThread.join();
/*      */       }
/*      */       catch (InterruptedException localInterruptedException) {}
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3268 */       this.gravitateCacheThread = null;
/*      */     }
/*      */     
/* 3271 */     if (this.runtimeLoadBalancingThread != null)
/*      */     {
/*      */       try
/*      */       {
/* 3275 */         this.runtimeLoadBalancingThread.interrupt();
/*      */       }
/*      */       catch (Exception localException) {}
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3283 */       this.runtimeLoadBalancingThread = null;
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 3292 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Wed_Jun_22_11:18:55_PDT_2005";
/*      */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\ojdbc14.jar!\oracle\jdbc\pool\OracleImplicitConnectionCache.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       0.7.1
 */