/*      */ package oracle.jdbc.pool;
/*      */ 
/*      */ import java.io.IOException;
/*      */ import java.io.ObjectInputStream;
/*      */ import java.io.ObjectOutputStream;
/*      */ import java.io.Serializable;
/*      */ import java.sql.CallableStatement;
/*      */ import java.sql.Connection;
/*      */ import java.sql.PreparedStatement;
/*      */ import java.sql.SQLException;
/*      */ import java.util.Enumeration;
/*      */ import java.util.HashMap;
/*      */ import java.util.Hashtable;
/*      */ import java.util.Map;
/*      */ import java.util.Properties;
/*      */ import javax.sql.ConnectionEvent;
/*      */ import javax.sql.ConnectionEventListener;
/*      */ import javax.sql.PooledConnection;
/*      */ import javax.transaction.xa.XAResource;
/*      */ import oracle.jdbc.driver.DatabaseError;
/*      */ import oracle.jdbc.driver.OracleCloseCallback;
/*      */ import oracle.jdbc.driver.OracleDriver;
/*      */ import oracle.jdbc.internal.OracleConnection;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public class OraclePooledConnection
/*      */   implements PooledConnection, Serializable
/*      */ {
/*      */   public static final String url_string = "connection_url";
/*      */   public static final String pool_auto_commit_string = "pool_auto_commit";
/*      */   public static final String object_type_map = "obj_type_map";
/*      */   public static final String transaction_isolation = "trans_isolation";
/*      */   public static final String statement_cache_size = "stmt_cache_size";
/*      */   public static final String isClearMetaData = "stmt_cache_clear_metadata";
/*      */   public static final String ImplicitStatementCachingEnabled = "ImplicitStatementCachingEnabled";
/*      */   public static final String ExplicitStatementCachingEnabled = "ExplicitStatementCachingEnabled";
/*      */   public static final String LoginTimeout = "LoginTimeout";
/*      */   public static final String connect_auto_commit_string = "connect_auto_commit";
/*      */   public static final String implicit_caching_enabled = "implicit_cache_enabled";
/*      */   public static final String explicit_caching_enabled = "explict_cache_enabled";
/*      */   public static final String connection_properties_string = "connection_properties";
/*      */   public static final String event_listener_string = "event_listener";
/*      */   public static final String sql_exception_string = "sql_exception";
/*      */   public static final String close_callback_string = "close_callback";
/*      */   public static final String private_data = "private_data";
/*   73 */   private Hashtable eventListeners = null;
/*   74 */   private SQLException sqlException = null;
/*   75 */   protected boolean autoCommit = true;
/*      */   
/*      */ 
/*      */ 
/*   79 */   private ConnectionEventListener iccEventListener = null;
/*      */   
/*      */ 
/*   82 */   protected transient OracleConnection logicalHandle = null;
/*      */   
/*      */ 
/*   85 */   protected transient OracleConnection physicalConn = null;
/*      */   
/*   87 */   private Hashtable connectionProperty = null;
/*      */   
/*   89 */   public Properties cachedConnectionAttributes = null;
/*   90 */   public Properties unMatchedCachedConnAttr = null;
/*   91 */   public int closeOption = 0;
/*   92 */   protected String pcUser = null;
/*      */   
/*   94 */   private String pcKey = null;
/*      */   
/*      */ 
/*   97 */   private OracleCloseCallback closeCallback = null;
/*   98 */   private Object privateData = null;
/*      */   
/*      */ 
/*  101 */   private long lastAccessedTime = 0L;
/*      */   
/*      */ 
/*  104 */   protected String dataSourceInstanceNameKey = null;
/*  105 */   protected String dataSourceHostNameKey = null;
/*  106 */   protected String dataSourceDbUniqNameKey = null;
/*  107 */   protected boolean connectionMarkedDown = false;
/*  108 */   protected boolean isHostDown = false;
/*      */   
/*  110 */   protected transient OracleDriver oracleDriver = new OracleDriver();
/*      */   
/*      */ 
/*      */   public OraclePooledConnection()
/*      */   {
/*  115 */     this((Connection)null);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public OraclePooledConnection(String paramString)
/*      */     throws SQLException
/*      */   {
/*  132 */     Connection localConnection = this.oracleDriver.connect(paramString, new Properties());
/*      */     
/*  134 */     if (localConnection == null) {
/*  135 */       DatabaseError.throwSqlException(67);
/*      */     }
/*  137 */     initialize(localConnection);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public OraclePooledConnection(String paramString1, String paramString2, String paramString3)
/*      */     throws SQLException
/*      */   {
/*  154 */     Properties localProperties = new Properties();
/*      */     
/*  156 */     localProperties.put("user", paramString2);
/*  157 */     localProperties.put("password", paramString3);
/*      */     
/*  159 */     Connection localConnection = this.oracleDriver.connect(paramString1, localProperties);
/*      */     
/*  161 */     if (localConnection == null) {
/*  162 */       DatabaseError.throwSqlException(67);
/*      */     }
/*  164 */     initialize(localConnection);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public OraclePooledConnection(Connection paramConnection)
/*      */   {
/*  178 */     initialize(paramConnection);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public OraclePooledConnection(Connection paramConnection, boolean paramBoolean)
/*      */   {
/*  189 */     this(paramConnection);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*  194 */     this.autoCommit = paramBoolean;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void initialize(Connection paramConnection)
/*      */   {
/*  204 */     this.physicalConn = ((OracleConnection)paramConnection);
/*  205 */     this.eventListeners = new Hashtable(10);
/*      */     
/*  207 */     this.closeCallback = null;
/*  208 */     this.privateData = null;
/*  209 */     this.lastAccessedTime = 0L;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void addConnectionEventListener(ConnectionEventListener paramConnectionEventListener)
/*      */   {
/*  224 */     if (this.eventListeners == null) {
/*  225 */       this.sqlException = new SQLException("Listener Hashtable Null");
/*      */     } else {
/*  227 */       this.eventListeners.put(paramConnectionEventListener, paramConnectionEventListener);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void close()
/*      */     throws SQLException
/*      */   {
/*  241 */     if (this.closeCallback != null) {
/*  242 */       this.closeCallback.beforeClose(this.physicalConn, this.privateData);
/*      */     }
/*  244 */     if (this.physicalConn != null)
/*      */     {
/*  246 */       this.physicalConn.close();
/*      */       
/*  248 */       this.physicalConn = null;
/*      */     }
/*      */     
/*  251 */     if (this.closeCallback != null) {
/*  252 */       this.closeCallback.afterClose(this.privateData);
/*      */     }
/*      */     
/*  255 */     this.lastAccessedTime = 0L;
/*      */     
/*  257 */     this.iccEventListener = null;
/*      */     
/*      */ 
/*  260 */     callListener(2);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Connection getConnection()
/*      */     throws SQLException
/*      */   {
/*  279 */     if (this.physicalConn == null)
/*      */     {
/*  281 */       this.sqlException = new SQLException("Physical Connection doesn't exis");
/*      */       
/*      */ 
/*  284 */       callListener(2);
/*      */       
/*  286 */       DatabaseError.throwSqlException(8);
/*      */       
/*  288 */       return null;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */     try
/*      */     {
/*  295 */       if (this.logicalHandle != null)
/*      */       {
/*      */ 
/*      */ 
/*      */ 
/*  300 */         this.logicalHandle.closeInternal(false);
/*      */       }
/*      */       
/*      */ 
/*  304 */       this.logicalHandle = ((OracleConnection)this.physicalConn.getLogicalConnection(this, this.autoCommit));
/*      */ 
/*      */     }
/*      */     catch (SQLException localSQLException)
/*      */     {
/*      */ 
/*  310 */       this.sqlException = localSQLException;
/*      */       
/*      */ 
/*  313 */       callListener(2);
/*  314 */       callImplicitCacheListener(102);
/*      */       
/*      */ 
/*      */ 
/*      */ 
/*  319 */       DatabaseError.throwSqlException(8);
/*      */       
/*  321 */       return null;
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*  327 */     return this.logicalHandle;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public Connection getLogicalHandle()
/*      */     throws SQLException
/*      */   {
/*  339 */     return this.logicalHandle;
/*      */   }
/*      */   
/*      */   public Connection getPhysicalHandle() throws SQLException
/*      */   {
/*  344 */     return this.physicalConn;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void setLastAccessedTime(long paramLong)
/*      */     throws SQLException
/*      */   {
/*  362 */     this.lastAccessedTime = paramLong;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public long getLastAccessedTime()
/*      */     throws SQLException
/*      */   {
/*  378 */     return this.lastAccessedTime;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void registerCloseCallback(OracleCloseCallback paramOracleCloseCallback, Object paramObject)
/*      */   {
/*  395 */     this.closeCallback = paramOracleCloseCallback;
/*  396 */     this.privateData = paramObject;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void removeConnectionEventListener(ConnectionEventListener paramConnectionEventListener)
/*      */   {
/*  410 */     if (this.eventListeners == null) {
/*  411 */       this.sqlException = new SQLException("Listener Hashtable Null");
/*      */     } else {
/*  413 */       this.eventListeners.remove(paramConnectionEventListener);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void registerImplicitCacheConnectionEventListener(ConnectionEventListener paramConnectionEventListener)
/*      */   {
/*  427 */     if (this.iccEventListener != null) {
/*  428 */       this.sqlException = new SQLException("Implicit cache listener already registered");
/*      */     }
/*      */     else {
/*  431 */       this.iccEventListener = paramConnectionEventListener;
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void logicalCloseForImplicitConnectionCache()
/*      */   {
/*  453 */     if (this.closeOption == 4096)
/*      */     {
/*  455 */       callImplicitCacheListener(102);
/*      */     }
/*      */     else
/*      */     {
/*  459 */       callImplicitCacheListener(101);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void logicalClose()
/*      */   {
/*  473 */     if (this.cachedConnectionAttributes != null)
/*      */     {
/*  475 */       logicalCloseForImplicitConnectionCache();
/*      */ 
/*      */     }
/*      */     else
/*      */     {
/*      */ 
/*  481 */       synchronized (this)
/*      */       {
/*      */ 
/*      */ 
/*  485 */         callListener(1);
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void callListener(int paramInt)
/*      */   {
/*  500 */     if (this.eventListeners == null) {
/*  501 */       return;
/*      */     }
/*      */     
/*      */ 
/*  505 */     Enumeration localEnumeration = this.eventListeners.keys();
/*      */     
/*  507 */     ConnectionEvent localConnectionEvent = new ConnectionEvent(this, this.sqlException);
/*      */     
/*  509 */     while (localEnumeration.hasMoreElements())
/*      */     {
/*  511 */       ConnectionEventListener localConnectionEventListener1 = (ConnectionEventListener)localEnumeration.nextElement();
/*      */       
/*  513 */       ConnectionEventListener localConnectionEventListener2 = (ConnectionEventListener)this.eventListeners.get(localConnectionEventListener1);
/*      */       
/*      */ 
/*      */ 
/*  517 */       if (paramInt == 1) {
/*  518 */         localConnectionEventListener2.connectionClosed(localConnectionEvent);
/*  519 */       } else if (paramInt == 2) {
/*  520 */         localConnectionEventListener2.connectionErrorOccurred(localConnectionEvent);
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void callImplicitCacheListener(int paramInt)
/*      */   {
/*  533 */     if (this.iccEventListener == null) {
/*  534 */       return;
/*      */     }
/*  536 */     ConnectionEvent localConnectionEvent = new ConnectionEvent(this, this.sqlException);
/*      */     
/*      */ 
/*  539 */     switch (paramInt)
/*      */     {
/*      */ 
/*      */ 
/*      */     case 101: 
/*  544 */       this.iccEventListener.connectionClosed(localConnectionEvent);
/*      */       
/*  546 */       break;
/*      */     
/*      */ 
/*      */ 
/*      */     case 102: 
/*  551 */       this.iccEventListener.connectionErrorOccurred(localConnectionEvent);
/*      */     }
/*      */     
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   /**
/*      */    * @deprecated
/*      */    */
/*      */   public synchronized void setStmtCacheSize(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  581 */     setStmtCacheSize(paramInt, false);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   /**
/*      */    * @deprecated
/*      */    */
/*      */   public synchronized void setStmtCacheSize(int paramInt, boolean paramBoolean)
/*      */     throws SQLException
/*      */   {
/*  608 */     if (paramInt < 0) {
/*  609 */       DatabaseError.throwSqlException(68);
/*      */     }
/*      */     
/*      */ 
/*  613 */     if (this.physicalConn != null) {
/*  614 */       this.physicalConn.setStmtCacheSize(paramInt, paramBoolean);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   /**
/*      */    * @deprecated
/*      */    */
/*      */   public synchronized int getStmtCacheSize()
/*      */   {
/*  629 */     if (this.physicalConn != null) {
/*  630 */       return this.physicalConn.getStmtCacheSize();
/*      */     }
/*  632 */     return 0;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void setStatementCacheSize(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  652 */     if (this.physicalConn != null) {
/*  653 */       this.physicalConn.setStatementCacheSize(paramInt);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public int getStatementCacheSize()
/*      */     throws SQLException
/*      */   {
/*  669 */     if (this.physicalConn != null) {
/*  670 */       return this.physicalConn.getStatementCacheSize();
/*      */     }
/*  672 */     return 0;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void setImplicitCachingEnabled(boolean paramBoolean)
/*      */     throws SQLException
/*      */   {
/*  692 */     if (this.physicalConn != null) {
/*  693 */       this.physicalConn.setImplicitCachingEnabled(paramBoolean);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public boolean getImplicitCachingEnabled()
/*      */     throws SQLException
/*      */   {
/*  708 */     if (this.physicalConn != null) {
/*  709 */       return this.physicalConn.getImplicitCachingEnabled();
/*      */     }
/*  711 */     return false;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void setExplicitCachingEnabled(boolean paramBoolean)
/*      */     throws SQLException
/*      */   {
/*  731 */     if (this.physicalConn != null) {
/*  732 */       this.physicalConn.setExplicitCachingEnabled(paramBoolean);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public boolean getExplicitCachingEnabled()
/*      */     throws SQLException
/*      */   {
/*  747 */     if (this.physicalConn != null) {
/*  748 */       return this.physicalConn.getExplicitCachingEnabled();
/*      */     }
/*  750 */     return false;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void purgeImplicitCache()
/*      */     throws SQLException
/*      */   {
/*  766 */     if (this.physicalConn != null) {
/*  767 */       this.physicalConn.purgeImplicitCache();
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void purgeExplicitCache()
/*      */     throws SQLException
/*      */   {
/*  783 */     if (this.physicalConn != null) {
/*  784 */       this.physicalConn.purgeExplicitCache();
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public PreparedStatement getStatementWithKey(String paramString)
/*      */     throws SQLException
/*      */   {
/*  804 */     if (this.physicalConn != null) {
/*  805 */       return this.physicalConn.getStatementWithKey(paramString);
/*      */     }
/*  807 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public CallableStatement getCallWithKey(String paramString)
/*      */     throws SQLException
/*      */   {
/*  827 */     if (this.physicalConn != null) {
/*  828 */       return this.physicalConn.getCallWithKey(paramString);
/*      */     }
/*  830 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public boolean isStatementCacheInitialized()
/*      */   {
/*  840 */     if (this.physicalConn != null) {
/*  841 */       return this.physicalConn.isStatementCacheInitialized();
/*      */     }
/*  843 */     return false;
/*      */   }
/*      */   
/*      */   public final void setProperties(Hashtable paramHashtable)
/*      */   {
/*  848 */     this.connectionProperty = paramHashtable;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public final void setUserName(String paramString1, String paramString2)
/*      */   {
/*  856 */     this.pcUser = paramString1;
/*  857 */     this.pcKey = (this.pcUser + paramString2);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   final OracleConnectionCacheEntry addToImplicitCache(HashMap paramHashMap, OracleConnectionCacheEntry paramOracleConnectionCacheEntry)
/*      */   {
/*  866 */     return (OracleConnectionCacheEntry)paramHashMap.put(this.pcKey, paramOracleConnectionCacheEntry);
/*      */   }
/*      */   
/*      */   final OracleConnectionCacheEntry removeFromImplictCache(HashMap paramHashMap)
/*      */   {
/*  871 */     return (OracleConnectionCacheEntry)paramHashMap.get(this.pcKey);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public XAResource getXAResource()
/*      */     throws SQLException
/*      */   {
/*  886 */     DatabaseError.throwSqlException(23);
/*      */     
/*  888 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void writeObject(ObjectOutputStream paramObjectOutputStream)
/*      */     throws IOException
/*      */   {
/*  898 */     paramObjectOutputStream.defaultWriteObject();
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     try
/*      */     {
/*  907 */       this.physicalConn.getPropertyForPooledConnection(this);
/*      */       
/*  909 */       if (this.eventListeners != null) {
/*  910 */         this.connectionProperty.put("event_listener", this.eventListeners);
/*      */       }
/*  912 */       if (this.sqlException != null) {
/*  913 */         this.connectionProperty.put("sql_exception", this.sqlException);
/*      */       }
/*  915 */       this.connectionProperty.put("pool_auto_commit", "" + this.autoCommit);
/*      */       
/*  917 */       if (this.closeCallback != null) {
/*  918 */         this.connectionProperty.put("close_callback", this.closeCallback);
/*      */       }
/*  920 */       if (this.privateData != null) {
/*  921 */         this.connectionProperty.put("private_data", this.privateData);
/*      */       }
/*  923 */       paramObjectOutputStream.writeObject(this.connectionProperty);
/*  924 */       this.physicalConn.close();
/*      */     }
/*      */     catch (SQLException localSQLException)
/*      */     {
/*  928 */       localSQLException.printStackTrace();
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void readObject(ObjectInputStream paramObjectInputStream)
/*      */     throws IOException, ClassNotFoundException, SQLException
/*      */   {
/*  940 */     paramObjectInputStream.defaultReadObject();
/*      */     
/*  942 */     this.connectionProperty = ((Hashtable)paramObjectInputStream.readObject());
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */     try
/*      */     {
/*  949 */       Properties localProperties = (Properties)this.connectionProperty.get("connection_properties");
/*      */       
/*  951 */       String str1 = localProperties.getProperty("connection_url");
/*      */       
/*  953 */       this.oracleDriver = new OracleDriver();
/*      */       
/*  955 */       Connection localConnection = this.oracleDriver.connect(str1, localProperties);
/*      */       
/*      */ 
/*      */ 
/*  959 */       initialize(localConnection);
/*      */       
/*  961 */       this.eventListeners = ((Hashtable)this.connectionProperty.get("event_listener"));
/*      */       
/*  963 */       this.sqlException = ((SQLException)this.connectionProperty.get("sql_exception"));
/*      */       
/*  965 */       this.autoCommit = ((String)this.connectionProperty.get("pool_auto_commit")).equals("true");
/*      */       
/*  967 */       this.closeCallback = ((OracleCloseCallback)this.connectionProperty.get("close_callback"));
/*      */       
/*  969 */       this.privateData = this.connectionProperty.get("private_data");
/*      */       
/*  971 */       Map localMap = (Map)this.connectionProperty.get("obj_type_map");
/*      */       
/*      */ 
/*  974 */       if (localMap != null) {
/*  975 */         ((OracleConnection)localConnection).setTypeMap(localMap);
/*      */       }
/*  977 */       String str2 = localProperties.getProperty("trans_isolation");
/*      */       
/*  979 */       localConnection.setTransactionIsolation(Integer.parseInt(str2));
/*      */       
/*  981 */       str2 = localProperties.getProperty("stmt_cache_size");
/*      */       
/*  983 */       int i = Integer.parseInt(str2);
/*      */       
/*  985 */       if (i != -1)
/*      */       {
/*  987 */         setStatementCacheSize(i);
/*      */         
/*  989 */         str2 = localProperties.getProperty("implicit_cache_enabled");
/*  990 */         if ((str2 != null) && (str2.equalsIgnoreCase("true"))) {
/*  991 */           setImplicitCachingEnabled(true);
/*      */         } else {
/*  993 */           setImplicitCachingEnabled(false);
/*      */         }
/*  995 */         str2 = localProperties.getProperty("explict_cache_enabled");
/*  996 */         if ((str2 != null) && (str2.equalsIgnoreCase("true"))) {
/*  997 */           setExplicitCachingEnabled(true);
/*      */         } else
/*  999 */           setExplicitCachingEnabled(false);
/*      */       }
/* 1001 */       this.physicalConn.setAutoCommit(((String)localProperties.get("connect_auto_commit")).equals("true"));
/*      */     }
/*      */     catch (Exception localException)
/*      */     {
/* 1005 */       localException.printStackTrace();
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1014 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Wed_Jun_22_11:18:55_PDT_2005";
/*      */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\ojdbc14.jar!\oracle\jdbc\pool\OraclePooledConnection.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       0.7.1
 */