/*     */ package oracle.jdbc.driver;
/*     */ 
/*     */ import java.sql.SQLException;
/*     */ import java.sql.Time;
/*     */ import java.sql.Timestamp;
/*     */ import java.util.Calendar;
/*     */ import java.util.TimeZone;
/*     */ import oracle.sql.DATE;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ abstract class DateTimeCommonAccessor
/*     */   extends Accessor
/*     */ {
/*     */   static final int GREGORIAN_CUTOVER_YEAR = 1582;
/*     */   static final long GREGORIAN_CUTOVER = -12219292800000L;
/*     */   static final int JAN_1_1_JULIAN_DAY = 1721426;
/*     */   static final int EPOCH_JULIAN_DAY = 2440588;
/*     */   static final int ONE_SECOND = 1000;
/*     */   static final int ONE_MINUTE = 60000;
/*     */   static final int ONE_HOUR = 3600000;
/*     */   static final long ONE_DAY = 86400000L;
/*  41 */   static final int[] NUM_DAYS = { 0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334 };
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*  46 */   static final int[] LEAP_NUM_DAYS = { 0, 31, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335 };
/*     */   
/*     */   static final int ORACLE_CENTURY = 0;
/*     */   
/*     */   static final int ORACLE_YEAR = 1;
/*     */   
/*     */   static final int ORACLE_MONTH = 2;
/*     */   
/*     */   static final int ORACLE_DAY = 3;
/*     */   
/*     */   static final int ORACLE_HOUR = 4;
/*     */   
/*     */   static final int ORACLE_MIN = 5;
/*     */   
/*     */   static final int ORACLE_SEC = 6;
/*     */   static final int ORACLE_NANO1 = 7;
/*     */   static final int ORACLE_NANO2 = 8;
/*     */   static final int ORACLE_NANO3 = 9;
/*     */   static final int ORACLE_NANO4 = 10;
/*     */   static final int ORACLE_TZ1 = 11;
/*     */   static final int ORACLE_TZ2 = 12;
/*     */   static final int SIZE_DATE = 7;
/*     */   static final int MAX_TIMESTAMP_LENGTH = 11;
/*     */   static TimeZone epochTimeZone;
/*     */   static long epochTimeZoneOffset;
/*     */   
/*     */   java.sql.Date getDate(int paramInt)
/*     */     throws SQLException
/*     */   {
/*  75 */     java.sql.Date localDate = null;
/*     */     
/*  77 */     if (this.rowSpaceIndicator == null)
/*     */     {
/*     */ 
/*     */ 
/*     */ 
/*  82 */       DatabaseError.throwSqlException(21);
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*  89 */     if (this.rowSpaceIndicator[(this.indicatorIndex + paramInt)] != -1)
/*     */     {
/*  91 */       int i = this.columnIndex + this.byteLength * paramInt;
/*     */       
/*     */ 
/*     */ 
/*  95 */       TimeZone localTimeZone = this.statement.getDefaultTimeZone();
/*     */       
/*     */ 
/*  98 */       int j = ((this.rowSpaceByte[(0 + i)] & 0xFF) - 100) * 100 + (this.rowSpaceByte[(1 + i)] & 0xFF) - 100;
/*     */       
/*     */ 
/*     */ 
/* 102 */       if (j <= 0) {
/* 103 */         j++;
/*     */       }
/* 105 */       localDate = new java.sql.Date(getMillis(j, oracleMonth(i), oracleDay(i), 0, localTimeZone));
/*     */     }
/*     */     
/*     */ 
/* 109 */     return localDate;
/*     */   }
/*     */   
/*     */ 
/*     */   Time getTime(int paramInt)
/*     */     throws SQLException
/*     */   {
/* 116 */     Time localTime = null;
/*     */     
/* 118 */     if (this.rowSpaceIndicator == null)
/*     */     {
/*     */ 
/*     */ 
/*     */ 
/* 123 */       DatabaseError.throwSqlException(21);
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 130 */     if (this.rowSpaceIndicator[(this.indicatorIndex + paramInt)] != -1)
/*     */     {
/* 132 */       int i = this.columnIndex + this.byteLength * paramInt;
/*     */       
/*     */ 
/*     */ 
/* 136 */       TimeZone localTimeZone = this.statement.getDefaultTimeZone();
/*     */       
/* 138 */       if (localTimeZone != epochTimeZone)
/*     */       {
/* 140 */         epochTimeZoneOffset = calculateEpochOffset(localTimeZone);
/* 141 */         epochTimeZone = localTimeZone;
/*     */       }
/*     */       
/* 144 */       localTime = new Time(oracleTime(i) - epochTimeZoneOffset);
/*     */     }
/*     */     
/* 147 */     return localTime;
/*     */   }
/*     */   
/*     */ 
/*     */   java.sql.Date getDate(int paramInt, Calendar paramCalendar)
/*     */     throws SQLException
/*     */   {
/* 154 */     if (paramCalendar == null) {
/* 155 */       return getDate(paramInt);
/*     */     }
/* 157 */     java.sql.Date localDate = null;
/*     */     
/* 159 */     if (this.rowSpaceIndicator == null)
/*     */     {
/*     */ 
/*     */ 
/*     */ 
/* 164 */       DatabaseError.throwSqlException(21);
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 171 */     if (this.rowSpaceIndicator[(this.indicatorIndex + paramInt)] != -1)
/*     */     {
/* 173 */       int i = this.columnIndex + this.byteLength * paramInt;
/* 174 */       int j = ((this.rowSpaceByte[(0 + i)] & 0xFF) - 100) * 100 + (this.rowSpaceByte[(1 + i)] & 0xFF) - 100;
/*     */       
/*     */ 
/*     */ 
/*     */ 
/* 179 */       paramCalendar.set(1, j);
/* 180 */       paramCalendar.set(2, oracleMonth(i));
/* 181 */       paramCalendar.set(5, oracleDay(i));
/* 182 */       paramCalendar.set(11, oracleHour(i));
/* 183 */       paramCalendar.set(12, oracleMin(i));
/* 184 */       paramCalendar.set(13, oracleSec(i));
/* 185 */       paramCalendar.set(14, 0);
/*     */       
/* 187 */       localDate = new java.sql.Date(paramCalendar.getTime().getTime());
/*     */     }
/*     */     
/* 190 */     return localDate;
/*     */   }
/*     */   
/*     */ 
/*     */   Time getTime(int paramInt, Calendar paramCalendar)
/*     */     throws SQLException
/*     */   {
/* 197 */     if (paramCalendar == null) {
/* 198 */       return getTime(paramInt);
/*     */     }
/* 200 */     Time localTime = null;
/*     */     
/* 202 */     if (this.rowSpaceIndicator == null)
/*     */     {
/*     */ 
/*     */ 
/*     */ 
/* 207 */       DatabaseError.throwSqlException(21);
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 214 */     if (this.rowSpaceIndicator[(this.indicatorIndex + paramInt)] != -1)
/*     */     {
/* 216 */       int i = this.columnIndex + this.byteLength * paramInt;
/* 217 */       int j = ((this.rowSpaceByte[(0 + i)] & 0xFF) - 100) * 100 + (this.rowSpaceByte[(1 + i)] & 0xFF) - 100;
/*     */       
/*     */ 
/*     */ 
/*     */ 
/* 222 */       paramCalendar.set(1, 1970);
/* 223 */       paramCalendar.set(2, 0);
/* 224 */       paramCalendar.set(5, 1);
/* 225 */       paramCalendar.set(11, oracleHour(i));
/* 226 */       paramCalendar.set(12, oracleMin(i));
/* 227 */       paramCalendar.set(13, oracleSec(i));
/* 228 */       paramCalendar.set(14, 0);
/*     */       
/* 230 */       localTime = new Time(paramCalendar.getTime().getTime());
/*     */     }
/*     */     
/* 233 */     return localTime;
/*     */   }
/*     */   
/*     */ 
/*     */   Timestamp getTimestamp(int paramInt, Calendar paramCalendar)
/*     */     throws SQLException
/*     */   {
/* 240 */     if (paramCalendar == null) {
/* 241 */       return getTimestamp(paramInt);
/*     */     }
/* 243 */     Timestamp localTimestamp = null;
/*     */     
/* 245 */     if (this.rowSpaceIndicator == null)
/*     */     {
/*     */ 
/*     */ 
/*     */ 
/* 250 */       DatabaseError.throwSqlException(21);
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 257 */     if (this.rowSpaceIndicator[(this.indicatorIndex + paramInt)] != -1)
/*     */     {
/* 259 */       int i = this.columnIndex + this.byteLength * paramInt;
/* 260 */       int j = ((this.rowSpaceByte[(0 + i)] & 0xFF) - 100) * 100 + (this.rowSpaceByte[(1 + i)] & 0xFF) - 100;
/*     */       
/*     */ 
/*     */ 
/*     */ 
/* 265 */       paramCalendar.set(1, j);
/* 266 */       paramCalendar.set(2, oracleMonth(i));
/* 267 */       paramCalendar.set(5, oracleDay(i));
/* 268 */       paramCalendar.set(11, oracleHour(i));
/* 269 */       paramCalendar.set(12, oracleMin(i));
/* 270 */       paramCalendar.set(13, oracleSec(i));
/* 271 */       paramCalendar.set(14, 0);
/*     */       
/* 273 */       localTimestamp = new Timestamp(paramCalendar.getTime().getTime());
/*     */       
/* 275 */       int k = this.rowSpaceIndicator[(this.lengthIndex + paramInt)];
/* 276 */       if (k >= 11)
/*     */       {
/* 278 */         localTimestamp.setNanos(oracleNanos(i));
/*     */       }
/*     */     }
/*     */     
/*     */ 
/* 283 */     return localTimestamp;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   DATE getDATE(int paramInt)
/*     */     throws SQLException
/*     */   {
/* 291 */     DATE localDATE = null;
/*     */     
/* 293 */     if (this.rowSpaceIndicator == null)
/*     */     {
/*     */ 
/*     */ 
/*     */ 
/* 298 */       DatabaseError.throwSqlException(21);
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 305 */     if (this.rowSpaceIndicator[(this.indicatorIndex + paramInt)] != -1)
/*     */     {
/* 307 */       int i = this.columnIndex + this.byteLength * paramInt;
/* 308 */       byte[] arrayOfByte = new byte[7];
/*     */       
/* 310 */       System.arraycopy(this.rowSpaceByte, i, arrayOfByte, 0, 7);
/*     */       
/* 312 */       localDATE = new DATE(arrayOfByte);
/*     */     }
/*     */     
/* 315 */     return localDATE;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   final int oracleYear(int paramInt)
/*     */   {
/* 322 */     int i = ((this.rowSpaceByte[(0 + paramInt)] & 0xFF) - 100) * 100 + (this.rowSpaceByte[(1 + paramInt)] & 0xFF) - 100;
/*     */     
/*     */ 
/*     */ 
/* 326 */     return i <= 0 ? i + 1 : i;
/*     */   }
/*     */   
/*     */ 
/*     */   final int oracleMonth(int paramInt)
/*     */   {
/* 332 */     return this.rowSpaceByte[(2 + paramInt)] - 1;
/*     */   }
/*     */   
/*     */ 
/*     */   final int oracleDay(int paramInt)
/*     */   {
/* 338 */     return this.rowSpaceByte[(3 + paramInt)];
/*     */   }
/*     */   
/*     */ 
/*     */   final int oracleHour(int paramInt)
/*     */   {
/* 344 */     return this.rowSpaceByte[(4 + paramInt)] - 1;
/*     */   }
/*     */   
/*     */ 
/*     */   final int oracleMin(int paramInt)
/*     */   {
/* 350 */     return this.rowSpaceByte[(5 + paramInt)] - 1;
/*     */   }
/*     */   
/*     */ 
/*     */   final int oracleSec(int paramInt)
/*     */   {
/* 356 */     return this.rowSpaceByte[(6 + paramInt)] - 1;
/*     */   }
/*     */   
/*     */ 
/*     */   final int oracleTZ1(int paramInt)
/*     */   {
/* 362 */     return this.rowSpaceByte[(11 + paramInt)];
/*     */   }
/*     */   
/*     */ 
/*     */   final int oracleTZ2(int paramInt)
/*     */   {
/* 368 */     return this.rowSpaceByte[(12 + paramInt)];
/*     */   }
/*     */   
/*     */   final int oracleTime(int paramInt)
/*     */   {
/* 373 */     int i = oracleHour(paramInt);
/*     */     
/* 375 */     i *= 60;
/* 376 */     i += oracleMin(paramInt);
/* 377 */     i *= 60;
/* 378 */     i += oracleSec(paramInt);
/* 379 */     i *= 1000;
/*     */     
/* 381 */     return i;
/*     */   }
/*     */   
/*     */   final int oracleNanos(int paramInt)
/*     */   {
/* 386 */     int i = (this.rowSpaceByte[(7 + paramInt)] & 0xFF) << 24;
/*     */     
/* 388 */     i |= (this.rowSpaceByte[(8 + paramInt)] & 0xFF) << 16;
/* 389 */     i |= (this.rowSpaceByte[(9 + paramInt)] & 0xFF) << 8;
/* 390 */     i |= this.rowSpaceByte[(10 + paramInt)] & 0xFF & 0xFF;
/*     */     
/* 392 */     return i;
/*     */   }
/*     */   
/*     */ 
/*     */   static final long computeJulianDay(boolean paramBoolean, int paramInt1, int paramInt2, int paramInt3)
/*     */   {
/* 398 */     int i = paramInt1 % 4 == 0 ? 1 : 0;
/* 399 */     int j = paramInt1 - 1;
/* 400 */     long l = 365L * j + floorDivide(j, 4L) + 1721423L;
/*     */     
/* 402 */     if (paramBoolean)
/*     */     {
/* 404 */       i = (i != 0) && ((paramInt1 % 100 != 0) || (paramInt1 % 400 == 0)) ? 1 : 0;
/*     */       
/*     */ 
/* 407 */       l += floorDivide(j, 400L) - floorDivide(j, 100L) + 2L;
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 414 */     return l + paramInt3 + (i != 0 ? LEAP_NUM_DAYS[paramInt2] : NUM_DAYS[paramInt2]);
/*     */   }
/*     */   
/*     */   static final long floorDivide(long paramLong1, long paramLong2)
/*     */   {
/* 419 */     return paramLong1 >= 0L ? paramLong1 / paramLong2 : (paramLong1 + 1L) / paramLong2 - 1L;
/*     */   }
/*     */   
/*     */ 
/*     */   static final long julianDayToMillis(long paramLong)
/*     */   {
/* 425 */     return (paramLong - 2440588L) * 86400000L;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   static final long zoneOffset(TimeZone paramTimeZone, int paramInt1, int paramInt2, int paramInt3, int paramInt4, int paramInt5)
/*     */   {
/* 433 */     return paramTimeZone.getOffset(paramInt1 < 0 ? 0 : 1, paramInt1, paramInt2, paramInt3, paramInt4, paramInt5);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   static long getMillis(int paramInt1, int paramInt2, int paramInt3, int paramInt4, TimeZone paramTimeZone)
/*     */   {
/* 452 */     boolean bool = paramInt1 >= 1582;
/* 453 */     long l1 = computeJulianDay(bool, paramInt1, paramInt2, paramInt3);
/* 454 */     long l2 = (l1 - 2440588L) * 86400000L;
/*     */     
/*     */ 
/*     */ 
/* 458 */     if (bool != l2 >= -12219292800000L)
/*     */     {
/* 460 */       l1 = computeJulianDay(!bool, paramInt1, paramInt2, paramInt3);
/* 461 */       l2 = (l1 - 2440588L) * 86400000L;
/*     */     }
/*     */     
/*     */ 
/*     */ 
/* 466 */     l2 += paramInt4;
/*     */     
/*     */ 
/*     */ 
/*     */ 
/* 471 */     return l2 - zoneOffset(paramTimeZone, paramInt1, paramInt2, paramInt3, julianDayToDayOfWeek(l1), paramInt4);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   static final int julianDayToDayOfWeek(long paramLong)
/*     */   {
/* 487 */     int i = (int)((paramLong + 1L) % 7L);
/*     */     
/* 489 */     return i + (i < 0 ? 8 : 1);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   static long calculateEpochOffset(TimeZone paramTimeZone)
/*     */   {
/* 506 */     return zoneOffset(paramTimeZone, 1970, 0, 1, 5, 0);
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\ojdbc14.jar!\oracle\jdbc\driver\DateTimeCommonAccessor.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       0.7.1
 */