/*      */ package oracle.jdbc.driver;
/*      */ 
/*      */ import java.io.ByteArrayInputStream;
/*      */ import java.io.IOException;
/*      */ import java.io.InputStream;
/*      */ import java.io.Reader;
/*      */ import java.math.BigDecimal;
/*      */ import java.net.MalformedURLException;
/*      */ import java.net.URL;
/*      */ import java.sql.Array;
/*      */ import java.sql.Blob;
/*      */ import java.sql.Clob;
/*      */ import java.sql.Date;
/*      */ import java.sql.Ref;
/*      */ import java.sql.ResultSet;
/*      */ import java.sql.ResultSetMetaData;
/*      */ import java.sql.SQLException;
/*      */ import java.sql.Statement;
/*      */ import java.sql.Time;
/*      */ import java.sql.Timestamp;
/*      */ import java.util.Calendar;
/*      */ import java.util.Map;
/*      */ import java.util.Vector;
/*      */ import oracle.sql.ARRAY;
/*      */ import oracle.sql.BFILE;
/*      */ import oracle.sql.BLOB;
/*      */ import oracle.sql.CHAR;
/*      */ import oracle.sql.CLOB;
/*      */ import oracle.sql.CustomDatum;
/*      */ import oracle.sql.CustomDatumFactory;
/*      */ import oracle.sql.DATE;
/*      */ import oracle.sql.Datum;
/*      */ import oracle.sql.INTERVALDS;
/*      */ import oracle.sql.INTERVALYM;
/*      */ import oracle.sql.NUMBER;
/*      */ import oracle.sql.OPAQUE;
/*      */ import oracle.sql.ORAData;
/*      */ import oracle.sql.ORADataFactory;
/*      */ import oracle.sql.RAW;
/*      */ import oracle.sql.REF;
/*      */ import oracle.sql.ROWID;
/*      */ import oracle.sql.STRUCT;
/*      */ import oracle.sql.TIMESTAMP;
/*      */ import oracle.sql.TIMESTAMPLTZ;
/*      */ import oracle.sql.TIMESTAMPTZ;
/*      */ 
/*      */ 
/*      */ class ScrollableResultSet
/*      */   extends BaseResultSet
/*      */ {
/*      */   PhysicalConnection connection;
/*      */   OracleResultSetImpl resultSet;
/*      */   ScrollRsetStatement scrollStmt;
/*      */   ResultSetMetaData metadata;
/*      */   private int rsetType;
/*      */   private int rsetConcurency;
/*      */   private int beginColumnIndex;
/*      */   private int columnCount;
/*      */   private int wasNull;
/*      */   OracleResultSetCache rsetCache;
/*      */   int currentRow;
/*      */   private int numRowsCached;
/*      */   private boolean allRowsCached;
/*      */   private int lastRefetchSz;
/*      */   private Vector refetchRowids;
/*      */   private OraclePreparedStatement refetchStmt;
/*      */   private int usrFetchDirection;
/*      */   
/*      */   ScrollableResultSet(ScrollRsetStatement paramScrollRsetStatement, OracleResultSetImpl paramOracleResultSetImpl, int paramInt1, int paramInt2)
/*      */     throws SQLException
/*      */   {
/*   72 */     this.connection = ((OracleStatement)paramScrollRsetStatement).connection;
/*   73 */     this.resultSet = paramOracleResultSetImpl;
/*   74 */     this.metadata = null;
/*   75 */     this.scrollStmt = paramScrollRsetStatement;
/*   76 */     this.rsetType = paramInt1;
/*   77 */     this.rsetConcurency = paramInt2;
/*   78 */     this.autoRefetch = paramScrollRsetStatement.getAutoRefetch();
/*   79 */     this.beginColumnIndex = (needIdentifier(paramInt1, paramInt2) ? 1 : 0);
/*   80 */     this.columnCount = 0;
/*   81 */     this.wasNull = -1;
/*   82 */     this.rsetCache = paramScrollRsetStatement.getResultSetCache();
/*      */     
/*   84 */     if (this.rsetCache == null)
/*      */     {
/*   86 */       this.rsetCache = new OracleResultSetCacheImpl();
/*      */     }
/*      */     else
/*      */     {
/*      */       try
/*      */       {
/*   92 */         this.rsetCache.clear();
/*      */       }
/*      */       catch (IOException localIOException)
/*      */       {
/*   96 */         DatabaseError.throwSqlException(localIOException);
/*      */       }
/*      */     }
/*      */     
/*  100 */     this.currentRow = 0;
/*  101 */     this.numRowsCached = 0;
/*  102 */     this.allRowsCached = false;
/*  103 */     this.lastRefetchSz = 0;
/*  104 */     this.refetchRowids = null;
/*  105 */     this.refetchStmt = null;
/*  106 */     this.usrFetchDirection = 1000;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void close()
/*      */     throws SQLException
/*      */   {
/*  122 */     if (this.resultSet != null) {
/*  123 */       this.resultSet.close();
/*      */     }
/*  125 */     if (this.refetchStmt != null) {
/*  126 */       this.refetchStmt.close();
/*      */     }
/*  128 */     if (this.scrollStmt != null) {
/*  129 */       this.scrollStmt.notifyCloseRset();
/*      */     }
/*  131 */     if (this.refetchRowids != null) {
/*  132 */       this.refetchRowids.removeAllElements();
/*      */     }
/*  134 */     this.resultSet = null;
/*  135 */     this.scrollStmt = null;
/*  136 */     this.refetchStmt = null;
/*  137 */     this.refetchRowids = null;
/*  138 */     this.metadata = null;
/*  139 */     this.connection = null;
/*      */     
/*      */     try
/*      */     {
/*  143 */       if (this.rsetCache != null)
/*      */       {
/*  145 */         this.rsetCache.clear();
/*  146 */         this.rsetCache.close();
/*      */       }
/*      */     }
/*      */     catch (IOException localIOException)
/*      */     {
/*  151 */       DatabaseError.throwSqlException(localIOException);
/*      */     }
/*      */     
/*  154 */     this.rsetCache = null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized boolean wasNull()
/*      */     throws SQLException
/*      */   {
/*  163 */     if (this.wasNull == -1) {
/*  164 */       DatabaseError.throwSqlException(24);
/*      */     }
/*  166 */     return this.wasNull == 1;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Statement getStatement()
/*      */     throws SQLException
/*      */   {
/*  176 */     return (Statement)this.scrollStmt;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   synchronized void resetBeginColumnIndex()
/*      */   {
/*  188 */     this.beginColumnIndex = 0;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   synchronized ResultSet getResultSet()
/*      */   {
/*  200 */     return this.resultSet;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   synchronized int removeRowInCache(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  209 */     if ((!isEmptyResultSet()) && (isValidRow(paramInt)))
/*      */     {
/*  211 */       removeCachedRowAt(paramInt);
/*      */       
/*  213 */       this.numRowsCached -= 1;
/*      */       
/*  215 */       if (paramInt >= this.currentRow) {
/*  216 */         this.currentRow -= 1;
/*      */       }
/*  218 */       return 1;
/*      */     }
/*      */     
/*  221 */     return 0;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   synchronized int refreshRowsInCache(int paramInt1, int paramInt2, int paramInt3)
/*      */     throws SQLException
/*      */   {
/*  234 */     OracleResultSet localOracleResultSet = null;
/*  235 */     int i = 0;
/*      */     
/*      */ 
/*  238 */     i = get_refetch_size(paramInt1, paramInt2, paramInt3);
/*      */     
/*      */     try
/*      */     {
/*  242 */       if (i > 0)
/*      */       {
/*      */ 
/*      */ 
/*  246 */         if (i != this.lastRefetchSz)
/*      */         {
/*  248 */           if (this.refetchStmt != null) {
/*  249 */             this.refetchStmt.close();
/*      */           }
/*  251 */           this.refetchStmt = prepare_refetch_statement(i);
/*  252 */           this.refetchStmt.setQueryTimeout(((OracleStatement)this.scrollStmt).getQueryTimeout());
/*  253 */           this.lastRefetchSz = i;
/*      */         }
/*      */         
/*      */ 
/*  257 */         prepare_refetch_binds(this.refetchStmt, i);
/*      */         
/*      */ 
/*  260 */         localOracleResultSet = (OracleResultSet)this.refetchStmt.executeQuery();
/*      */         
/*      */ 
/*  263 */         save_refetch_results(localOracleResultSet, paramInt1, i, paramInt3);
/*      */       }
/*      */       
/*      */     }
/*      */     finally
/*      */     {
/*  269 */       if (localOracleResultSet != null) {
/*  270 */         localOracleResultSet.close();
/*      */       }
/*      */     }
/*  273 */     return i;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized boolean next()
/*      */     throws SQLException
/*      */   {
/*  286 */     if (isEmptyResultSet())
/*      */     {
/*  288 */       return false;
/*      */     }
/*      */     
/*      */ 
/*  292 */     if (this.currentRow < 1)
/*      */     {
/*  294 */       this.currentRow = 1;
/*      */     }
/*      */     else
/*      */     {
/*  298 */       this.currentRow += 1;
/*      */     }
/*      */     
/*  301 */     return isValidRow(this.currentRow);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized boolean isBeforeFirst()
/*      */     throws SQLException
/*      */   {
/*  311 */     return (!isEmptyResultSet()) && (this.currentRow < 1);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized boolean isAfterLast()
/*      */     throws SQLException
/*      */   {
/*  320 */     return (!isEmptyResultSet()) && (this.currentRow > 0) && (!isValidRow(this.currentRow));
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized boolean isFirst()
/*      */     throws SQLException
/*      */   {
/*  329 */     return this.currentRow == 1;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized boolean isLast()
/*      */     throws SQLException
/*      */   {
/*  338 */     return (!isEmptyResultSet()) && (isValidRow(this.currentRow)) && (!isValidRow(this.currentRow + 1));
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void beforeFirst()
/*      */     throws SQLException
/*      */   {
/*  348 */     if (!isEmptyResultSet()) {
/*  349 */       this.currentRow = 0;
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public synchronized void afterLast()
/*      */     throws SQLException
/*      */   {
/*  358 */     if (!isEmptyResultSet()) {
/*  359 */       this.currentRow = (getLastRow() + 1);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public synchronized boolean first()
/*      */     throws SQLException
/*      */   {
/*  368 */     if (isEmptyResultSet())
/*      */     {
/*  370 */       return false;
/*      */     }
/*      */     
/*      */ 
/*  374 */     this.currentRow = 1;
/*      */     
/*  376 */     return isValidRow(this.currentRow);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized boolean last()
/*      */     throws SQLException
/*      */   {
/*  386 */     if (isEmptyResultSet())
/*      */     {
/*  388 */       return false;
/*      */     }
/*      */     
/*      */ 
/*  392 */     this.currentRow = getLastRow();
/*      */     
/*  394 */     return isValidRow(this.currentRow);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized int getRow()
/*      */     throws SQLException
/*      */   {
/*  404 */     if (isValidRow(this.currentRow)) {
/*  405 */       return this.currentRow;
/*      */     }
/*  407 */     return 0;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized boolean absolute(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  416 */     if (paramInt == 0) {
/*  417 */       DatabaseError.throwSqlException(68, "absolute (0)");
/*      */     }
/*      */     
/*  420 */     if (isEmptyResultSet())
/*      */     {
/*  422 */       return false;
/*      */     }
/*  424 */     if (paramInt > 0)
/*      */     {
/*  426 */       this.currentRow = paramInt;
/*      */     }
/*  428 */     else if (paramInt < 0)
/*      */     {
/*  430 */       this.currentRow = (getLastRow() + 1 + paramInt);
/*      */     }
/*      */     
/*  433 */     return isValidRow(this.currentRow);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized boolean relative(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  442 */     if (isEmptyResultSet())
/*      */     {
/*  444 */       return false;
/*      */     }
/*  446 */     if (isValidRow(this.currentRow))
/*      */     {
/*  448 */       this.currentRow += paramInt;
/*      */       
/*  450 */       return isValidRow(this.currentRow);
/*      */     }
/*      */     
/*      */ 
/*  454 */     DatabaseError.throwSqlException(82, "relative");
/*      */     
/*      */ 
/*  457 */     return false;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized boolean previous()
/*      */     throws SQLException
/*      */   {
/*  467 */     if (isEmptyResultSet())
/*      */     {
/*  469 */       return false;
/*      */     }
/*  471 */     if (isAfterLast())
/*      */     {
/*  473 */       this.currentRow = getLastRow();
/*      */     }
/*      */     else
/*      */     {
/*  477 */       this.currentRow -= 1;
/*      */     }
/*      */     
/*  480 */     return isValidRow(this.currentRow);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Datum getOracleObject(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  493 */     this.wasNull = -1;
/*      */     
/*  495 */     if (!isValidRow(this.currentRow)) {
/*  496 */       DatabaseError.throwSqlException(11);
/*      */     }
/*  498 */     if ((paramInt < 1) || (paramInt > getColumnCount())) {
/*  499 */       DatabaseError.throwSqlException(3);
/*      */     }
/*  501 */     Datum localDatum = getCachedDatumValueAt(this.currentRow, paramInt + this.beginColumnIndex);
/*      */     
/*      */ 
/*  504 */     this.wasNull = (localDatum == null ? 1 : 0);
/*      */     
/*  506 */     return localDatum;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized String getString(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  515 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  517 */     if (localDatum != null) {
/*  518 */       return localDatum.stringValue();
/*      */     }
/*  520 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized boolean getBoolean(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  529 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  531 */     if (localDatum != null)
/*      */     {
/*  533 */       return localDatum.booleanValue();
/*      */     }
/*      */     
/*  536 */     return false;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized byte getByte(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  545 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  547 */     if (localDatum != null) {
/*  548 */       return localDatum.byteValue();
/*      */     }
/*  550 */     return 0;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized short getShort(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  559 */     long l = getLong(paramInt);
/*      */     
/*  561 */     if ((l > 65537L) || (l < -65538L)) {
/*  562 */       DatabaseError.throwSqlException(26, "getShort");
/*      */     }
/*      */     
/*  565 */     return (short)(int)l;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized int getInt(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  574 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  576 */     if (localDatum != null)
/*      */     {
/*  578 */       return localDatum.intValue();
/*      */     }
/*      */     
/*  581 */     return 0;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized long getLong(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  590 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  592 */     if (localDatum != null)
/*      */     {
/*  594 */       return localDatum.longValue();
/*      */     }
/*      */     
/*  597 */     return 0L;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized float getFloat(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  606 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  608 */     if (localDatum != null)
/*      */     {
/*  610 */       return localDatum.floatValue();
/*      */     }
/*      */     
/*  613 */     return 0.0F;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized double getDouble(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  622 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  624 */     if (localDatum != null)
/*      */     {
/*  626 */       return localDatum.doubleValue();
/*      */     }
/*      */     
/*  629 */     return 0.0D;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized BigDecimal getBigDecimal(int paramInt1, int paramInt2)
/*      */     throws SQLException
/*      */   {
/*  639 */     Datum localDatum = getOracleObject(paramInt1);
/*      */     
/*  641 */     if (localDatum != null)
/*      */     {
/*  643 */       return localDatum.bigDecimalValue();
/*      */     }
/*      */     
/*  646 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized byte[] getBytes(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  655 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  657 */     if (localDatum != null)
/*      */     {
/*  659 */       if ((localDatum instanceof RAW)) {
/*  660 */         return ((RAW)localDatum).shareBytes();
/*      */       }
/*  662 */       DatabaseError.throwSqlException(4, "getBytes");
/*      */     }
/*      */     
/*      */ 
/*  666 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Date getDate(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  675 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  677 */     if (localDatum != null)
/*      */     {
/*  679 */       return localDatum.dateValue();
/*      */     }
/*      */     
/*  682 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Time getTime(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  691 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  693 */     if (localDatum != null)
/*      */     {
/*  695 */       return localDatum.timeValue();
/*      */     }
/*      */     
/*  698 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Timestamp getTimestamp(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  708 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  710 */     if (localDatum != null)
/*      */     {
/*  712 */       return localDatum.timestampValue();
/*      */     }
/*      */     
/*  715 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized InputStream getAsciiStream(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  725 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  727 */     if (localDatum != null)
/*      */     {
/*  729 */       return localDatum.asciiStreamValue();
/*      */     }
/*      */     
/*  732 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized InputStream getUnicodeStream(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  742 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  744 */     if (localDatum != null)
/*      */     {
/*  746 */       DBConversion localDBConversion = this.connection.conversion;
/*  747 */       byte[] arrayOfByte = localDatum.shareBytes();
/*      */       
/*  749 */       if ((localDatum instanceof RAW))
/*      */       {
/*  751 */         return localDBConversion.ConvertStream(new ByteArrayInputStream(arrayOfByte), 3);
/*      */       }
/*      */       
/*  754 */       if ((localDatum instanceof CHAR))
/*      */       {
/*  756 */         return localDBConversion.ConvertStream(new ByteArrayInputStream(arrayOfByte), 1);
/*      */       }
/*      */       
/*      */ 
/*  760 */       DatabaseError.throwSqlException(4, "getUnicodeStream");
/*      */     }
/*      */     
/*      */ 
/*  764 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized InputStream getBinaryStream(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  774 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  776 */     if (localDatum != null)
/*      */     {
/*  778 */       return localDatum.binaryStreamValue();
/*      */     }
/*      */     
/*  781 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Object getObject(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  791 */     return getObject(paramInt, this.connection.getTypeMap());
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Reader getCharacterStream(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  802 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  804 */     if (localDatum != null)
/*      */     {
/*  806 */       return localDatum.characterStreamValue();
/*      */     }
/*      */     
/*  809 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public BigDecimal getBigDecimal(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  819 */     return getBigDecimal(paramInt, 0);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Object getObject(int paramInt, Map paramMap)
/*      */     throws SQLException
/*      */   {
/*  830 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  832 */     if (localDatum != null)
/*      */     {
/*  834 */       if ((localDatum instanceof STRUCT)) {
/*  835 */         return ((STRUCT)localDatum).toJdbc(paramMap);
/*      */       }
/*  837 */       return localDatum.toJdbc();
/*      */     }
/*      */     
/*  840 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Ref getRef(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  850 */     return getREF(paramInt);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Blob getBlob(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  860 */     return getBLOB(paramInt);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Clob getClob(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  870 */     return getCLOB(paramInt);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Array getArray(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  881 */     return getARRAY(paramInt);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Date getDate(int paramInt, Calendar paramCalendar)
/*      */     throws SQLException
/*      */   {
/*  892 */     DATE localDATE = getDATE(paramInt);
/*      */     
/*  894 */     return localDATE != null ? localDATE.dateValue(paramCalendar) : null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Time getTime(int paramInt, Calendar paramCalendar)
/*      */     throws SQLException
/*      */   {
/*  905 */     DATE localDATE = getDATE(paramInt);
/*      */     
/*  907 */     return localDATE != null ? localDATE.timeValue(paramCalendar) : null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Timestamp getTimestamp(int paramInt, Calendar paramCalendar)
/*      */     throws SQLException
/*      */   {
/*  918 */     DATE localDATE = getDATE(paramInt);
/*      */     
/*  920 */     return localDATE != null ? localDATE.timestampValue(paramCalendar) : null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized URL getURL(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  930 */     URL localURL = null;
/*      */     
/*  932 */     int i = getInternalMetadata().getColumnType(paramInt);
/*  933 */     int j = SQLUtil.getInternalType(i);
/*      */     
/*      */ 
/*  936 */     if ((j == 96) || (j == 1) || (j == 8))
/*      */     {
/*      */       try
/*      */       {
/*      */ 
/*  941 */         localURL = new URL(getString(paramInt));
/*      */       }
/*      */       catch (MalformedURLException localMalformedURLException)
/*      */       {
/*  945 */         DatabaseError.throwSqlException(136);
/*      */       }
/*      */       
/*      */     }
/*      */     else {
/*  950 */       throw new SQLException("Conversion to java.net.URL not supported.");
/*      */     }
/*      */     
/*  953 */     return localURL;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized ResultSet getCursor(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  963 */     DatabaseError.throwSqlException(4, "getCursor");
/*      */     
/*      */ 
/*  966 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized ROWID getROWID(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  976 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  978 */     if (localDatum != null)
/*      */     {
/*  980 */       if ((localDatum instanceof ROWID)) {
/*  981 */         return (ROWID)localDatum;
/*      */       }
/*  983 */       DatabaseError.throwSqlException(4, "getROWID");
/*      */     }
/*      */     
/*      */ 
/*  987 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized NUMBER getNUMBER(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  997 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*  999 */     if (localDatum != null)
/*      */     {
/* 1001 */       if ((localDatum instanceof NUMBER)) {
/* 1002 */         return (NUMBER)localDatum;
/*      */       }
/* 1004 */       DatabaseError.throwSqlException(4, "getNUMBER");
/*      */     }
/*      */     
/*      */ 
/* 1008 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized DATE getDATE(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1018 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1020 */     if (localDatum != null)
/*      */     {
/* 1022 */       if ((localDatum instanceof DATE)) {
/* 1023 */         return (DATE)localDatum;
/*      */       }
/* 1025 */       DatabaseError.throwSqlException(4, "getDATE");
/*      */     }
/*      */     
/*      */ 
/* 1029 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized TIMESTAMP getTIMESTAMP(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1039 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1041 */     if (localDatum != null)
/*      */     {
/* 1043 */       if ((localDatum instanceof TIMESTAMP)) {
/* 1044 */         return (TIMESTAMP)localDatum;
/*      */       }
/* 1046 */       DatabaseError.throwSqlException(4, "getTIMESTAMP");
/*      */     }
/*      */     
/*      */ 
/* 1050 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized TIMESTAMPTZ getTIMESTAMPTZ(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1060 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1062 */     if (localDatum != null)
/*      */     {
/* 1064 */       if ((localDatum instanceof TIMESTAMPTZ)) {
/* 1065 */         return (TIMESTAMPTZ)localDatum;
/*      */       }
/* 1067 */       DatabaseError.throwSqlException(4, "getTIMESTAMPTZ");
/*      */     }
/*      */     
/*      */ 
/* 1071 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized TIMESTAMPLTZ getTIMESTAMPLTZ(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1081 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1083 */     if (localDatum != null)
/*      */     {
/* 1085 */       if ((localDatum instanceof TIMESTAMPLTZ)) {
/* 1086 */         return (TIMESTAMPLTZ)localDatum;
/*      */       }
/* 1088 */       DatabaseError.throwSqlException(4, "getTIMESTAMPLTZ");
/*      */     }
/*      */     
/*      */ 
/* 1092 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized INTERVALDS getINTERVALDS(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1102 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1104 */     if (localDatum != null)
/*      */     {
/* 1106 */       if ((localDatum instanceof INTERVALDS)) {
/* 1107 */         return (INTERVALDS)localDatum;
/*      */       }
/* 1109 */       DatabaseError.throwSqlException(4, "getINTERVALDS");
/*      */     }
/*      */     
/*      */ 
/* 1113 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized INTERVALYM getINTERVALYM(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1123 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1125 */     if (localDatum != null)
/*      */     {
/* 1127 */       if ((localDatum instanceof INTERVALYM)) {
/* 1128 */         return (INTERVALYM)localDatum;
/*      */       }
/* 1130 */       DatabaseError.throwSqlException(4, "getINTERVALYM");
/*      */     }
/*      */     
/*      */ 
/* 1134 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized ARRAY getARRAY(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1144 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1146 */     if (localDatum != null)
/*      */     {
/* 1148 */       if ((localDatum instanceof ARRAY)) {
/* 1149 */         return (ARRAY)localDatum;
/*      */       }
/* 1151 */       DatabaseError.throwSqlException(4, "getARRAY");
/*      */     }
/*      */     
/*      */ 
/* 1155 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized STRUCT getSTRUCT(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1165 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1167 */     if (localDatum != null)
/*      */     {
/* 1169 */       if ((localDatum instanceof STRUCT)) {
/* 1170 */         return (STRUCT)localDatum;
/*      */       }
/* 1172 */       DatabaseError.throwSqlException(4, "getSTRUCT");
/*      */     }
/*      */     
/*      */ 
/* 1176 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized OPAQUE getOPAQUE(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1186 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1188 */     if (localDatum != null)
/*      */     {
/* 1190 */       if ((localDatum instanceof OPAQUE)) {
/* 1191 */         return (OPAQUE)localDatum;
/*      */       }
/* 1193 */       DatabaseError.throwSqlException(4, "getOPAQUE");
/*      */     }
/*      */     
/*      */ 
/* 1197 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized REF getREF(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1207 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1209 */     if (localDatum != null)
/*      */     {
/* 1211 */       if ((localDatum instanceof REF)) {
/* 1212 */         return (REF)localDatum;
/*      */       }
/* 1214 */       DatabaseError.throwSqlException(4, "getREF");
/*      */     }
/*      */     
/*      */ 
/* 1218 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized CHAR getCHAR(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1228 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1230 */     if (localDatum != null)
/*      */     {
/* 1232 */       if ((localDatum instanceof CHAR)) {
/* 1233 */         return (CHAR)localDatum;
/*      */       }
/* 1235 */       DatabaseError.throwSqlException(4, "getCHAR");
/*      */     }
/*      */     
/*      */ 
/* 1239 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized RAW getRAW(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1249 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1251 */     if (localDatum != null)
/*      */     {
/* 1253 */       if ((localDatum instanceof RAW)) {
/* 1254 */         return (RAW)localDatum;
/*      */       }
/* 1256 */       DatabaseError.throwSqlException(4, "getRAW");
/*      */     }
/*      */     
/*      */ 
/* 1260 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized BLOB getBLOB(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1270 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1272 */     if (localDatum != null)
/*      */     {
/* 1274 */       if ((localDatum instanceof BLOB)) {
/* 1275 */         return (BLOB)localDatum;
/*      */       }
/* 1277 */       DatabaseError.throwSqlException(4, "getBLOB");
/*      */     }
/*      */     
/*      */ 
/* 1281 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized CLOB getCLOB(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1291 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1293 */     if (localDatum != null)
/*      */     {
/* 1295 */       if ((localDatum instanceof CLOB)) {
/* 1296 */         return (CLOB)localDatum;
/*      */       }
/* 1298 */       DatabaseError.throwSqlException(4, "getCLOB");
/*      */     }
/*      */     
/*      */ 
/* 1302 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized BFILE getBFILE(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1312 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/* 1314 */     if (localDatum != null)
/*      */     {
/* 1316 */       if ((localDatum instanceof BFILE)) {
/* 1317 */         return (BFILE)localDatum;
/*      */       }
/* 1319 */       DatabaseError.throwSqlException(4, "getBFILE");
/*      */     }
/*      */     
/*      */ 
/* 1323 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized BFILE getBfile(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1334 */     return getBFILE(paramInt);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized CustomDatum getCustomDatum(int paramInt, CustomDatumFactory paramCustomDatumFactory)
/*      */     throws SQLException
/*      */   {
/* 1345 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1350 */     return paramCustomDatumFactory.create(localDatum, 0);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized ORAData getORAData(int paramInt, ORADataFactory paramORADataFactory)
/*      */     throws SQLException
/*      */   {
/* 1361 */     Datum localDatum = getOracleObject(paramInt);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1366 */     return paramORADataFactory.create(localDatum, 0);
/*      */   }
/*      */   
/*      */   /* Error */
/*      */   public ResultSetMetaData getMetaData()
/*      */     throws SQLException
/*      */   {
/*      */     // Byte code:
/*      */     //   0: aload_0
/*      */     //   1: getfield 4	oracle/jdbc/driver/ScrollableResultSet:connection	Loracle/jdbc/driver/PhysicalConnection;
/*      */     //   4: dup
/*      */     //   5: astore_1
/*      */     //   6: monitorenter
/*      */     //   7: aload_0
/*      */     //   8: dup
/*      */     //   9: astore_2
/*      */     //   10: monitorenter
/*      */     //   11: new 146	oracle/jdbc/driver/OracleResultSetMetaData
/*      */     //   14: dup
/*      */     //   15: aload_0
/*      */     //   16: getfield 4	oracle/jdbc/driver/ScrollableResultSet:connection	Loracle/jdbc/driver/PhysicalConnection;
/*      */     //   19: aload_0
/*      */     //   20: getfield 7	oracle/jdbc/driver/ScrollableResultSet:scrollStmt	Loracle/jdbc/driver/ScrollRsetStatement;
/*      */     //   23: checkcast 2	oracle/jdbc/driver/OracleStatement
/*      */     //   26: aload_0
/*      */     //   27: getfield 13	oracle/jdbc/driver/ScrollableResultSet:beginColumnIndex	I
/*      */     //   30: invokespecial 147	oracle/jdbc/driver/OracleResultSetMetaData:<init>	(Loracle/jdbc/driver/PhysicalConnection;Loracle/jdbc/driver/OracleStatement;I)V
/*      */     //   33: aload_2
/*      */     //   34: monitorexit
/*      */     //   35: aload_1
/*      */     //   36: monitorexit
/*      */     //   37: areturn
/*      */     //   38: astore_3
/*      */     //   39: aload_2
/*      */     //   40: monitorexit
/*      */     //   41: aload_3
/*      */     //   42: athrow
/*      */     //   43: astore 4
/*      */     //   45: aload_1
/*      */     //   46: monitorexit
/*      */     //   47: aload 4
/*      */     //   49: athrow
/*      */     // Line number table:
/*      */     //   Java source line #1379	-> byte code offset #0
/*      */     //   Java source line #1381	-> byte code offset #7
/*      */     //   Java source line #1383	-> byte code offset #11
/*      */     //   Java source line #1386	-> byte code offset #38
/*      */     //   Java source line #1387	-> byte code offset #43
/*      */     // Local variable table:
/*      */     //   start	length	slot	name	signature
/*      */     //   0	50	0	this	ScrollableResultSet
/*      */     //   5	41	1	Ljava/lang/Object;	Object
/*      */     //   9	31	2	Ljava/lang/Object;	Object
/*      */     //   38	4	3	localObject1	Object
/*      */     //   43	5	4	localObject2	Object
/*      */     // Exception table:
/*      */     //   from	to	target	type
/*      */     //   11	35	38	finally
/*      */     //   38	41	38	finally
/*      */     //   7	37	43	finally
/*      */     //   38	47	43	finally
/*      */   }
/*      */   
/*      */   public synchronized int findColumn(String paramString)
/*      */     throws SQLException
/*      */   {
/* 1396 */     return this.resultSet.findColumn(paramString) - this.beginColumnIndex;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void setFetchDirection(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1409 */     if (paramInt == 1000)
/*      */     {
/* 1411 */       this.usrFetchDirection = paramInt;
/*      */     }
/* 1413 */     else if ((paramInt == 1001) || (paramInt == 1002))
/*      */     {
/*      */ 
/* 1416 */       this.usrFetchDirection = paramInt;
/*      */       
/* 1418 */       this.sqlWarning = DatabaseError.addSqlWarning(this.sqlWarning, 87);
/*      */ 
/*      */     }
/*      */     else
/*      */     {
/*      */ 
/* 1424 */       DatabaseError.throwSqlException(68, "setFetchDirection");
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized int getFetchDirection()
/*      */     throws SQLException
/*      */   {
/* 1436 */     return 1000;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void setFetchSize(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1445 */     this.resultSet.setFetchSize(paramInt);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized int getFetchSize()
/*      */     throws SQLException
/*      */   {
/* 1454 */     return this.resultSet.getFetchSize();
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public int getType()
/*      */     throws SQLException
/*      */   {
/* 1463 */     return this.rsetType;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public int getConcurrency()
/*      */     throws SQLException
/*      */   {
/* 1472 */     return this.rsetConcurency;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void refreshRow()
/*      */     throws SQLException
/*      */   {
/* 1488 */     if (!needIdentifier(this.rsetType, this.rsetConcurency)) {
/* 1489 */       DatabaseError.throwSqlException(23, "refreshRow");
/*      */     }
/*      */     
/* 1492 */     if (isValidRow(this.currentRow))
/*      */     {
/* 1494 */       int i = getFetchDirection();
/*      */       
/*      */       try
/*      */       {
/* 1498 */         refreshRowsInCache(this.currentRow, getFetchSize(), i);
/*      */       }
/*      */       catch (SQLException localSQLException)
/*      */       {
/* 1502 */         DatabaseError.throwSqlException(localSQLException, 90, "Unsupported syntax for refreshRow()");
/*      */       }
/*      */     }
/*      */     else
/*      */     {
/* 1507 */       DatabaseError.throwSqlException(82, "refreshRow");
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public void setCurrentRowValueAt(Object paramObject1, int paramInt, Object paramObject2)
/*      */     throws SQLException
/*      */   {
/* 1522 */     if ((paramObject1 instanceof UpdatableResultSet)) {
/* 1523 */       putCachedValueAt(this.currentRow, paramInt, paramObject2);
/*      */     } else {
/* 1525 */       DatabaseError.throwSqlException(1);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private boolean isEmptyResultSet()
/*      */     throws SQLException
/*      */   {
/* 1537 */     if (this.numRowsCached != 0)
/*      */     {
/* 1539 */       return false;
/*      */     }
/* 1541 */     if ((this.numRowsCached == 0) && (this.allRowsCached))
/*      */     {
/* 1543 */       return true;
/*      */     }
/*      */     
/*      */ 
/* 1547 */     return !isValidRow(1);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   boolean isValidRow(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1561 */     if ((paramInt > 0) && (paramInt <= this.numRowsCached))
/*      */     {
/* 1563 */       return true;
/*      */     }
/* 1565 */     if (paramInt <= 0)
/*      */     {
/* 1567 */       return false;
/*      */     }
/*      */     
/*      */ 
/* 1571 */     return cacheRowAt(paramInt);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private boolean cacheRowAt(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1588 */     while ((this.numRowsCached < paramInt) && (this.resultSet.next()))
/*      */     {
/* 1590 */       for (int i = 0; i < getColumnCount(); i++)
/*      */       {
/*      */ 
/* 1593 */         byte[] arrayOfByte = this.resultSet.privateGetBytes(i + 1);
/*      */         
/* 1595 */         putCachedValueAt(this.numRowsCached + 1, i + 1, arrayOfByte);
/*      */       }
/*      */       
/* 1598 */       this.numRowsCached += 1;
/*      */     }
/*      */     
/* 1601 */     if (this.numRowsCached < paramInt)
/*      */     {
/* 1603 */       this.allRowsCached = true;
/*      */       
/* 1605 */       return false;
/*      */     }
/*      */     
/*      */ 
/* 1609 */     return true;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private int cacheAllRows()
/*      */     throws SQLException
/*      */   {
/* 1622 */     while (this.resultSet.next())
/*      */     {
/* 1624 */       for (int i = 0; i < getColumnCount(); i++) {
/* 1625 */         putCachedValueAt(this.numRowsCached + 1, i + 1, this.resultSet.privateGetBytes(i + 1));
/*      */       }
/* 1627 */       this.numRowsCached += 1;
/*      */     }
/*      */     
/* 1630 */     this.allRowsCached = true;
/*      */     
/* 1632 */     return this.numRowsCached;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   int getColumnCount()
/*      */     throws SQLException
/*      */   {
/* 1644 */     if (this.columnCount == 0)
/*      */     {
/*      */ 
/*      */ 
/* 1648 */       int i = this.resultSet.statement.numberOfDefinePositions;
/*      */       
/* 1650 */       if ((this.resultSet.statement.accessors != null) && (i > 0)) {
/* 1651 */         this.columnCount = i;
/*      */       } else {
/* 1653 */         this.columnCount = getInternalMetadata().getColumnCount();
/*      */       }
/*      */     }
/* 1656 */     return this.columnCount;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private ResultSetMetaData getInternalMetadata()
/*      */     throws SQLException
/*      */   {
/* 1668 */     if (this.metadata == null) {
/* 1669 */       this.metadata = this.resultSet.getMetaData();
/*      */     }
/* 1671 */     return this.metadata;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private int getLastRow()
/*      */     throws SQLException
/*      */   {
/* 1683 */     if (!this.allRowsCached) {
/* 1684 */       cacheAllRows();
/*      */     }
/* 1686 */     return this.numRowsCached;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private int get_refetch_size(int paramInt1, int paramInt2, int paramInt3)
/*      */     throws SQLException
/*      */   {
/* 1700 */     int i = paramInt3 == 1001 ? -1 : 1;
/*      */     
/*      */ 
/* 1703 */     int j = 0;
/*      */     
/* 1705 */     if (this.refetchRowids == null) {
/* 1706 */       this.refetchRowids = new Vector(10);
/*      */     } else {
/* 1708 */       this.refetchRowids.removeAllElements();
/*      */     }
/*      */     
/* 1711 */     while ((j < paramInt2) && (isValidRow(paramInt1 + j * i)))
/*      */     {
/* 1713 */       this.refetchRowids.addElement(getCachedDatumValueAt(paramInt1 + j * i, 1));
/*      */       
/*      */ 
/* 1716 */       j++;
/*      */     }
/*      */     
/* 1719 */     return j;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private OraclePreparedStatement prepare_refetch_statement(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1737 */     if (paramInt < 1) {
/* 1738 */       DatabaseError.throwSqlException(68);
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 1743 */     return (OraclePreparedStatement)this.connection.prepareStatement(((OracleStatement)this.scrollStmt).sqlObject.getRefetchSqlForScrollableResultSet(this, paramInt));
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void prepare_refetch_binds(OraclePreparedStatement paramOraclePreparedStatement, int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1760 */     int i = this.scrollStmt.copyBinds(paramOraclePreparedStatement, 0);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1781 */     for (int j = 0; j < paramInt; j++)
/*      */     {
/* 1783 */       paramOraclePreparedStatement.setROWID(i + j + 1, (ROWID)this.refetchRowids.elementAt(j));
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void save_refetch_results(OracleResultSet paramOracleResultSet, int paramInt1, int paramInt2, int paramInt3)
/*      */     throws SQLException
/*      */   {
/* 1799 */     int i = paramInt3 == 1001 ? -1 : 1;
/*      */     
/* 1801 */     while (paramOracleResultSet.next())
/*      */     {
/* 1803 */       ROWID localROWID = paramOracleResultSet.getROWID(1);
/*      */       
/* 1805 */       int j = 0;
/* 1806 */       int k = paramInt1;
/*      */       
/* 1808 */       while ((j == 0) && (k < paramInt1 + paramInt2 * i))
/*      */       {
/* 1810 */         if (((ROWID)getCachedDatumValueAt(k, 1)).stringValue().equals(localROWID.stringValue()))
/*      */         {
/* 1812 */           j = 1;
/*      */         } else {
/* 1814 */           k += i;
/*      */         }
/*      */       }
/* 1817 */       if (j != 0)
/*      */       {
/* 1819 */         for (int m = 0; m < getColumnCount(); m++)
/*      */         {
/* 1821 */           putCachedValueAt(k, m + 1, paramOracleResultSet.getOracleObject(m + 1));
/*      */         }
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private Object getCachedValueAt(int paramInt1, int paramInt2)
/*      */     throws SQLException
/*      */   {
/*      */     try
/*      */     {
/* 1836 */       return this.rsetCache.get(paramInt1, paramInt2);
/*      */     }
/*      */     catch (IOException localIOException)
/*      */     {
/* 1840 */       DatabaseError.throwSqlException(localIOException);
/*      */     }
/*      */     
/* 1843 */     return null;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   private Datum getCachedDatumValueAt(int paramInt1, int paramInt2)
/*      */     throws SQLException
/*      */   {
/* 1852 */     Object localObject = null;
/*      */     
/*      */     try
/*      */     {
/* 1856 */       localObject = this.rsetCache.get(paramInt1, paramInt2);
/*      */     }
/*      */     catch (IOException localIOException1)
/*      */     {
/* 1860 */       DatabaseError.throwSqlException(localIOException1);
/*      */     }
/*      */     
/* 1863 */     Datum localDatum = null;
/*      */     
/* 1865 */     if (localObject != null)
/*      */     {
/* 1867 */       if ((localObject instanceof Datum))
/*      */       {
/* 1869 */         localDatum = (Datum)localObject;
/*      */       }
/* 1871 */       else if (((byte[])localObject).length > 0)
/*      */       {
/* 1873 */         int i = getInternalMetadata().getColumnType(paramInt2);
/* 1874 */         int j = getInternalMetadata().getColumnDisplaySize(paramInt2);
/*      */         
/*      */ 
/*      */ 
/* 1878 */         int k = this.scrollStmt.getMaxFieldSize();
/*      */         
/* 1880 */         if ((k > 0) && (k < j)) {
/* 1881 */           j = k;
/*      */         }
/* 1883 */         String str = null;
/*      */         
/* 1885 */         if ((i == 2006) || (i == 2002) || (i == 2008) || (i == 2007) || (i == 2003))
/*      */         {
/*      */ 
/* 1888 */           str = getInternalMetadata().getColumnTypeName(paramInt2);
/*      */         }
/* 1890 */         int m = SQLUtil.getInternalType(i);
/*      */         
/*      */ 
/* 1893 */         short s = this.resultSet.statement.accessors[(paramInt2 - 1)].formOfUse;
/*      */         
/* 1895 */         if ((s == 2) && ((m == 96) || (m == 1) || (m == 8) || (m == 112)))
/*      */         {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 1904 */           localDatum = SQLUtil.makeNDatum(this.connection, (byte[])localObject, m, str, s, j);
/*      */ 
/*      */         }
/*      */         else
/*      */         {
/*      */ 
/* 1910 */           localDatum = SQLUtil.makeDatum(this.connection, (byte[])localObject, m, str, j);
/*      */         }
/*      */         
/*      */ 
/*      */         try
/*      */         {
/* 1916 */           this.rsetCache.put(paramInt1, paramInt2, localDatum);
/*      */         }
/*      */         catch (IOException localIOException3)
/*      */         {
/* 1920 */           DatabaseError.throwSqlException(localIOException3);
/*      */         }
/*      */       }
/*      */       else
/*      */       {
/*      */         try
/*      */         {
/* 1927 */           this.rsetCache.put(paramInt1, paramInt2, null);
/*      */         }
/*      */         catch (IOException localIOException2)
/*      */         {
/* 1931 */           DatabaseError.throwSqlException(localIOException2);
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 1939 */     return localDatum;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void putCachedValueAt(int paramInt1, int paramInt2, Object paramObject)
/*      */     throws SQLException
/*      */   {
/*      */     try
/*      */     {
/* 1951 */       this.rsetCache.put(paramInt1, paramInt2, paramObject);
/*      */     }
/*      */     catch (IOException localIOException)
/*      */     {
/* 1955 */       DatabaseError.throwSqlException(localIOException);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   private void removeCachedRowAt(int paramInt)
/*      */     throws SQLException
/*      */   {
/*      */     try
/*      */     {
/* 1967 */       this.rsetCache.remove(paramInt);
/*      */     }
/*      */     catch (IOException localIOException)
/*      */     {
/* 1971 */       DatabaseError.throwSqlException(localIOException);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public static boolean needIdentifier(int paramInt1, int paramInt2)
/*      */   {
/* 1984 */     if (((paramInt1 == 1003) && (paramInt2 == 1007)) || ((paramInt1 == 1004) && (paramInt2 == 1007)))
/*      */     {
/*      */ 
/* 1987 */       return false;
/*      */     }
/* 1989 */     return true;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public static boolean needCache(int paramInt1, int paramInt2)
/*      */   {
/* 1999 */     if ((paramInt1 == 1003) || ((paramInt1 == 1004) && (paramInt2 == 1007)))
/*      */     {
/*      */ 
/* 2002 */       return false;
/*      */     }
/* 2004 */     return true;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public static boolean supportRefreshRow(int paramInt1, int paramInt2)
/*      */   {
/* 2014 */     if ((paramInt1 == 1003) || ((paramInt1 == 1004) && (paramInt2 == 1007)))
/*      */     {
/*      */ 
/* 2017 */       return false;
/*      */     }
/* 2019 */     return true;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   int getFirstUserColumnIndex()
/*      */   {
/* 2039 */     return this.beginColumnIndex;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/* 2045 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Wed_Jun_22_11:18:52_PDT_2005";
/*      */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\ojdbc14.jar!\oracle\jdbc\driver\ScrollableResultSet.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       0.7.1
 */