/*      */ package oracle.jdbc.driver;
/*      */ 
/*      */ import java.io.ByteArrayInputStream;
/*      */ import java.io.IOException;
/*      */ import java.io.InputStream;
/*      */ import java.io.Reader;
/*      */ import java.math.BigDecimal;
/*      */ import java.net.MalformedURLException;
/*      */ import java.net.URL;
/*      */ import java.sql.Array;
/*      */ import java.sql.Blob;
/*      */ import java.sql.Clob;
/*      */ import java.sql.Date;
/*      */ import java.sql.Ref;
/*      */ import java.sql.ResultSet;
/*      */ import java.sql.ResultSetMetaData;
/*      */ import java.sql.SQLException;
/*      */ import java.sql.SQLWarning;
/*      */ import java.sql.Statement;
/*      */ import java.sql.Time;
/*      */ import java.sql.Timestamp;
/*      */ import java.util.Calendar;
/*      */ import java.util.Map;
/*      */ import oracle.sql.ARRAY;
/*      */ import oracle.sql.BFILE;
/*      */ import oracle.sql.BLOB;
/*      */ import oracle.sql.CHAR;
/*      */ import oracle.sql.CLOB;
/*      */ import oracle.sql.CustomDatum;
/*      */ import oracle.sql.CustomDatumFactory;
/*      */ import oracle.sql.DATE;
/*      */ import oracle.sql.Datum;
/*      */ import oracle.sql.INTERVALDS;
/*      */ import oracle.sql.INTERVALYM;
/*      */ import oracle.sql.NUMBER;
/*      */ import oracle.sql.OPAQUE;
/*      */ import oracle.sql.ORAData;
/*      */ import oracle.sql.ORADataFactory;
/*      */ import oracle.sql.RAW;
/*      */ import oracle.sql.REF;
/*      */ import oracle.sql.ROWID;
/*      */ import oracle.sql.STRUCT;
/*      */ import oracle.sql.TIMESTAMP;
/*      */ import oracle.sql.TIMESTAMPLTZ;
/*      */ import oracle.sql.TIMESTAMPTZ;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ class UpdatableResultSet
/*      */   extends BaseResultSet
/*      */ {
/*      */   static final int concurrencyType = 1008;
/*      */   static final int beginColumnIndex = 1;
/*      */   PhysicalConnection connection;
/*      */   OracleResultSet resultSet;
/*      */   boolean isCachedRset;
/*      */   ScrollRsetStatement scrollStmt;
/*      */   ResultSetMetaData rsetMetaData;
/*      */   private int rsetType;
/*      */   private int columnCount;
/*      */   private OraclePreparedStatement deleteStmt;
/*      */   private OraclePreparedStatement insertStmt;
/*      */   private OraclePreparedStatement updateStmt;
/*      */   private int[] indexColsChanged;
/*      */   private Object[] rowBuffer;
/*      */   private boolean[] m_nullIndicator;
/*      */   private int[][] typeInfo;
/*      */   private boolean isInserting;
/*      */   private boolean isUpdating;
/*      */   private int wasNull;
/*      */   private static final int VALUE_NULL = 1;
/*      */   private static final int VALUE_NOT_NULL = 2;
/*      */   private static final int VALUE_UNKNOWN = 3;
/*      */   private static final int VALUE_IN_RSET = 4;
/*      */   private static final int ASCII_STREAM = 1;
/*      */   private static final int BINARY_STREAM = 2;
/*      */   private static final int UNICODE_STREAM = 3;
/*   80 */   private static int _MIN_STREAM_SIZE = 4000;
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   UpdatableResultSet(ScrollRsetStatement paramScrollRsetStatement, ScrollableResultSet paramScrollableResultSet, int paramInt1, int paramInt2)
/*      */     throws SQLException
/*      */   {
/*   92 */     init(paramScrollRsetStatement, paramScrollableResultSet, paramInt1, paramInt2);
/*      */     
/*      */ 
/*   95 */     paramScrollableResultSet.resetBeginColumnIndex();
/*      */     
/*   97 */     this.isCachedRset = true;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   UpdatableResultSet(ScrollRsetStatement paramScrollRsetStatement, OracleResultSetImpl paramOracleResultSetImpl, int paramInt1, int paramInt2)
/*      */     throws SQLException
/*      */   {
/*  106 */     init(paramScrollRsetStatement, paramOracleResultSetImpl, paramInt1, paramInt2);
/*      */     
/*  108 */     this.isCachedRset = false;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void init(ScrollRsetStatement paramScrollRsetStatement, OracleResultSet paramOracleResultSet, int paramInt1, int paramInt2)
/*      */     throws SQLException
/*      */   {
/*  121 */     if ((paramScrollRsetStatement == null) || (paramOracleResultSet == null) || (paramInt2 != 1008)) {
/*  122 */       DatabaseError.throwSqlException(68);
/*      */     }
/*  124 */     this.connection = ((OracleStatement)paramScrollRsetStatement).connection;
/*  125 */     this.resultSet = paramOracleResultSet;
/*  126 */     this.scrollStmt = paramScrollRsetStatement;
/*  127 */     this.rsetType = paramInt1;
/*  128 */     this.autoRefetch = paramScrollRsetStatement.getAutoRefetch();
/*  129 */     this.deleteStmt = null;
/*  130 */     this.insertStmt = null;
/*  131 */     this.updateStmt = null;
/*  132 */     this.indexColsChanged = null;
/*  133 */     this.rowBuffer = null;
/*  134 */     this.m_nullIndicator = null;
/*  135 */     this.typeInfo = ((int[][])null);
/*  136 */     this.isInserting = false;
/*  137 */     this.isUpdating = false;
/*  138 */     this.wasNull = -1;
/*  139 */     this.rsetMetaData = null;
/*  140 */     this.columnCount = 0;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void close()
/*      */     throws SQLException
/*      */   {
/*  155 */     if (this.resultSet != null) {
/*  156 */       this.resultSet.close();
/*      */     }
/*  158 */     if (this.insertStmt != null) {
/*  159 */       this.insertStmt.close();
/*      */     }
/*  161 */     if (this.updateStmt != null) {
/*  162 */       this.updateStmt.close();
/*      */     }
/*  164 */     if (this.deleteStmt != null) {
/*  165 */       this.deleteStmt.close();
/*      */     }
/*  167 */     if (this.scrollStmt != null) {
/*  168 */       this.scrollStmt.notifyCloseRset();
/*      */     }
/*  170 */     cancelRowInserts();
/*      */     
/*  172 */     this.connection = null;
/*  173 */     this.resultSet = null;
/*  174 */     this.scrollStmt = null;
/*  175 */     this.rsetMetaData = null;
/*  176 */     this.scrollStmt = null;
/*  177 */     this.deleteStmt = null;
/*  178 */     this.insertStmt = null;
/*  179 */     this.updateStmt = null;
/*  180 */     this.indexColsChanged = null;
/*  181 */     this.rowBuffer = null;
/*  182 */     this.m_nullIndicator = null;
/*  183 */     this.typeInfo = ((int[][])null);
/*      */   }
/*      */   
/*      */   public synchronized boolean wasNull() throws SQLException
/*      */   {
/*  188 */     switch (this.wasNull)
/*      */     {
/*      */ 
/*      */     case 1: 
/*  192 */       return true;
/*      */     
/*      */     case 2: 
/*  195 */       return false;
/*      */     
/*      */     case 4: 
/*  198 */       return this.resultSet.wasNull();
/*      */     }
/*      */     
/*      */     
/*      */ 
/*  203 */     DatabaseError.throwSqlException(24);
/*      */     
/*      */ 
/*  206 */     return false;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   int getFirstUserColumnIndex()
/*      */   {
/*  219 */     return 1;
/*      */   }
/*      */   
/*      */   public synchronized Statement getStatement()
/*      */     throws SQLException
/*      */   {
/*  225 */     return (Statement)this.scrollStmt;
/*      */   }
/*      */   
/*      */   public SQLWarning getWarnings() throws SQLException
/*      */   {
/*  230 */     SQLWarning localSQLWarning1 = this.resultSet.getWarnings();
/*      */     
/*  232 */     if (this.sqlWarning == null) {
/*  233 */       return localSQLWarning1;
/*      */     }
/*      */     
/*  236 */     SQLWarning localSQLWarning2 = this.sqlWarning;
/*      */     
/*  238 */     while (localSQLWarning2.getNextWarning() != null) {
/*  239 */       localSQLWarning2 = localSQLWarning2.getNextWarning();
/*      */     }
/*  241 */     localSQLWarning2.setNextWarning(localSQLWarning1);
/*      */     
/*      */ 
/*  244 */     return this.sqlWarning;
/*      */   }
/*      */   
/*      */   public void clearWarnings() throws SQLException
/*      */   {
/*  249 */     this.sqlWarning = null;
/*      */     
/*  251 */     this.resultSet.clearWarnings();
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized boolean next()
/*      */     throws SQLException
/*      */   {
/*  260 */     cancelRowChanges();
/*      */     
/*  262 */     return this.resultSet.next();
/*      */   }
/*      */   
/*      */   public synchronized boolean isBeforeFirst() throws SQLException
/*      */   {
/*  267 */     return this.resultSet.isBeforeFirst();
/*      */   }
/*      */   
/*      */   public synchronized boolean isAfterLast() throws SQLException
/*      */   {
/*  272 */     return this.resultSet.isAfterLast();
/*      */   }
/*      */   
/*      */   public synchronized boolean isFirst() throws SQLException
/*      */   {
/*  277 */     return this.resultSet.isFirst();
/*      */   }
/*      */   
/*      */   public synchronized boolean isLast() throws SQLException
/*      */   {
/*  282 */     return this.resultSet.isLast();
/*      */   }
/*      */   
/*      */   public synchronized void beforeFirst() throws SQLException
/*      */   {
/*  287 */     cancelRowChanges();
/*  288 */     this.resultSet.beforeFirst();
/*      */   }
/*      */   
/*      */   public synchronized void afterLast() throws SQLException
/*      */   {
/*  293 */     cancelRowChanges();
/*  294 */     this.resultSet.afterLast();
/*      */   }
/*      */   
/*      */   public synchronized boolean first() throws SQLException
/*      */   {
/*  299 */     cancelRowChanges();
/*      */     
/*  301 */     return this.resultSet.first();
/*      */   }
/*      */   
/*      */   public synchronized boolean last() throws SQLException
/*      */   {
/*  306 */     cancelRowChanges();
/*      */     
/*  308 */     return this.resultSet.last();
/*      */   }
/*      */   
/*      */   public synchronized int getRow() throws SQLException
/*      */   {
/*  313 */     return this.resultSet.getRow();
/*      */   }
/*      */   
/*      */   public synchronized boolean absolute(int paramInt) throws SQLException
/*      */   {
/*  318 */     cancelRowChanges();
/*      */     
/*  320 */     return this.resultSet.absolute(paramInt);
/*      */   }
/*      */   
/*      */   public synchronized boolean relative(int paramInt) throws SQLException
/*      */   {
/*  325 */     cancelRowChanges();
/*      */     
/*  327 */     return this.resultSet.relative(paramInt);
/*      */   }
/*      */   
/*      */   public synchronized boolean previous() throws SQLException
/*      */   {
/*  332 */     cancelRowChanges();
/*      */     
/*  334 */     return this.resultSet.previous();
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized Datum getOracleObject(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  343 */     Datum localDatum = null;
/*      */     
/*  345 */     setIsNull(3);
/*      */     
/*  347 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  350 */       setIsNull(localDatum == null);
/*      */       
/*  352 */       localDatum = getRowBufferDatumAt(paramInt);
/*      */     }
/*      */     else
/*      */     {
/*  356 */       setIsNull(4);
/*      */       
/*  358 */       localDatum = this.resultSet.getOracleObject(paramInt + 1);
/*      */     }
/*      */     
/*  361 */     return localDatum;
/*      */   }
/*      */   
/*      */   public synchronized String getString(int paramInt) throws SQLException
/*      */   {
/*  366 */     String str = null;
/*      */     
/*  368 */     setIsNull(3);
/*      */     
/*  370 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  373 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/*  375 */       setIsNull(localDatum == null);
/*      */       
/*  377 */       if (localDatum != null) {
/*  378 */         str = localDatum.stringValue();
/*      */       }
/*      */     }
/*      */     else {
/*  382 */       setIsNull(4);
/*      */       
/*  384 */       str = this.resultSet.getString(paramInt + 1);
/*      */     }
/*      */     
/*  387 */     return str;
/*      */   }
/*      */   
/*      */   public synchronized boolean getBoolean(int paramInt) throws SQLException
/*      */   {
/*  392 */     boolean bool = false;
/*      */     
/*  394 */     setIsNull(3);
/*      */     
/*  396 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  399 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/*  401 */       setIsNull(localDatum == null);
/*      */       
/*  403 */       if (localDatum != null) {
/*  404 */         bool = localDatum.booleanValue();
/*      */       }
/*      */     }
/*      */     else {
/*  408 */       setIsNull(4);
/*      */       
/*  410 */       bool = this.resultSet.getBoolean(paramInt + 1);
/*      */     }
/*      */     
/*  413 */     return bool;
/*      */   }
/*      */   
/*      */   public synchronized byte getByte(int paramInt) throws SQLException
/*      */   {
/*  418 */     byte b = 0;
/*      */     
/*  420 */     setIsNull(3);
/*      */     
/*  422 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  425 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/*  427 */       setIsNull(localDatum == null);
/*      */       
/*  429 */       if (localDatum != null) {
/*  430 */         b = localDatum.byteValue();
/*      */       }
/*      */     }
/*      */     else {
/*  434 */       setIsNull(4);
/*      */       
/*  436 */       b = this.resultSet.getByte(paramInt + 1);
/*      */     }
/*      */     
/*  439 */     return b;
/*      */   }
/*      */   
/*      */   public synchronized short getShort(int paramInt) throws SQLException
/*      */   {
/*  444 */     short s = 0;
/*      */     
/*  446 */     setIsNull(3);
/*      */     
/*  448 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  451 */       long l = getLong(paramInt);
/*      */       
/*  453 */       if ((l > 65537L) || (l < -65538L)) {
/*  454 */         DatabaseError.throwSqlException(26, "getShort");
/*      */       }
/*      */       
/*  457 */       s = (short)(int)l;
/*      */     }
/*      */     else
/*      */     {
/*  461 */       setIsNull(4);
/*      */       
/*  463 */       s = this.resultSet.getShort(paramInt + 1);
/*      */     }
/*      */     
/*  466 */     return s;
/*      */   }
/*      */   
/*      */   public synchronized int getInt(int paramInt) throws SQLException
/*      */   {
/*  471 */     int i = 0;
/*      */     
/*  473 */     setIsNull(3);
/*      */     
/*  475 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  478 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/*  480 */       setIsNull(localDatum == null);
/*      */       
/*  482 */       if (localDatum != null) {
/*  483 */         i = localDatum.intValue();
/*      */       }
/*      */     }
/*      */     else {
/*  487 */       setIsNull(4);
/*      */       
/*  489 */       i = this.resultSet.getInt(paramInt + 1);
/*      */     }
/*      */     
/*  492 */     return i;
/*      */   }
/*      */   
/*      */   public synchronized long getLong(int paramInt) throws SQLException
/*      */   {
/*  497 */     long l = 0L;
/*      */     
/*  499 */     setIsNull(3);
/*      */     
/*  501 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  504 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/*  506 */       setIsNull(localDatum == null);
/*      */       
/*  508 */       if (localDatum != null) {
/*  509 */         l = localDatum.longValue();
/*      */       }
/*      */     }
/*      */     else {
/*  513 */       setIsNull(4);
/*      */       
/*  515 */       l = this.resultSet.getLong(paramInt + 1);
/*      */     }
/*      */     
/*  518 */     return l;
/*      */   }
/*      */   
/*      */   public synchronized float getFloat(int paramInt) throws SQLException
/*      */   {
/*  523 */     float f = 0.0F;
/*      */     
/*  525 */     setIsNull(3);
/*      */     
/*  527 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  530 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/*  532 */       setIsNull(localDatum == null);
/*      */       
/*  534 */       if (localDatum != null) {
/*  535 */         f = localDatum.floatValue();
/*      */       }
/*      */     }
/*      */     else {
/*  539 */       setIsNull(4);
/*      */       
/*  541 */       f = this.resultSet.getFloat(paramInt + 1);
/*      */     }
/*      */     
/*  544 */     return f;
/*      */   }
/*      */   
/*      */   public synchronized double getDouble(int paramInt) throws SQLException
/*      */   {
/*  549 */     double d = 0.0D;
/*      */     
/*  551 */     setIsNull(3);
/*      */     
/*  553 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  556 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/*  558 */       setIsNull(localDatum == null);
/*      */       
/*  560 */       if (localDatum != null) {
/*  561 */         d = localDatum.doubleValue();
/*      */       }
/*      */     }
/*      */     else {
/*  565 */       setIsNull(4);
/*      */       
/*  567 */       d = this.resultSet.getDouble(paramInt + 1);
/*      */     }
/*      */     
/*  570 */     return d;
/*      */   }
/*      */   
/*      */   public synchronized BigDecimal getBigDecimal(int paramInt1, int paramInt2)
/*      */     throws SQLException
/*      */   {
/*  576 */     BigDecimal localBigDecimal = null;
/*      */     
/*  578 */     setIsNull(3);
/*      */     
/*  580 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt1))))
/*      */     {
/*      */ 
/*  583 */       Datum localDatum = getRowBufferDatumAt(paramInt1);
/*      */       
/*  585 */       setIsNull(localDatum == null);
/*      */       
/*  587 */       if (localDatum != null) {
/*  588 */         localBigDecimal = localDatum.bigDecimalValue();
/*      */       }
/*      */     }
/*      */     else {
/*  592 */       setIsNull(4);
/*      */       
/*  594 */       localBigDecimal = this.resultSet.getBigDecimal(paramInt1 + 1);
/*      */     }
/*      */     
/*  597 */     return localBigDecimal;
/*      */   }
/*      */   
/*      */   public synchronized byte[] getBytes(int paramInt) throws SQLException
/*      */   {
/*  602 */     byte[] arrayOfByte = null;
/*      */     
/*  604 */     setIsNull(3);
/*      */     
/*  606 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  609 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/*  611 */       setIsNull(localDatum == null);
/*      */       
/*  613 */       if (localDatum != null) {
/*  614 */         arrayOfByte = localDatum.getBytes();
/*      */       }
/*      */     }
/*      */     else {
/*  618 */       setIsNull(4);
/*      */       
/*  620 */       arrayOfByte = this.resultSet.getBytes(paramInt + 1);
/*      */     }
/*      */     
/*  623 */     return arrayOfByte;
/*      */   }
/*      */   
/*      */   public synchronized Date getDate(int paramInt) throws SQLException
/*      */   {
/*  628 */     Date localDate = null;
/*      */     
/*  630 */     setIsNull(3);
/*      */     
/*  632 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  635 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/*  637 */       setIsNull(localDatum == null);
/*      */       
/*  639 */       if (localDatum != null) {
/*  640 */         localDate = localDatum.dateValue();
/*      */       }
/*      */     }
/*      */     else {
/*  644 */       setIsNull(4);
/*      */       
/*  646 */       localDate = this.resultSet.getDate(paramInt + 1);
/*      */     }
/*      */     
/*  649 */     return localDate;
/*      */   }
/*      */   
/*      */   public synchronized Time getTime(int paramInt) throws SQLException
/*      */   {
/*  654 */     Time localTime = null;
/*      */     
/*  656 */     setIsNull(3);
/*      */     
/*  658 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  661 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/*  663 */       setIsNull(localDatum == null);
/*      */       
/*  665 */       if (localDatum != null) {
/*  666 */         localTime = localDatum.timeValue();
/*      */       }
/*      */     }
/*      */     else {
/*  670 */       setIsNull(4);
/*      */       
/*  672 */       localTime = this.resultSet.getTime(paramInt + 1);
/*      */     }
/*      */     
/*  675 */     return localTime;
/*      */   }
/*      */   
/*      */   public synchronized Timestamp getTimestamp(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  681 */     Timestamp localTimestamp = null;
/*      */     
/*  683 */     setIsNull(3);
/*      */     
/*  685 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  688 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/*  690 */       setIsNull(localDatum == null);
/*      */       
/*  692 */       if (localDatum != null) {
/*  693 */         localTimestamp = localDatum.timestampValue();
/*      */       }
/*      */     }
/*      */     else {
/*  697 */       setIsNull(4);
/*      */       
/*  699 */       localTimestamp = this.resultSet.getTimestamp(paramInt + 1);
/*      */     }
/*      */     
/*  702 */     return localTimestamp;
/*      */   }
/*      */   
/*      */   public synchronized InputStream getAsciiStream(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  708 */     InputStream localInputStream = null;
/*      */     
/*  710 */     setIsNull(3);
/*      */     
/*  712 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  715 */       Object localObject = getRowBufferAt(paramInt);
/*      */       
/*  717 */       setIsNull(localObject == null);
/*      */       
/*  719 */       if (localObject != null)
/*      */       {
/*  721 */         if ((localObject instanceof InputStream))
/*      */         {
/*  723 */           localInputStream = (InputStream)localObject;
/*      */         }
/*      */         else
/*      */         {
/*  727 */           Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */           
/*  729 */           localInputStream = localDatum.asciiStreamValue();
/*      */         }
/*      */       }
/*      */     }
/*      */     else
/*      */     {
/*  735 */       setIsNull(4);
/*      */       
/*  737 */       localInputStream = this.resultSet.getAsciiStream(paramInt + 1);
/*      */     }
/*      */     
/*  740 */     return localInputStream;
/*      */   }
/*      */   
/*      */   public synchronized InputStream getUnicodeStream(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  746 */     InputStream localInputStream = null;
/*      */     
/*  748 */     setIsNull(3);
/*      */     
/*  750 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  753 */       Object localObject = getRowBufferAt(paramInt);
/*      */       
/*  755 */       setIsNull(localObject == null);
/*      */       
/*  757 */       if (localObject != null)
/*      */       {
/*  759 */         if ((localObject instanceof InputStream))
/*      */         {
/*  761 */           localInputStream = (InputStream)localObject;
/*      */         }
/*      */         else
/*      */         {
/*  765 */           Datum localDatum = getRowBufferDatumAt(paramInt);
/*  766 */           DBConversion localDBConversion = this.connection.conversion;
/*  767 */           byte[] arrayOfByte = localDatum.shareBytes();
/*      */           
/*  769 */           if ((localDatum instanceof RAW))
/*      */           {
/*  771 */             localInputStream = localDBConversion.ConvertStream(new ByteArrayInputStream(arrayOfByte), 3);
/*      */ 
/*      */           }
/*  774 */           else if ((localDatum instanceof CHAR))
/*      */           {
/*  776 */             localInputStream = localDBConversion.ConvertStream(new ByteArrayInputStream(arrayOfByte), 1);
/*      */           }
/*      */           else
/*      */           {
/*  780 */             DatabaseError.throwSqlException(4, "getUnicodeStream");
/*      */           }
/*      */         }
/*      */       }
/*      */     }
/*      */     else
/*      */     {
/*  787 */       setIsNull(4);
/*      */       
/*  789 */       localInputStream = this.resultSet.getUnicodeStream(paramInt + 1);
/*      */     }
/*      */     
/*  792 */     return localInputStream;
/*      */   }
/*      */   
/*      */   public synchronized InputStream getBinaryStream(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  798 */     InputStream localInputStream = null;
/*      */     
/*  800 */     setIsNull(3);
/*      */     
/*  802 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  805 */       Object localObject = getRowBufferAt(paramInt);
/*      */       
/*  807 */       setIsNull(localObject == null);
/*      */       
/*  809 */       if (localObject != null)
/*      */       {
/*  811 */         if ((localObject instanceof InputStream))
/*      */         {
/*  813 */           localInputStream = (InputStream)localObject;
/*      */         }
/*      */         else
/*      */         {
/*  817 */           Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */           
/*  819 */           localInputStream = localDatum.binaryStreamValue();
/*      */         }
/*      */       }
/*      */     }
/*      */     else
/*      */     {
/*  825 */       setIsNull(4);
/*      */       
/*  827 */       localInputStream = this.resultSet.getBinaryStream(paramInt + 1);
/*      */     }
/*      */     
/*  830 */     return localInputStream;
/*      */   }
/*      */   
/*      */   public synchronized Object getObject(int paramInt) throws SQLException
/*      */   {
/*  835 */     Object localObject = null;
/*      */     
/*  837 */     setIsNull(3);
/*      */     
/*  839 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  842 */       Datum localDatum = getOracleObject(paramInt);
/*      */       
/*  844 */       setIsNull(localDatum == null);
/*      */       
/*  846 */       if (localDatum != null) {
/*  847 */         localObject = localDatum.toJdbc();
/*      */       }
/*      */     }
/*      */     else {
/*  851 */       setIsNull(4);
/*      */       
/*  853 */       localObject = this.resultSet.getObject(paramInt + 1);
/*      */     }
/*      */     
/*  856 */     return localObject;
/*      */   }
/*      */   
/*      */ 
/*      */   public synchronized Reader getCharacterStream(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  863 */     Reader localReader = null;
/*      */     
/*  865 */     setIsNull(3);
/*      */     
/*  867 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  870 */       Object localObject = getRowBufferAt(paramInt);
/*      */       
/*  872 */       setIsNull(localObject == null);
/*      */       
/*  874 */       if (localObject != null)
/*      */       {
/*  876 */         if ((localObject instanceof Reader))
/*      */         {
/*  878 */           localReader = (Reader)localObject;
/*      */         }
/*      */         else
/*      */         {
/*  882 */           Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */           
/*  884 */           localReader = localDatum.characterStreamValue();
/*      */         }
/*      */       }
/*      */     }
/*      */     else
/*      */     {
/*  890 */       setIsNull(4);
/*      */       
/*  892 */       localReader = this.resultSet.getCharacterStream(paramInt + 1);
/*      */     }
/*      */     
/*  895 */     return localReader;
/*      */   }
/*      */   
/*      */ 
/*      */   public synchronized BigDecimal getBigDecimal(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  902 */     BigDecimal localBigDecimal = null;
/*      */     
/*  904 */     setIsNull(3);
/*      */     
/*  906 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  909 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/*  911 */       setIsNull(localDatum == null);
/*      */       
/*  913 */       if (localDatum != null) {
/*  914 */         localBigDecimal = localDatum.bigDecimalValue();
/*      */       }
/*      */     }
/*      */     else {
/*  918 */       setIsNull(4);
/*      */       
/*  920 */       localBigDecimal = this.resultSet.getBigDecimal(paramInt + 1);
/*      */     }
/*      */     
/*  923 */     return localBigDecimal;
/*      */   }
/*      */   
/*      */ 
/*      */   public synchronized Object getObject(int paramInt, Map paramMap)
/*      */     throws SQLException
/*      */   {
/*  930 */     Object localObject = null;
/*      */     
/*  932 */     setIsNull(3);
/*      */     
/*  934 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  937 */       Datum localDatum = getOracleObject(paramInt);
/*      */       
/*  939 */       setIsNull(localDatum == null);
/*      */       
/*  941 */       if (localDatum != null)
/*      */       {
/*  943 */         if ((localDatum instanceof STRUCT)) {
/*  944 */           localObject = ((STRUCT)localDatum).toJdbc(paramMap);
/*      */         } else {
/*  946 */           localObject = localDatum.toJdbc();
/*      */         }
/*      */       }
/*      */     }
/*      */     else {
/*  951 */       setIsNull(4);
/*      */       
/*  953 */       localObject = this.resultSet.getObject(paramInt + 1, paramMap);
/*      */     }
/*      */     
/*  956 */     return localObject;
/*      */   }
/*      */   
/*      */   public synchronized Ref getRef(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  962 */     return getREF(paramInt);
/*      */   }
/*      */   
/*      */   public synchronized Blob getBlob(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  968 */     return getBLOB(paramInt);
/*      */   }
/*      */   
/*      */   public synchronized Clob getClob(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  974 */     return getCLOB(paramInt);
/*      */   }
/*      */   
/*      */ 
/*      */   public synchronized Array getArray(int paramInt)
/*      */     throws SQLException
/*      */   {
/*  981 */     return getARRAY(paramInt);
/*      */   }
/*      */   
/*      */ 
/*      */   public synchronized Date getDate(int paramInt, Calendar paramCalendar)
/*      */     throws SQLException
/*      */   {
/*  988 */     Date localDate = null;
/*      */     
/*  990 */     setIsNull(3);
/*      */     
/*  992 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/*  995 */       Datum localDatum = getOracleObject(paramInt);
/*      */       
/*  997 */       setIsNull(localDatum == null);
/*      */       
/*  999 */       if (localDatum != null)
/*      */       {
/* 1001 */         if ((localDatum instanceof DATE)) {
/* 1002 */           localDate = ((DATE)localDatum).dateValue(paramCalendar);
/*      */         }
/*      */         else {
/* 1005 */           DATE localDATE = new DATE(localDatum.stringValue());
/*      */           
/* 1007 */           if (localDATE != null) {
/* 1008 */             localDate = localDATE.dateValue(paramCalendar);
/*      */           }
/*      */         }
/*      */       }
/*      */     }
/*      */     else {
/* 1014 */       setIsNull(4);
/*      */       
/* 1016 */       localDate = this.resultSet.getDate(paramInt + 1, paramCalendar);
/*      */     }
/*      */     
/* 1019 */     return localDate;
/*      */   }
/*      */   
/*      */ 
/*      */   public synchronized Time getTime(int paramInt, Calendar paramCalendar)
/*      */     throws SQLException
/*      */   {
/* 1026 */     Time localTime = null;
/*      */     
/* 1028 */     setIsNull(3);
/*      */     
/* 1030 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1033 */       Datum localDatum = getOracleObject(paramInt);
/*      */       
/* 1035 */       setIsNull(localDatum == null);
/*      */       
/* 1037 */       if (localDatum != null)
/*      */       {
/* 1039 */         if ((localDatum instanceof DATE)) {
/* 1040 */           localTime = ((DATE)localDatum).timeValue(paramCalendar);
/*      */         }
/*      */         else {
/* 1043 */           DATE localDATE = new DATE(localDatum.stringValue());
/*      */           
/* 1045 */           if (localDATE != null) {
/* 1046 */             localTime = localDATE.timeValue(paramCalendar);
/*      */           }
/*      */         }
/*      */       }
/*      */     }
/*      */     else {
/* 1052 */       setIsNull(4);
/*      */       
/* 1054 */       localTime = this.resultSet.getTime(paramInt + 1, paramCalendar);
/*      */     }
/*      */     
/* 1057 */     return localTime;
/*      */   }
/*      */   
/*      */ 
/*      */   public synchronized Timestamp getTimestamp(int paramInt, Calendar paramCalendar)
/*      */     throws SQLException
/*      */   {
/* 1064 */     Timestamp localTimestamp = null;
/*      */     
/* 1066 */     setIsNull(3);
/*      */     
/* 1068 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1071 */       Datum localDatum = getOracleObject(paramInt);
/*      */       
/* 1073 */       setIsNull(localDatum == null);
/*      */       
/* 1075 */       if (localDatum != null)
/*      */       {
/* 1077 */         if ((localDatum instanceof DATE)) {
/* 1078 */           localTimestamp = ((DATE)localDatum).timestampValue(paramCalendar);
/*      */         }
/*      */         else {
/* 1081 */           DATE localDATE = new DATE(localDatum.stringValue());
/*      */           
/* 1083 */           if (localDATE != null) {
/* 1084 */             localTimestamp = localDATE.timestampValue(paramCalendar);
/*      */           }
/*      */         }
/*      */       }
/*      */     }
/*      */     else {
/* 1090 */       setIsNull(4);
/*      */       
/* 1092 */       localTimestamp = this.resultSet.getTimestamp(paramInt + 1, paramCalendar);
/*      */     }
/*      */     
/* 1095 */     return localTimestamp;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized URL getURL(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1105 */     URL localURL = null;
/*      */     
/* 1107 */     int i = getInternalMetadata().getColumnType(paramInt);
/* 1108 */     int j = SQLUtil.getInternalType(i);
/*      */     
/*      */ 
/* 1111 */     if ((j == 96) || (j == 1) || (j == 8))
/*      */     {
/*      */       try
/*      */       {
/*      */ 
/* 1116 */         localURL = new URL(getString(paramInt));
/*      */       }
/*      */       catch (MalformedURLException localMalformedURLException)
/*      */       {
/* 1120 */         DatabaseError.throwSqlException(136);
/*      */       }
/*      */       
/*      */     }
/*      */     else {
/* 1125 */       throw new SQLException("Conversion to java.net.URL not supported.");
/*      */     }
/*      */     
/* 1128 */     return localURL;
/*      */   }
/*      */   
/*      */   public synchronized ResultSet getCursor(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1134 */     ResultSet localResultSet = null;
/*      */     
/* 1136 */     setIsNull(3);
/*      */     
/* 1138 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1141 */       Datum localDatum = getOracleObject(paramInt);
/*      */       
/* 1143 */       setIsNull(localDatum == null);
/* 1144 */       DatabaseError.throwSqlException(4, "getCursor");
/*      */ 
/*      */     }
/*      */     else
/*      */     {
/* 1149 */       setIsNull(4);
/*      */       
/* 1151 */       localResultSet = this.resultSet.getCursor(paramInt + 1);
/*      */     }
/*      */     
/* 1154 */     return localResultSet;
/*      */   }
/*      */   
/*      */   public synchronized ROWID getROWID(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1160 */     ROWID localROWID = null;
/*      */     
/* 1162 */     setIsNull(3);
/*      */     
/* 1164 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1167 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1169 */       setIsNull(localDatum == null);
/*      */       
/* 1171 */       if ((localDatum != null) && (!(localDatum instanceof ROWID))) {
/* 1172 */         DatabaseError.throwSqlException(4, "getROWID");
/*      */       }
/*      */       
/* 1175 */       localROWID = (ROWID)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1179 */       setIsNull(4);
/*      */       
/* 1181 */       localROWID = this.resultSet.getROWID(paramInt + 1);
/*      */     }
/*      */     
/* 1184 */     return localROWID;
/*      */   }
/*      */   
/*      */   public synchronized NUMBER getNUMBER(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1190 */     NUMBER localNUMBER = null;
/*      */     
/* 1192 */     setIsNull(3);
/*      */     
/* 1194 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1197 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1199 */       setIsNull(localDatum == null);
/*      */       
/* 1201 */       if ((localDatum != null) && (!(localDatum instanceof NUMBER))) {
/* 1202 */         DatabaseError.throwSqlException(4, "getNUMBER");
/*      */       }
/*      */       
/* 1205 */       localNUMBER = (NUMBER)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1209 */       setIsNull(4);
/*      */       
/* 1211 */       localNUMBER = this.resultSet.getNUMBER(paramInt + 1);
/*      */     }
/*      */     
/* 1214 */     return localNUMBER;
/*      */   }
/*      */   
/*      */   public synchronized DATE getDATE(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1220 */     DATE localDATE = null;
/*      */     
/* 1222 */     setIsNull(3);
/*      */     
/* 1224 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1227 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1229 */       setIsNull(localDatum == null);
/*      */       
/* 1231 */       if ((localDatum != null) && (!(localDatum instanceof DATE))) {
/* 1232 */         DatabaseError.throwSqlException(4, "getDATE");
/*      */       }
/*      */       
/* 1235 */       localDATE = (DATE)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1239 */       setIsNull(4);
/*      */       
/* 1241 */       localDATE = this.resultSet.getDATE(paramInt + 1);
/*      */     }
/*      */     
/* 1244 */     return localDATE;
/*      */   }
/*      */   
/*      */   public synchronized TIMESTAMP getTIMESTAMP(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1250 */     TIMESTAMP localTIMESTAMP = null;
/*      */     
/* 1252 */     setIsNull(3);
/*      */     
/* 1254 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1257 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1259 */       setIsNull(localDatum == null);
/*      */       
/* 1261 */       if ((localDatum != null) && (!(localDatum instanceof TIMESTAMP))) {
/* 1262 */         DatabaseError.throwSqlException(4, "getTIMESTAMP");
/*      */       }
/*      */       
/* 1265 */       localTIMESTAMP = (TIMESTAMP)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1269 */       setIsNull(4);
/*      */       
/* 1271 */       localTIMESTAMP = this.resultSet.getTIMESTAMP(paramInt + 1);
/*      */     }
/*      */     
/* 1274 */     return localTIMESTAMP;
/*      */   }
/*      */   
/*      */   public synchronized TIMESTAMPTZ getTIMESTAMPTZ(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1280 */     TIMESTAMPTZ localTIMESTAMPTZ = null;
/*      */     
/* 1282 */     setIsNull(3);
/*      */     
/* 1284 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1287 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1289 */       setIsNull(localDatum == null);
/*      */       
/* 1291 */       if ((localDatum != null) && (!(localDatum instanceof TIMESTAMPTZ))) {
/* 1292 */         DatabaseError.throwSqlException(4, "getTIMESTAMPTZ");
/*      */       }
/*      */       
/* 1295 */       localTIMESTAMPTZ = (TIMESTAMPTZ)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1299 */       setIsNull(4);
/*      */       
/* 1301 */       localTIMESTAMPTZ = this.resultSet.getTIMESTAMPTZ(paramInt + 1);
/*      */     }
/*      */     
/* 1304 */     return localTIMESTAMPTZ;
/*      */   }
/*      */   
/*      */   public synchronized TIMESTAMPLTZ getTIMESTAMPLTZ(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1310 */     TIMESTAMPLTZ localTIMESTAMPLTZ = null;
/*      */     
/* 1312 */     setIsNull(3);
/*      */     
/* 1314 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1317 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1319 */       setIsNull(localDatum == null);
/*      */       
/* 1321 */       if ((localDatum != null) && (!(localDatum instanceof TIMESTAMPLTZ))) {
/* 1322 */         DatabaseError.throwSqlException(4, "getTIMESTAMPLTZ");
/*      */       }
/*      */       
/* 1325 */       localTIMESTAMPLTZ = (TIMESTAMPLTZ)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1329 */       setIsNull(4);
/*      */       
/* 1331 */       localTIMESTAMPLTZ = this.resultSet.getTIMESTAMPLTZ(paramInt + 1);
/*      */     }
/*      */     
/* 1334 */     return localTIMESTAMPLTZ;
/*      */   }
/*      */   
/*      */   public synchronized INTERVALDS getINTERVALDS(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1340 */     INTERVALDS localINTERVALDS = null;
/*      */     
/* 1342 */     setIsNull(3);
/*      */     
/* 1344 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1347 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1349 */       setIsNull(localDatum == null);
/*      */       
/* 1351 */       if ((localDatum != null) && (!(localDatum instanceof INTERVALDS))) {
/* 1352 */         DatabaseError.throwSqlException(4, "getINTERVALDS");
/*      */       }
/*      */       
/* 1355 */       localINTERVALDS = (INTERVALDS)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1359 */       setIsNull(4);
/*      */       
/* 1361 */       localINTERVALDS = this.resultSet.getINTERVALDS(paramInt + 1);
/*      */     }
/*      */     
/* 1364 */     return localINTERVALDS;
/*      */   }
/*      */   
/*      */   public synchronized INTERVALYM getINTERVALYM(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1370 */     INTERVALYM localINTERVALYM = null;
/*      */     
/* 1372 */     setIsNull(3);
/*      */     
/* 1374 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1377 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1379 */       setIsNull(localDatum == null);
/*      */       
/* 1381 */       if ((localDatum != null) && (!(localDatum instanceof INTERVALYM))) {
/* 1382 */         DatabaseError.throwSqlException(4, "getINTERVALYM");
/*      */       }
/*      */       
/* 1385 */       localINTERVALYM = (INTERVALYM)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1389 */       setIsNull(4);
/*      */       
/* 1391 */       localINTERVALYM = this.resultSet.getINTERVALYM(paramInt + 1);
/*      */     }
/*      */     
/* 1394 */     return localINTERVALYM;
/*      */   }
/*      */   
/*      */   public synchronized ARRAY getARRAY(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1400 */     ARRAY localARRAY = null;
/*      */     
/* 1402 */     setIsNull(3);
/*      */     
/* 1404 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1407 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1409 */       setIsNull(localDatum == null);
/*      */       
/* 1411 */       if ((localDatum != null) && (!(localDatum instanceof ARRAY))) {
/* 1412 */         DatabaseError.throwSqlException(4, "getARRAY");
/*      */       }
/*      */       
/* 1415 */       localARRAY = (ARRAY)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1419 */       setIsNull(4);
/*      */       
/* 1421 */       localARRAY = this.resultSet.getARRAY(paramInt + 1);
/*      */     }
/*      */     
/* 1424 */     return localARRAY;
/*      */   }
/*      */   
/*      */   public synchronized STRUCT getSTRUCT(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1430 */     STRUCT localSTRUCT = null;
/*      */     
/* 1432 */     setIsNull(3);
/*      */     
/* 1434 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1437 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1439 */       setIsNull(localDatum == null);
/*      */       
/* 1441 */       if ((localDatum != null) && (!(localDatum instanceof STRUCT))) {
/* 1442 */         DatabaseError.throwSqlException(4, "getSTRUCT");
/*      */       }
/*      */       
/* 1445 */       localSTRUCT = (STRUCT)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1449 */       setIsNull(4);
/*      */       
/* 1451 */       localSTRUCT = this.resultSet.getSTRUCT(paramInt + 1);
/*      */     }
/*      */     
/* 1454 */     return localSTRUCT;
/*      */   }
/*      */   
/*      */   public synchronized OPAQUE getOPAQUE(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1460 */     OPAQUE localOPAQUE = null;
/*      */     
/* 1462 */     setIsNull(3);
/*      */     
/* 1464 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1467 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1469 */       setIsNull(localDatum == null);
/*      */       
/* 1471 */       if ((localDatum != null) && (!(localDatum instanceof OPAQUE))) {
/* 1472 */         DatabaseError.throwSqlException(4, "getOPAQUE");
/*      */       }
/*      */       
/* 1475 */       localOPAQUE = (OPAQUE)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1479 */       setIsNull(4);
/*      */       
/* 1481 */       localOPAQUE = this.resultSet.getOPAQUE(paramInt + 1);
/*      */     }
/*      */     
/* 1484 */     return localOPAQUE;
/*      */   }
/*      */   
/*      */   public synchronized REF getREF(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1490 */     REF localREF = null;
/*      */     
/* 1492 */     setIsNull(3);
/*      */     
/* 1494 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1497 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1499 */       setIsNull(localDatum == null);
/*      */       
/* 1501 */       if ((localDatum != null) && (!(localDatum instanceof REF))) {
/* 1502 */         DatabaseError.throwSqlException(4, "getREF");
/*      */       }
/*      */       
/* 1505 */       localREF = (REF)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1509 */       setIsNull(4);
/*      */       
/* 1511 */       localREF = this.resultSet.getREF(paramInt + 1);
/*      */     }
/*      */     
/* 1514 */     return localREF;
/*      */   }
/*      */   
/*      */   public synchronized CHAR getCHAR(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1520 */     CHAR localCHAR = null;
/*      */     
/* 1522 */     setIsNull(3);
/*      */     
/* 1524 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1527 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1529 */       setIsNull(localDatum == null);
/*      */       
/* 1531 */       if ((localDatum != null) && (!(localDatum instanceof CHAR))) {
/* 1532 */         DatabaseError.throwSqlException(4, "getCHAR");
/*      */       }
/*      */       
/* 1535 */       localCHAR = (CHAR)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1539 */       setIsNull(4);
/*      */       
/* 1541 */       localCHAR = this.resultSet.getCHAR(paramInt + 1);
/*      */     }
/*      */     
/* 1544 */     return localCHAR;
/*      */   }
/*      */   
/*      */   public synchronized RAW getRAW(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1550 */     RAW localRAW = null;
/*      */     
/* 1552 */     setIsNull(3);
/*      */     
/* 1554 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1557 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1559 */       setIsNull(localDatum == null);
/*      */       
/* 1561 */       if ((localDatum != null) && (!(localDatum instanceof RAW))) {
/* 1562 */         DatabaseError.throwSqlException(4, "getRAW");
/*      */       }
/*      */       
/* 1565 */       localRAW = (RAW)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1569 */       setIsNull(4);
/*      */       
/* 1571 */       localRAW = this.resultSet.getRAW(paramInt + 1);
/*      */     }
/*      */     
/* 1574 */     return localRAW;
/*      */   }
/*      */   
/*      */   public synchronized BLOB getBLOB(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1580 */     BLOB localBLOB = null;
/*      */     
/* 1582 */     setIsNull(3);
/*      */     
/* 1584 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1587 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1589 */       setIsNull(localDatum == null);
/*      */       
/* 1591 */       if ((localDatum != null) && (!(localDatum instanceof BLOB))) {
/* 1592 */         DatabaseError.throwSqlException(4, "getBLOB");
/*      */       }
/*      */       
/* 1595 */       localBLOB = (BLOB)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1599 */       setIsNull(4);
/*      */       
/* 1601 */       localBLOB = this.resultSet.getBLOB(paramInt + 1);
/*      */     }
/*      */     
/* 1604 */     return localBLOB;
/*      */   }
/*      */   
/*      */   public synchronized CLOB getCLOB(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1610 */     CLOB localCLOB = null;
/*      */     
/* 1612 */     setIsNull(3);
/*      */     
/* 1614 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1617 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1619 */       setIsNull(localDatum == null);
/*      */       
/* 1621 */       if ((localDatum != null) && (!(localDatum instanceof CLOB))) {
/* 1622 */         DatabaseError.throwSqlException(4, "getCLOB");
/*      */       }
/*      */       
/* 1625 */       localCLOB = (CLOB)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1629 */       setIsNull(4);
/*      */       
/* 1631 */       localCLOB = this.resultSet.getCLOB(paramInt + 1);
/*      */     }
/*      */     
/* 1634 */     return localCLOB;
/*      */   }
/*      */   
/*      */   public synchronized BFILE getBFILE(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1640 */     BFILE localBFILE = null;
/*      */     
/* 1642 */     setIsNull(3);
/*      */     
/* 1644 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1647 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1649 */       setIsNull(localDatum == null);
/*      */       
/* 1651 */       if ((localDatum != null) && (!(localDatum instanceof BFILE))) {
/* 1652 */         DatabaseError.throwSqlException(4, "getBFILE");
/*      */       }
/*      */       
/* 1655 */       localBFILE = (BFILE)localDatum;
/*      */     }
/*      */     else
/*      */     {
/* 1659 */       setIsNull(4);
/*      */       
/* 1661 */       localBFILE = this.resultSet.getBFILE(paramInt + 1);
/*      */     }
/*      */     
/* 1664 */     return localBFILE;
/*      */   }
/*      */   
/*      */   public synchronized BFILE getBfile(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1670 */     return getBFILE(paramInt);
/*      */   }
/*      */   
/*      */ 
/*      */   public synchronized CustomDatum getCustomDatum(int paramInt, CustomDatumFactory paramCustomDatumFactory)
/*      */     throws SQLException
/*      */   {
/* 1677 */     if (paramCustomDatumFactory == null) {
/* 1678 */       DatabaseError.throwSqlException(68);
/*      */     }
/* 1680 */     CustomDatum localCustomDatum = null;
/*      */     
/* 1682 */     setIsNull(3);
/*      */     
/* 1684 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1687 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1689 */       setIsNull(localDatum == null);
/*      */       
/* 1691 */       localCustomDatum = paramCustomDatumFactory.create(localDatum, 0);
/*      */     }
/*      */     else
/*      */     {
/* 1695 */       setIsNull(4);
/*      */       
/* 1697 */       localCustomDatum = this.resultSet.getCustomDatum(paramInt + 1, paramCustomDatumFactory);
/*      */     }
/*      */     
/* 1700 */     return localCustomDatum;
/*      */   }
/*      */   
/*      */ 
/*      */   public synchronized ORAData getORAData(int paramInt, ORADataFactory paramORADataFactory)
/*      */     throws SQLException
/*      */   {
/* 1707 */     if (paramORADataFactory == null) {
/* 1708 */       DatabaseError.throwSqlException(68);
/*      */     }
/* 1710 */     ORAData localORAData = null;
/*      */     
/* 1712 */     setIsNull(3);
/*      */     
/* 1714 */     if ((isOnInsertRow()) || ((isUpdatingRow()) && (isRowBufferUpdatedAt(paramInt))))
/*      */     {
/*      */ 
/* 1717 */       Datum localDatum = getRowBufferDatumAt(paramInt);
/*      */       
/* 1719 */       setIsNull(localDatum == null);
/*      */       
/* 1721 */       localORAData = paramORADataFactory.create(localDatum, 0);
/*      */     }
/*      */     else
/*      */     {
/* 1725 */       setIsNull(4);
/*      */       
/* 1727 */       localORAData = this.resultSet.getORAData(paramInt + 1, paramORADataFactory);
/*      */     }
/*      */     
/* 1730 */     return localORAData;
/*      */   }
/*      */   
/*      */   /* Error */
/*      */   public ResultSetMetaData getMetaData()
/*      */     throws SQLException
/*      */   {
/*      */     // Byte code:
/*      */     //   0: aload_0
/*      */     //   1: getfield 10	oracle/jdbc/driver/UpdatableResultSet:scrollStmt	Loracle/jdbc/driver/ScrollRsetStatement;
/*      */     //   4: checkcast 6	oracle/jdbc/driver/OracleStatement
/*      */     //   7: getfield 191	oracle/jdbc/driver/OracleStatement:closed	Z
/*      */     //   10: ifeq +10 -> 20
/*      */     //   13: bipush 9
/*      */     //   15: ldc -64
/*      */     //   17: invokestatic 71	oracle/jdbc/driver/DatabaseError:throwSqlException	(ILjava/lang/Object;)V
/*      */     //   20: aload_0
/*      */     //   21: getfield 8	oracle/jdbc/driver/UpdatableResultSet:connection	Loracle/jdbc/driver/PhysicalConnection;
/*      */     //   24: dup
/*      */     //   25: astore_1
/*      */     //   26: monitorenter
/*      */     //   27: aload_0
/*      */     //   28: dup
/*      */     //   29: astore_2
/*      */     //   30: monitorenter
/*      */     //   31: new 193	oracle/jdbc/driver/OracleResultSetMetaData
/*      */     //   34: dup
/*      */     //   35: aload_0
/*      */     //   36: getfield 8	oracle/jdbc/driver/UpdatableResultSet:connection	Loracle/jdbc/driver/PhysicalConnection;
/*      */     //   39: aload_0
/*      */     //   40: getfield 10	oracle/jdbc/driver/UpdatableResultSet:scrollStmt	Loracle/jdbc/driver/ScrollRsetStatement;
/*      */     //   43: checkcast 6	oracle/jdbc/driver/OracleStatement
/*      */     //   46: iconst_1
/*      */     //   47: invokespecial 194	oracle/jdbc/driver/OracleResultSetMetaData:<init>	(Loracle/jdbc/driver/PhysicalConnection;Loracle/jdbc/driver/OracleStatement;I)V
/*      */     //   50: aload_2
/*      */     //   51: monitorexit
/*      */     //   52: aload_1
/*      */     //   53: monitorexit
/*      */     //   54: areturn
/*      */     //   55: astore_3
/*      */     //   56: aload_2
/*      */     //   57: monitorexit
/*      */     //   58: aload_3
/*      */     //   59: athrow
/*      */     //   60: astore 4
/*      */     //   62: aload_1
/*      */     //   63: monitorexit
/*      */     //   64: aload 4
/*      */     //   66: athrow
/*      */     // Line number table:
/*      */     //   Java source line #1739	-> byte code offset #0
/*      */     //   Java source line #1740	-> byte code offset #13
/*      */     //   Java source line #1743	-> byte code offset #20
/*      */     //   Java source line #1745	-> byte code offset #27
/*      */     //   Java source line #1747	-> byte code offset #31
/*      */     //   Java source line #1750	-> byte code offset #55
/*      */     //   Java source line #1751	-> byte code offset #60
/*      */     // Local variable table:
/*      */     //   start	length	slot	name	signature
/*      */     //   0	67	0	this	UpdatableResultSet
/*      */     //   25	38	1	Ljava/lang/Object;	Object
/*      */     //   29	28	2	Ljava/lang/Object;	Object
/*      */     //   55	4	3	localObject1	Object
/*      */     //   60	5	4	localObject2	Object
/*      */     // Exception table:
/*      */     //   from	to	target	type
/*      */     //   31	52	55	finally
/*      */     //   55	58	55	finally
/*      */     //   27	54	60	finally
/*      */     //   55	64	60	finally
/*      */   }
/*      */   
/*      */   public synchronized int findColumn(String paramString)
/*      */     throws SQLException
/*      */   {
/* 1756 */     return this.resultSet.findColumn(paramString) - 1;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public synchronized void setFetchDirection(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 1765 */     this.resultSet.setFetchDirection(paramInt);
/*      */   }
/*      */   
/*      */   public synchronized int getFetchDirection() throws SQLException
/*      */   {
/* 1770 */     return this.resultSet.getFetchDirection();
/*      */   }
/*      */   
/*      */   public synchronized void setFetchSize(int paramInt) throws SQLException
/*      */   {
/* 1775 */     this.resultSet.setFetchSize(paramInt);
/*      */   }
/*      */   
/*      */   public synchronized int getFetchSize() throws SQLException
/*      */   {
/* 1780 */     return this.resultSet.getFetchSize();
/*      */   }
/*      */   
/*      */   public int getType() throws SQLException
/*      */   {
/* 1785 */     return this.rsetType;
/*      */   }
/*      */   
/*      */   public int getConcurrency() throws SQLException
/*      */   {
/* 1790 */     return 1008;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public boolean rowUpdated()
/*      */     throws SQLException
/*      */   {
/* 1799 */     return false;
/*      */   }
/*      */   
/*      */   public boolean rowInserted() throws SQLException
/*      */   {
/* 1804 */     return false;
/*      */   }
/*      */   
/*      */   public boolean rowDeleted() throws SQLException
/*      */   {
/* 1809 */     return false;
/*      */   }
/*      */   
/*      */   public synchronized void insertRow() throws SQLException
/*      */   {
/* 1814 */     if (!isOnInsertRow()) {
/* 1815 */       DatabaseError.throwSqlException(83);
/*      */     }
/* 1817 */     prepareInsertRowStatement();
/* 1818 */     prepareInsertRowBinds();
/* 1819 */     executeInsertRow();
/*      */   }
/*      */   
/*      */ 
/*      */   public synchronized void updateRow()
/*      */     throws SQLException
/*      */   {
/* 1826 */     if (isOnInsertRow()) {
/* 1827 */       DatabaseError.throwSqlException(84);
/*      */     }
/* 1829 */     int i = getNumColumnsChanged();
/*      */     
/* 1831 */     if (i > 0)
/*      */     {
/* 1833 */       prepareUpdateRowStatement(i);
/* 1834 */       prepareUpdateRowBinds(i);
/* 1835 */       executeUpdateRow();
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */   public synchronized void deleteRow()
/*      */     throws SQLException
/*      */   {
/* 1843 */     if (isOnInsertRow()) {
/* 1844 */       DatabaseError.throwSqlException(84);
/*      */     }
/* 1846 */     prepareDeleteRowStatement();
/* 1847 */     prepareDeleteRowBinds();
/* 1848 */     executeDeleteRow();
/*      */   }
/*      */   
/*      */ 
/*      */   public synchronized void refreshRow()
/*      */     throws SQLException
/*      */   {
/* 1855 */     if (isOnInsertRow()) {
/* 1856 */       DatabaseError.throwSqlException(84);
/*      */     }
/* 1858 */     this.resultSet.refreshRow();
/*      */   }
/*      */   
/*      */   public synchronized void cancelRowUpdates() throws SQLException
/*      */   {
/* 1863 */     if (this.isUpdating)
/*      */     {
/* 1865 */       this.isUpdating = false;
/*      */       
/* 1867 */       clearRowBuffer();
/*      */     }
/*      */   }
/*      */   
/*      */   public synchronized void moveToInsertRow() throws SQLException
/*      */   {
/* 1873 */     if (isOnInsertRow()) {
/* 1874 */       return;
/*      */     }
/* 1876 */     this.isInserting = true;
/*      */     
/*      */ 
/* 1879 */     if (this.rowBuffer == null) {
/* 1880 */       this.rowBuffer = new Object[getColumnCount()];
/*      */     }
/* 1882 */     if (this.m_nullIndicator == null) {
/* 1883 */       this.m_nullIndicator = new boolean[getColumnCount()];
/*      */     }
/* 1885 */     clearRowBuffer();
/*      */   }
/*      */   
/*      */   public synchronized void moveToCurrentRow() throws SQLException
/*      */   {
/* 1890 */     cancelRowInserts();
/*      */   }
/*      */   
/*      */   public synchronized void updateString(int paramInt, String paramString)
/*      */     throws SQLException
/*      */   {
/* 1896 */     updateObject(paramInt, paramString);
/*      */   }
/*      */   
/*      */   public synchronized void updateNull(int paramInt) throws SQLException
/*      */   {
/* 1901 */     setRowBufferAt(paramInt, null);
/*      */   }
/*      */   
/*      */   public void updateBoolean(int paramInt, boolean paramBoolean) throws SQLException
/*      */   {
/* 1906 */     updateObject(paramInt, new Boolean(paramBoolean));
/*      */   }
/*      */   
/*      */   public void updateByte(int paramInt, byte paramByte) throws SQLException
/*      */   {
/* 1911 */     updateObject(paramInt, new Integer(paramByte));
/*      */   }
/*      */   
/*      */   public void updateShort(int paramInt, short paramShort) throws SQLException
/*      */   {
/* 1916 */     updateObject(paramInt, new Integer(paramShort));
/*      */   }
/*      */   
/*      */   public void updateInt(int paramInt1, int paramInt2) throws SQLException
/*      */   {
/* 1921 */     updateObject(paramInt1, new Integer(paramInt2));
/*      */   }
/*      */   
/*      */   public void updateLong(int paramInt, long paramLong) throws SQLException
/*      */   {
/* 1926 */     updateObject(paramInt, new Long(paramLong));
/*      */   }
/*      */   
/*      */   public void updateFloat(int paramInt, float paramFloat) throws SQLException
/*      */   {
/* 1931 */     updateObject(paramInt, new Float(paramFloat));
/*      */   }
/*      */   
/*      */   public void updateDouble(int paramInt, double paramDouble) throws SQLException
/*      */   {
/* 1936 */     updateObject(paramInt, new Double(paramDouble));
/*      */   }
/*      */   
/*      */   public void updateBigDecimal(int paramInt, BigDecimal paramBigDecimal)
/*      */     throws SQLException
/*      */   {
/* 1942 */     updateObject(paramInt, paramBigDecimal);
/*      */   }
/*      */   
/*      */   public void updateBytes(int paramInt, byte[] paramArrayOfByte) throws SQLException
/*      */   {
/* 1947 */     updateObject(paramInt, paramArrayOfByte);
/*      */   }
/*      */   
/*      */   public void updateDate(int paramInt, Date paramDate) throws SQLException
/*      */   {
/* 1952 */     updateObject(paramInt, paramDate);
/*      */   }
/*      */   
/*      */   public void updateTime(int paramInt, Time paramTime) throws SQLException
/*      */   {
/* 1957 */     updateObject(paramInt, paramTime);
/*      */   }
/*      */   
/*      */   public void updateTimestamp(int paramInt, Timestamp paramTimestamp)
/*      */     throws SQLException
/*      */   {
/* 1963 */     updateObject(paramInt, paramTimestamp);
/*      */   }
/*      */   
/*      */   public void updateAsciiStream(int paramInt1, InputStream paramInputStream, int paramInt2)
/*      */     throws SQLException
/*      */   {
/* 1969 */     int i = getInternalMetadata().getColumnType(1 + paramInt1);
/*      */     
/* 1971 */     if ((paramInputStream != null) && (paramInt2 > 0)) {
/*      */       Object localObject;
/* 1973 */       if (!isStreamType(i))
/*      */       {
/* 1975 */         localObject = new byte[paramInt2];
/*      */         
/*      */         try
/*      */         {
/* 1979 */           int j = paramInputStream.read((byte[])localObject);
/*      */           
/* 1981 */           paramInputStream.close();
/*      */           
/* 1983 */           String str = new String((byte[])localObject, 0, j);
/*      */           
/* 1985 */           updateString(paramInt1, str);
/*      */         }
/*      */         catch (IOException localIOException)
/*      */         {
/* 1989 */           DatabaseError.throwSqlException(localIOException);
/*      */         }
/*      */       }
/*      */       else
/*      */       {
/* 1994 */         localObject = new int[] { paramInt2, 1 };
/*      */         
/*      */ 
/*      */ 
/*      */ 
/* 1999 */         setRowBufferAt(paramInt1, paramInputStream, (int[])localObject);
/*      */       }
/*      */     }
/*      */     else
/*      */     {
/* 2004 */       setRowBufferAt(paramInt1, null);
/*      */     }
/*      */   }
/*      */   
/*      */   final boolean isStreamType(int paramInt)
/*      */   {
/* 2010 */     return (paramInt == 2004) || (paramInt == 2005) || (paramInt == -4) || (paramInt == -1);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   public void updateBinaryStream(int paramInt1, InputStream paramInputStream, int paramInt2)
/*      */     throws SQLException
/*      */   {
/* 2019 */     int i = getInternalMetadata().getColumnType(1 + paramInt1);
/*      */     
/* 2021 */     if ((paramInputStream != null) && (paramInt2 > 0)) {
/*      */       Object localObject;
/* 2023 */       if (!isStreamType(i))
/*      */       {
/* 2025 */         localObject = new byte[paramInt2];
/*      */         
/*      */         try
/*      */         {
/* 2029 */           int j = paramInputStream.read((byte[])localObject);
/*      */           
/* 2031 */           paramInputStream.close();
/* 2032 */           updateBytes(paramInt1, (byte[])localObject);
/*      */         }
/*      */         catch (IOException localIOException)
/*      */         {
/* 2036 */           DatabaseError.throwSqlException(localIOException);
/*      */         }
/*      */       }
/*      */       else
/*      */       {
/* 2041 */         localObject = new int[] { paramInt2, 2 };
/*      */         
/*      */ 
/*      */ 
/*      */ 
/* 2046 */         setRowBufferAt(paramInt1, paramInputStream, (int[])localObject);
/*      */       }
/*      */     }
/*      */     else
/*      */     {
/* 2051 */       setRowBufferAt(paramInt1, null);
/*      */     }
/*      */   }
/*      */   
/*      */   public void updateCharacterStream(int paramInt1, Reader paramReader, int paramInt2)
/*      */     throws SQLException
/*      */   {
/* 2058 */     int i = getInternalMetadata().getColumnType(1 + paramInt1);
/*      */     
/* 2060 */     if ((paramReader != null) && (paramInt2 > 0)) {
/*      */       Object localObject;
/* 2062 */       if (!isStreamType(i))
/*      */       {
/* 2064 */         localObject = new char[paramInt2];
/*      */         
/*      */         try
/*      */         {
/* 2068 */           int j = paramReader.read((char[])localObject);
/*      */           
/* 2070 */           paramReader.close();
/* 2071 */           updateString(paramInt1, new String((char[])localObject));
/*      */         }
/*      */         catch (IOException localIOException)
/*      */         {
/* 2075 */           DatabaseError.throwSqlException(localIOException);
/*      */         }
/*      */       }
/*      */       else
/*      */       {
/* 2080 */         localObject = new int[] { paramInt2 };
/*      */         
/*      */ 
/*      */ 
/*      */ 
/* 2085 */         setRowBufferAt(paramInt1, paramReader, (int[])localObject);
/*      */       }
/*      */     }
/*      */     else
/*      */     {
/* 2090 */       setRowBufferAt(paramInt1, null);
/*      */     }
/*      */   }
/*      */   
/*      */   public void updateObject(int paramInt1, Object paramObject, int paramInt2)
/*      */     throws SQLException
/*      */   {
/* 2097 */     updateObject(paramInt1, paramObject);
/*      */   }
/*      */   
/*      */   public synchronized void updateObject(int paramInt, Object paramObject)
/*      */     throws SQLException
/*      */   {
/* 2103 */     Datum localDatum = null;
/*      */     
/* 2105 */     if (paramObject != null)
/*      */     {
/* 2107 */       if ((paramObject instanceof Datum)) {
/* 2108 */         localDatum = (Datum)paramObject;
/*      */       }
/*      */       else {
/* 2111 */         OracleResultSetMetaData localOracleResultSetMetaData = (OracleResultSetMetaData)getInternalMetadata();
/* 2112 */         int i = paramInt + 1;
/* 2113 */         localDatum = SQLUtil.makeOracleDatum(this.connection, paramObject, localOracleResultSetMetaData.getColumnType(i), null, localOracleResultSetMetaData.isNCHAR(i));
/*      */       }
/*      */     }
/*      */     
/*      */ 
/* 2118 */     setRowBufferAt(paramInt, localDatum);
/*      */   }
/*      */   
/*      */   public synchronized void updateOracleObject(int paramInt, Datum paramDatum)
/*      */     throws SQLException
/*      */   {
/* 2124 */     setRowBufferAt(paramInt, paramDatum);
/*      */   }
/*      */   
/*      */   public void updateROWID(int paramInt, ROWID paramROWID) throws SQLException
/*      */   {
/* 2129 */     updateOracleObject(paramInt, paramROWID);
/*      */   }
/*      */   
/*      */   public void updateNUMBER(int paramInt, NUMBER paramNUMBER) throws SQLException
/*      */   {
/* 2134 */     updateOracleObject(paramInt, paramNUMBER);
/*      */   }
/*      */   
/*      */   public void updateDATE(int paramInt, DATE paramDATE) throws SQLException
/*      */   {
/* 2139 */     updateOracleObject(paramInt, paramDATE);
/*      */   }
/*      */   
/*      */   public void updateINTERVALYM(int paramInt, INTERVALYM paramINTERVALYM)
/*      */     throws SQLException
/*      */   {
/* 2145 */     updateOracleObject(paramInt, paramINTERVALYM);
/*      */   }
/*      */   
/*      */   public void updateINTERVALDS(int paramInt, INTERVALDS paramINTERVALDS)
/*      */     throws SQLException
/*      */   {
/* 2151 */     updateOracleObject(paramInt, paramINTERVALDS);
/*      */   }
/*      */   
/*      */   public void updateTIMESTAMP(int paramInt, TIMESTAMP paramTIMESTAMP) throws SQLException
/*      */   {
/* 2156 */     updateOracleObject(paramInt, paramTIMESTAMP);
/*      */   }
/*      */   
/*      */   public void updateTIMESTAMPTZ(int paramInt, TIMESTAMPTZ paramTIMESTAMPTZ)
/*      */     throws SQLException
/*      */   {
/* 2162 */     updateOracleObject(paramInt, paramTIMESTAMPTZ);
/*      */   }
/*      */   
/*      */   public void updateTIMESTAMPLTZ(int paramInt, TIMESTAMPLTZ paramTIMESTAMPLTZ)
/*      */     throws SQLException
/*      */   {
/* 2168 */     updateOracleObject(paramInt, paramTIMESTAMPLTZ);
/*      */   }
/*      */   
/*      */   public void updateARRAY(int paramInt, ARRAY paramARRAY) throws SQLException
/*      */   {
/* 2173 */     updateOracleObject(paramInt, paramARRAY);
/*      */   }
/*      */   
/*      */   public void updateSTRUCT(int paramInt, STRUCT paramSTRUCT) throws SQLException
/*      */   {
/* 2178 */     updateOracleObject(paramInt, paramSTRUCT);
/*      */   }
/*      */   
/*      */   public void updateOPAQUE(int paramInt, OPAQUE paramOPAQUE) throws SQLException
/*      */   {
/* 2183 */     updateOracleObject(paramInt, paramOPAQUE);
/*      */   }
/*      */   
/*      */   public void updateREF(int paramInt, REF paramREF) throws SQLException
/*      */   {
/* 2188 */     updateOracleObject(paramInt, paramREF);
/*      */   }
/*      */   
/*      */   public void updateCHAR(int paramInt, CHAR paramCHAR) throws SQLException
/*      */   {
/* 2193 */     updateOracleObject(paramInt, paramCHAR);
/*      */   }
/*      */   
/*      */   public void updateRAW(int paramInt, RAW paramRAW) throws SQLException
/*      */   {
/* 2198 */     updateOracleObject(paramInt, paramRAW);
/*      */   }
/*      */   
/*      */   public void updateBLOB(int paramInt, BLOB paramBLOB) throws SQLException
/*      */   {
/* 2203 */     updateOracleObject(paramInt, paramBLOB);
/*      */   }
/*      */   
/*      */   public void updateCLOB(int paramInt, CLOB paramCLOB) throws SQLException
/*      */   {
/* 2208 */     updateOracleObject(paramInt, paramCLOB);
/*      */   }
/*      */   
/*      */   public void updateBFILE(int paramInt, BFILE paramBFILE) throws SQLException
/*      */   {
/* 2213 */     updateOracleObject(paramInt, paramBFILE);
/*      */   }
/*      */   
/*      */   public void updateBfile(int paramInt, BFILE paramBFILE) throws SQLException
/*      */   {
/* 2218 */     updateOracleObject(paramInt, paramBFILE);
/*      */   }
/*      */   
/*      */   public void updateCustomDatum(int paramInt, CustomDatum paramCustomDatum)
/*      */     throws SQLException
/*      */   {
/* 2224 */     throw new Error("wanna do datum = ((CustomDatum) x).toDatum(m_comm)");
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   public void updateORAData(int paramInt, ORAData paramORAData)
/*      */     throws SQLException
/*      */   {
/* 2232 */     Datum localDatum = paramORAData.toDatum(this.connection);
/*      */     
/* 2234 */     updateOracleObject(paramInt, localDatum);
/*      */   }
/*      */   
/*      */   public void updateRef(int paramInt, Ref paramRef) throws SQLException
/*      */   {
/* 2239 */     updateREF(paramInt, (REF)paramRef);
/*      */   }
/*      */   
/*      */   public void updateBlob(int paramInt, Blob paramBlob) throws SQLException
/*      */   {
/* 2244 */     updateBLOB(paramInt, (BLOB)paramBlob);
/*      */   }
/*      */   
/*      */   public void updateClob(int paramInt, Clob paramClob) throws SQLException
/*      */   {
/* 2249 */     updateCLOB(paramInt, (CLOB)paramClob);
/*      */   }
/*      */   
/*      */   public void updateArray(int paramInt, Array paramArray) throws SQLException
/*      */   {
/* 2254 */     updateARRAY(paramInt, (ARRAY)paramArray);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   int getColumnCount()
/*      */     throws SQLException
/*      */   {
/* 2266 */     if (this.columnCount == 0)
/*      */     {
/* 2268 */       if ((this.resultSet instanceof OracleResultSetImpl))
/*      */       {
/* 2270 */         if (((OracleResultSetImpl)this.resultSet).statement.accessors != null) {
/* 2271 */           this.columnCount = ((OracleResultSetImpl)this.resultSet).statement.numberOfDefinePositions;
/*      */         }
/*      */         else {
/* 2274 */           this.columnCount = getInternalMetadata().getColumnCount();
/*      */         }
/*      */       } else {
/* 2277 */         this.columnCount = ((ScrollableResultSet)this.resultSet).getColumnCount();
/*      */       }
/*      */     }
/* 2280 */     return this.columnCount;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   ResultSetMetaData getInternalMetadata()
/*      */     throws SQLException
/*      */   {
/* 2288 */     if (this.rsetMetaData == null) {
/* 2289 */       this.rsetMetaData = this.resultSet.getMetaData();
/*      */     }
/* 2291 */     return this.rsetMetaData;
/*      */   }
/*      */   
/*      */   private void cancelRowChanges() throws SQLException
/*      */   {
/* 2296 */     if (this.isInserting) {
/* 2297 */       cancelRowInserts();
/*      */     }
/* 2299 */     if (this.isUpdating) {
/* 2300 */       cancelRowUpdates();
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   boolean isOnInsertRow()
/*      */   {
/* 2308 */     return this.isInserting;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   private void cancelRowInserts()
/*      */   {
/* 2316 */     if (this.isInserting)
/*      */     {
/* 2318 */       this.isInserting = false;
/*      */       
/* 2320 */       clearRowBuffer();
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   boolean isUpdatingRow()
/*      */   {
/* 2329 */     return this.isUpdating;
/*      */   }
/*      */   
/*      */ 
/*      */   private void clearRowBuffer()
/*      */   {
/*      */     int i;
/*      */     
/* 2337 */     if (this.rowBuffer != null)
/*      */     {
/* 2339 */       for (i = 0; i < this.rowBuffer.length; i++) {
/* 2340 */         this.rowBuffer[i] = null;
/*      */       }
/*      */     }
/* 2343 */     if (this.m_nullIndicator != null)
/*      */     {
/* 2345 */       for (i = 0; i < this.m_nullIndicator.length; i++) {
/* 2346 */         this.m_nullIndicator[i] = false;
/*      */       }
/*      */     }
/* 2349 */     if (this.typeInfo != null)
/*      */     {
/* 2351 */       for (i = 0; i < this.typeInfo.length; i++) {
/* 2352 */         if (this.typeInfo[i] != null) {
/* 2353 */           for (int j = 0; j < this.typeInfo[i].length; j++) {
/* 2354 */             this.typeInfo[i][j] = 0;
/*      */           }
/*      */         }
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */   private void setRowBufferAt(int paramInt, Datum paramDatum) throws SQLException
/*      */   {
/* 2363 */     setRowBufferAt(paramInt, paramDatum, (int[])null);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   private void setRowBufferAt(int paramInt, Object paramObject, int[] paramArrayOfInt)
/*      */     throws SQLException
/*      */   {
/* 2372 */     if (!this.isInserting)
/*      */     {
/* 2374 */       if ((isBeforeFirst()) || (isAfterLast()) || (getRow() == 0)) {
/* 2375 */         DatabaseError.throwSqlException(82);
/*      */       } else {
/* 2377 */         this.isUpdating = true;
/*      */       }
/*      */     }
/* 2380 */     if ((paramInt < 1) || (paramInt > getColumnCount() - 1)) {
/* 2381 */       DatabaseError.throwSqlException(68, "setRowBufferAt");
/*      */     }
/*      */     
/* 2384 */     if (this.rowBuffer == null) {
/* 2385 */       this.rowBuffer = new Object[getColumnCount()];
/*      */     }
/* 2387 */     if (this.m_nullIndicator == null)
/*      */     {
/* 2389 */       this.m_nullIndicator = new boolean[getColumnCount()];
/*      */       
/* 2391 */       for (int i = 0; i < getColumnCount(); i++) {
/* 2392 */         this.m_nullIndicator[i] = false;
/*      */       }
/*      */     }
/* 2395 */     if (paramArrayOfInt != null)
/*      */     {
/* 2397 */       if (this.typeInfo == null)
/*      */       {
/* 2399 */         this.typeInfo = new int[getColumnCount()][];
/*      */       }
/*      */       
/* 2402 */       this.typeInfo[paramInt] = paramArrayOfInt;
/*      */     }
/*      */     
/* 2405 */     this.rowBuffer[paramInt] = paramObject;
/* 2406 */     this.m_nullIndicator[paramInt] = (paramObject == null ? 1 : false);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   private Datum getRowBufferDatumAt(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 2414 */     if ((paramInt < 1) || (paramInt > getColumnCount() - 1)) {
/* 2415 */       DatabaseError.throwSqlException(68, "getRowBufferDatumAt");
/*      */     }
/*      */     
/* 2418 */     Datum localDatum = null;
/*      */     
/* 2420 */     if (this.rowBuffer != null)
/*      */     {
/* 2422 */       Object localObject = this.rowBuffer[paramInt];
/*      */       
/* 2424 */       if (localObject != null)
/*      */       {
/* 2426 */         if ((localObject instanceof Datum))
/*      */         {
/* 2428 */           localDatum = (Datum)localObject;
/*      */         }
/*      */         else
/*      */         {
/* 2432 */           OracleResultSetMetaData localOracleResultSetMetaData = (OracleResultSetMetaData)getInternalMetadata();
/* 2433 */           int i = paramInt + 1;
/* 2434 */           localDatum = SQLUtil.makeOracleDatum(this.connection, localObject, localOracleResultSetMetaData.getColumnType(i), null, localOracleResultSetMetaData.isNCHAR(i));
/*      */           
/*      */ 
/*      */ 
/* 2438 */           this.rowBuffer[paramInt] = localDatum;
/*      */         }
/*      */       }
/*      */     }
/*      */     
/* 2443 */     return localDatum;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   private Object getRowBufferAt(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 2451 */     if ((paramInt < 1) || (paramInt > getColumnCount() - 1)) {
/* 2452 */       DatabaseError.throwSqlException(68, "getRowBufferDatumAt");
/*      */     }
/*      */     
/* 2455 */     if (this.rowBuffer != null)
/*      */     {
/* 2457 */       return this.rowBuffer[paramInt];
/*      */     }
/*      */     
/* 2460 */     return null;
/*      */   }
/*      */   
/*      */   private boolean isRowBufferUpdatedAt(int paramInt)
/*      */   {
/* 2465 */     if (this.rowBuffer == null) {
/* 2466 */       return false;
/*      */     }
/* 2468 */     return (this.rowBuffer[paramInt] != null) || (this.m_nullIndicator[paramInt] != 0);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   private void prepareInsertRowStatement()
/*      */     throws SQLException
/*      */   {
/* 2476 */     if (this.insertStmt == null)
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/* 2481 */       this.insertStmt = ((OraclePreparedStatement)this.connection.prepareStatement(((OracleStatement)this.scrollStmt).sqlObject.getInsertSqlForUpdatableResultSet(this)));
/*      */       
/*      */ 
/* 2484 */       this.insertStmt.setQueryTimeout(((Statement)this.scrollStmt).getQueryTimeout());
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   private void prepareInsertRowBinds()
/*      */     throws SQLException
/*      */   {
/* 2494 */     int i = 1;
/*      */     
/*      */ 
/* 2497 */     i = prepareSubqueryBinds(this.insertStmt, i);
/*      */     
/* 2499 */     OracleResultSetMetaData localOracleResultSetMetaData = (OracleResultSetMetaData)getInternalMetadata();
/*      */     
/* 2501 */     for (int j = 1; j < getColumnCount(); j++)
/*      */     {
/* 2503 */       Object localObject = getRowBufferAt(j);
/*      */       
/* 2505 */       if (localObject != null)
/*      */       {
/* 2507 */         if ((localObject instanceof Reader))
/*      */         {
/* 2509 */           this.insertStmt.setCharacterStream(i + j - 1, (Reader)localObject, this.typeInfo[j][0]);
/*      */ 
/*      */         }
/* 2512 */         else if ((localObject instanceof InputStream))
/*      */         {
/* 2514 */           if (this.typeInfo[j][1] == 2) {
/* 2515 */             this.insertStmt.setBinaryStream(i + j - 1, (InputStream)localObject, this.typeInfo[j][0]);
/*      */ 
/*      */           }
/* 2518 */           else if (this.typeInfo[j][1] == 1) {
/* 2519 */             this.insertStmt.setAsciiStream(i + j - 1, (InputStream)localObject, this.typeInfo[j][0]);
/*      */           }
/*      */           
/*      */         }
/*      */         else
/*      */         {
/* 2525 */           Datum localDatum = getRowBufferDatumAt(j);
/*      */           
/* 2527 */           if (localOracleResultSetMetaData.isNCHAR(j + 1))
/* 2528 */             this.insertStmt.setFormOfUse(i + j - 1, (short)2);
/* 2529 */           this.insertStmt.setOracleObject(i + j - 1, localDatum);
/*      */ 
/*      */         }
/*      */         
/*      */ 
/*      */       }
/*      */       else
/*      */       {
/*      */ 
/* 2538 */         int k = getInternalMetadata().getColumnType(j + 1);
/*      */         
/* 2540 */         if ((k == 2006) || (k == 2002) || (k == 2008) || (k == 2007) || (k == 2003))
/*      */         {
/*      */ 
/*      */ 
/* 2544 */           this.insertStmt.setNull(i + j - 1, k, getInternalMetadata().getColumnTypeName(j + 1));
/*      */ 
/*      */         }
/*      */         else
/*      */         {
/* 2549 */           this.insertStmt.setNull(i + j - 1, k);
/*      */         }
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   private void executeInsertRow()
/*      */     throws SQLException
/*      */   {
/* 2560 */     if (this.insertStmt.executeUpdate() != 1) {
/* 2561 */       DatabaseError.throwSqlException(85);
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */   private int getNumColumnsChanged()
/*      */     throws SQLException
/*      */   {
/* 2571 */     int i = 0;
/*      */     
/* 2573 */     if (this.indexColsChanged == null) {
/* 2574 */       this.indexColsChanged = new int[getColumnCount()];
/*      */     }
/* 2576 */     if (this.rowBuffer != null)
/*      */     {
/* 2578 */       for (int j = 1; j < getColumnCount(); j++)
/*      */       {
/* 2580 */         if ((this.rowBuffer[j] != null) || ((this.rowBuffer[j] == null) && (this.m_nullIndicator[j] != 0)))
/*      */         {
/*      */ 
/* 2583 */           this.indexColsChanged[(i++)] = j;
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*      */ 
/*      */ 
/*      */ 
/* 2591 */     return i;
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void prepareUpdateRowStatement(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 2603 */     if (this.updateStmt != null) {
/* 2604 */       this.updateStmt.close();
/*      */     }
/*      */     
/*      */ 
/*      */ 
/* 2609 */     this.updateStmt = ((OraclePreparedStatement)this.connection.prepareStatement(((OracleStatement)this.scrollStmt).sqlObject.getUpdateSqlForUpdatableResultSet(this, paramInt, this.rowBuffer, this.indexColsChanged)));
/*      */     
/*      */ 
/*      */ 
/* 2613 */     this.updateStmt.setQueryTimeout(((Statement)this.scrollStmt).getQueryTimeout());
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   private void prepareUpdateRowBinds(int paramInt)
/*      */     throws SQLException
/*      */   {
/* 2621 */     int i = 1;
/*      */     
/*      */ 
/* 2624 */     i = prepareSubqueryBinds(this.updateStmt, i);
/*      */     
/* 2626 */     OracleResultSetMetaData localOracleResultSetMetaData = (OracleResultSetMetaData)getInternalMetadata();
/*      */     
/* 2628 */     for (int j = 0; j < paramInt; j++)
/*      */     {
/* 2630 */       int k = this.indexColsChanged[j];
/* 2631 */       Object localObject = getRowBufferAt(k);
/*      */       
/* 2633 */       if (localObject != null)
/*      */       {
/* 2635 */         if ((localObject instanceof Reader))
/*      */         {
/* 2637 */           this.updateStmt.setCharacterStream(i++, (Reader)localObject, this.typeInfo[k][0]);
/*      */ 
/*      */         }
/* 2640 */         else if ((localObject instanceof InputStream))
/*      */         {
/* 2642 */           if (this.typeInfo[k][1] == 2)
/*      */           {
/*      */ 
/* 2645 */             this.updateStmt.setBinaryStream(i++, (InputStream)localObject, this.typeInfo[k][0]);
/*      */           }
/* 2647 */           else if (this.typeInfo[k][1] == 1) {
/* 2648 */             this.updateStmt.setAsciiStream(i++, (InputStream)localObject, this.typeInfo[k][0]);
/*      */           }
/*      */         }
/*      */         else
/*      */         {
/* 2653 */           Datum localDatum = getRowBufferDatumAt(k);
/*      */           
/* 2655 */           if (localOracleResultSetMetaData.isNCHAR(k + 1))
/* 2656 */             this.updateStmt.setFormOfUse(i, (short)2);
/* 2657 */           this.updateStmt.setOracleObject(i++, localDatum);
/*      */         }
/*      */         
/*      */       }
/*      */       else
/*      */       {
/* 2663 */         int m = getInternalMetadata().getColumnType(k + 1);
/*      */         
/* 2665 */         if ((m == 2006) || (m == 2002) || (m == 2008) || (m == 2007) || (m == 2003))
/*      */         {
/*      */ 
/*      */ 
/* 2669 */           this.updateStmt.setNull(i++, m, getInternalMetadata().getColumnTypeName(k + 1));
/*      */ 
/*      */         }
/*      */         else
/*      */         {
/* 2674 */           this.updateStmt.setNull(i++, m);
/*      */         }
/*      */       }
/*      */     }
/*      */     
/*      */ 
/* 2680 */     prepareCompareSelfBinds(this.updateStmt, i);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   private void executeUpdateRow()
/*      */     throws SQLException
/*      */   {
/*      */     try
/*      */     {
/* 2690 */       if (this.updateStmt.executeUpdate() == 0) {
/* 2691 */         DatabaseError.throwSqlException(85);
/*      */       }
/*      */       
/*      */ 
/* 2695 */       if (this.isCachedRset)
/*      */       {
/* 2697 */         if (this.autoRefetch)
/*      */         {
/* 2699 */           ((ScrollableResultSet)this.resultSet).refreshRowsInCache(getRow(), 1, 1000);
/*      */           
/* 2701 */           cancelRowUpdates();
/*      */         }
/*      */         else
/*      */         {
/* 2705 */           if (this.rowBuffer != null)
/*      */           {
/* 2707 */             for (int i = 1; i < getColumnCount(); i++)
/*      */             {
/* 2709 */               if ((this.rowBuffer[i] != null) || ((this.rowBuffer[i] == null) && (this.m_nullIndicator[i] != 0)))
/*      */               {
/*      */ 
/* 2712 */                 ((ScrollableResultSet)this.resultSet).setCurrentRowValueAt(this, i + 1, this.rowBuffer[i]);
/*      */               }
/*      */             }
/*      */           }
/*      */           
/*      */ 
/* 2718 */           cancelRowUpdates();
/*      */ 
/*      */         }
/*      */         
/*      */       }
/*      */       
/*      */ 
/*      */     }
/*      */     finally
/*      */     {
/*      */ 
/* 2729 */       if (this.updateStmt != null)
/*      */       {
/* 2731 */         this.updateStmt.close();
/*      */         
/* 2733 */         this.updateStmt = null;
/*      */       }
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   private void prepareDeleteRowStatement()
/*      */     throws SQLException
/*      */   {
/* 2743 */     if (this.deleteStmt == null)
/*      */     {
/* 2745 */       StringBuffer localStringBuffer = new StringBuffer();
/*      */       
/*      */ 
/*      */ 
/*      */ 
/* 2750 */       this.deleteStmt = ((OraclePreparedStatement)this.connection.prepareStatement(((OracleStatement)this.scrollStmt).sqlObject.getDeleteSqlForUpdatableResultSet(this)));
/*      */       
/*      */ 
/* 2753 */       this.deleteStmt.setQueryTimeout(((Statement)this.scrollStmt).getQueryTimeout());
/*      */     }
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */   private void prepareDeleteRowBinds()
/*      */     throws SQLException
/*      */   {
/* 2762 */     int i = 1;
/*      */     
/*      */ 
/* 2765 */     i = prepareSubqueryBinds(this.deleteStmt, i);
/*      */     
/*      */ 
/* 2768 */     prepareCompareSelfBinds(this.deleteStmt, i);
/*      */   }
/*      */   
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   private void executeDeleteRow()
/*      */     throws SQLException
/*      */   {
/* 2778 */     if (this.deleteStmt.executeUpdate() == 0) {
/* 2779 */       DatabaseError.throwSqlException(85);
/*      */     }
/*      */     
/*      */ 
/* 2783 */     if (this.isCachedRset) {
/* 2784 */       ((ScrollableResultSet)this.resultSet).removeRowInCache(getRow());
/*      */     }
/*      */   }
/*      */   
/*      */   private int prepareCompareSelfBinds(OraclePreparedStatement paramOraclePreparedStatement, int paramInt) throws SQLException
/*      */   {
/* 2790 */     Datum localDatum = this.resultSet.getOracleObject(1);
/*      */     
/* 2792 */     paramOraclePreparedStatement.setOracleObject(paramInt, this.resultSet.getOracleObject(1));
/*      */     
/* 2794 */     return paramInt + 1;
/*      */   }
/*      */   
/*      */   private int prepareSubqueryBinds(OraclePreparedStatement paramOraclePreparedStatement, int paramInt)
/*      */     throws SQLException
/*      */   {
/* 2800 */     int i = this.scrollStmt.copyBinds(paramOraclePreparedStatement, paramInt - 1);
/*      */     
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/* 2818 */     return i + 1;
/*      */   }
/*      */   
/*      */   private void setIsNull(int paramInt)
/*      */   {
/* 2823 */     this.wasNull = paramInt;
/*      */   }
/*      */   
/*      */   private void setIsNull(boolean paramBoolean)
/*      */   {
/* 2828 */     if (paramBoolean) {
/* 2829 */       this.wasNull = 1;
/*      */     } else {
/* 2831 */       this.wasNull = 2;
/*      */     }
/*      */   }
/*      */   
/*      */ 
/* 2836 */   private static final String _Copyright_2004_Oracle_All_Rights_Reserved_ = null;
/*      */   public static final boolean TRACE = false;
/*      */   public static final boolean PRIVATE_TRACE = false;
/*      */   public static final String BUILD_DATE = "Wed_Jun_22_11:18:55_PDT_2005";
/*      */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\ojdbc14.jar!\oracle\jdbc\driver\UpdatableResultSet.class
 * Java compiler version: 2 (46.0)
 * JD-Core Version:       0.7.1
 */